@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,9 +36,9 @@
 #endif
 #include <cstdlib>
 #include <climits>
-// #include <cmath>
 #include <cfloat>
 #include <hintids.hxx>
+#include <osl/diagnose.hxx>
 #include <rtl/math.hxx>
 #include <editeng/langitem.hxx>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
@@ -58,9 +59,7 @@
 #include <dbfld.hxx>
 #include <expfld.hxx>
 #include <usrfld.hxx>
-#ifndef _DBMGR_HXX
 #include <dbmgr.hxx>
-#endif
 #include <docfld.hxx>
 #include <swunodef.hxx>
 #include <swtypes.hxx>
@@ -270,7 +269,7 @@ SwCalc::SwCalc( SwDoc& rD )
     :
     aErrExpr( aEmptyStr, SwSbxValue(), 0 ),
     rDoc( rD ),
-    pLclData( &SvtSysLocale().GetLocaleData() ),
+    pLclData( m_aSysLocale.GetLocaleDataPtr() ),
     pCharClass( &GetAppCharClass() ),
     nListPor( 0 ),
     eError( CALC_NOERR )
@@ -419,7 +418,7 @@ SwCalc::~SwCalc()
 {
     for( USHORT n = 0; n < TBLSZ; ++n )
         delete VarTable[n];
-    if( pLclData != &SvtSysLocale().GetLocaleData() )
+    if( pLclData != m_aSysLocale.GetLocaleDataPtr() )
         delete pLclData;
     if( pCharClass != &GetAppCharClass() )
         delete pCharClass;
@@ -607,7 +606,7 @@ SwCalcExp* SwCalc::VarLook( const String& rStr, USHORT ins )
             pMgr->OpenDataSource(sSourceName, sTableName, -1, false))
         {
             String sColumnName( GetColumnName( sTmpName ));
-            ASSERT (sColumnName.Len(), "DB-Spaltenname fehlt!");
+           OSL_ENSURE(sColumnName.Len(), "DB-Spaltenname fehlt!");
 
             String sDBNum( SwFieldType::GetTypeStr(TYP_DBSETNUMBERFLD) );
             pCharClass->toLower(sDBNum);
@@ -657,7 +656,7 @@ SwCalcExp* SwCalc::VarLook( const String& rStr, USHORT ins )
     VarTable[ ii ] = pNewExp;
 
     String sColumnName( GetColumnName( sTmpName ));
-    ASSERT( sColumnName.Len(), "DB-Spaltenname fehlt!" );
+    OSL_ENSURE( sColumnName.Len(), "DB-Spaltenname fehlt!" );
     if( sColumnName.EqualsIgnoreCaseAscii(
                             SwFieldType::GetTypeStr( TYP_DBSETNUMBERFLD ) ))
     {
@@ -738,7 +737,7 @@ BOOL SwCalc::Push( const VoidPtr pPtr )
 
 void SwCalc::Pop( const VoidPtr )
 {
-    ASSERT( aRekurStk.Count(), "SwCalc: Pop auf ungueltigen Ptr" );
+    OSL_ENSURE( aRekurStk.Count(), "SwCalc: Pop auf ungueltigen Ptr" );
 
     aRekurStk.Remove( aRekurStk.Count() - 1 );
 }
@@ -1608,63 +1607,63 @@ String SwCalc::GetDBName(const String& rName)
 
 //------------------------------------------------------------------------------
 
+namespace
+{
+
+static bool
+lcl_Str2Double( const String& rCommand, xub_StrLen& rCommandPos, double& rVal,
+        const LocaleDataWrapper* const pLclData )
+{
+    OSL_ASSERT(pLclData);
+    const xub_Unicode nCurrCmdPos = rCommandPos;
+    rtl_math_ConversionStatus eStatus;
+    const sal_Unicode* pEnd;
+    rVal = rtl_math_uStringToDouble( rCommand.GetBuffer() + rCommandPos,
+            rCommand.GetBuffer() + rCommand.Len(),
+            pLclData->getNumDecimalSep().GetChar(0),
+            pLclData->getNumThousandSep().GetChar(0),
+            &eStatus, &pEnd );
+    rCommandPos = static_cast<xub_StrLen>(pEnd - rCommand.GetBuffer());
+
+    return rtl_math_ConversionStatus_Ok == eStatus && nCurrCmdPos != rCommandPos;
+}
+
+}
+
 /******************************************************************************
  *	Methode		:	BOOL SwCalc::Str2Double( double& )
  *	Beschreibung:
  *	Erstellt	:	OK 07.06.94 12:56
  *	Aenderung	: 	JP 27.10.98
  ******************************************************************************/
-BOOL SwCalc::Str2Double( const String& rCommand, xub_StrLen& rCommandPos,
-                            double& rVal, const LocaleDataWrapper* pLclData )
+bool SwCalc::Str2Double( const String& rCommand, xub_StrLen& rCommandPos,
+    double& rVal, const LocaleDataWrapper* const pLclData )
 {
-    const LocaleDataWrapper* pLclD = pLclData;
-    if( !pLclD )
-        pLclD = &SvtSysLocale().GetLocaleData();
-
-    const xub_Unicode nCurrCmdPos = rCommandPos;
-    rtl_math_ConversionStatus eStatus;
-    const sal_Unicode* pEnd;
-    rVal = rtl_math_uStringToDouble( rCommand.GetBuffer() + rCommandPos,
-            rCommand.GetBuffer() + rCommand.Len(),
-            pLclD->getNumDecimalSep().GetChar(0),
-            pLclD->getNumThousandSep().GetChar(0),
-            &eStatus, &pEnd );
-    rCommandPos = static_cast<xub_StrLen>(pEnd - rCommand.GetBuffer());
-
-    if( !pLclData && pLclD != &SvtSysLocale().GetLocaleData() )
-        delete (LocaleDataWrapper*)pLclD;
-
-    return rtl_math_ConversionStatus_Ok == eStatus && nCurrCmdPos != rCommandPos;
+    const SvtSysLocale aSysLocale;
+    return lcl_Str2Double( rCommand, rCommandPos, rVal,
+            pLclData ? pLclData : aSysLocale.GetLocaleDataPtr() );
 }
 
-BOOL SwCalc::Str2Double( const String& rCommand, xub_StrLen& rCommandPos,
-                            double& rVal, SwDoc* pDoc )
+bool SwCalc::Str2Double( const String& rCommand, xub_StrLen& rCommandPos,
+    double& rVal, SwDoc* const pDoc )
 {
-    const LocaleDataWrapper* pLclD = &SvtSysLocale().GetLocaleData();
+    const SvtSysLocale aSysLocale;
+    ::std::auto_ptr<const LocaleDataWrapper> pLclD;
     if( pDoc )
     {
-
         LanguageType eLang = GetDocAppScriptLang( *pDoc );
-        if( eLang != SvxLocaleToLanguage( pLclD->getLocale() ) )
-            pLclD = new LocaleDataWrapper(
+        if( eLang != SvxLocaleToLanguage( aSysLocale.GetLocaleData().getLocale() ) )
+        {
+            pLclD.reset( new LocaleDataWrapper(
                             ::comphelper::getProcessServiceFactory(),
-                            SvxCreateLocale( eLang ) );
+                            SvxCreateLocale( eLang ) ) );
+        }
     }
 
-    const xub_Unicode nCurrCmdPos = rCommandPos;
-    rtl_math_ConversionStatus eStatus;
-    const sal_Unicode* pEnd;
-    rVal = rtl_math_uStringToDouble( rCommand.GetBuffer() + rCommandPos,
-            rCommand.GetBuffer() + rCommand.Len(),
-            pLclD->getNumDecimalSep().GetChar(0),
-            pLclD->getNumThousandSep().GetChar(0),
-            &eStatus, &pEnd );
-    rCommandPos = static_cast<xub_StrLen>(pEnd - rCommand.GetBuffer());
+    bool const bRet = lcl_Str2Double( rCommand, rCommandPos, rVal,
+            (pLclD.get()) ? pLclD.get() : aSysLocale.GetLocaleDataPtr() );
 
-    if( pLclD != &SvtSysLocale().GetLocaleData() )
-        delete (LocaleDataWrapper*)pLclD;
-
-    return rtl_math_ConversionStatus_Ok == eStatus && nCurrCmdPos != rCommandPos;
+    return bRet;
 }
 
 //------------------------------------------------------------------------------
@@ -1822,3 +1821,4 @@ static const sal_Char* sNTypeTab[ 27 ] =
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
