@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -58,9 +59,7 @@
 #include <crsskip.hxx>
 #include <vcl/msgbox.hxx>
 #include <mdiexp.hxx>			// ...Percent()
-#ifndef _STATSTR_HRC
 #include <statstr.hrc>			// ResId fuer Statusleiste
-#endif
 #include <redline.hxx>      // SwRedline
 
 
@@ -327,7 +326,7 @@ BOOL SwCursor::IsSelOvr( int eFlags )
                 if( rProtect.IsCntntProtected() )
                 {
                     const SwFmtCntnt& rCntnt = pFmt->GetCntnt(FALSE);
-                    ASSERT( rCntnt.GetCntntIdx(), "wo ist der SectionNode?" );
+                    OSL_ENSURE( rCntnt.GetCntntIdx(), "wo ist der SectionNode?" );
                     ULONG nIdx = rCntnt.GetCntntIdx()->GetIndex();
                     if( nSttIdx <= nIdx && nEndIdx >= nIdx )
                     {
@@ -537,7 +536,7 @@ BOOL SwCursor::IsInProtectTable( BOOL bMove, BOOL bChgCrsr )
     // Check for convered cell:
     bool bInCoveredCell = false;
     const SwStartNode* pTmpSttNode = pCNd->FindTableBoxStartNode();
-    ASSERT( pTmpSttNode, "In table, therefore I expect to get a SwTableBoxStartNode" )
+    OSL_ENSURE( pTmpSttNode, "In table, therefore I expect to get a SwTableBoxStartNode" );
     const SwTableBox* pBox = pTmpSttNode ? pTableNode->GetTable().GetTblBox( pTmpSttNode->GetIndex() ) : 0; //Robust #151355
     if ( pBox && pBox->getRowSpan() < 1 ) // Robust #151270
         bInCoveredCell = true;
@@ -1372,22 +1371,46 @@ BOOL SwCursor::SelectWordWT( sal_Int16 nWordType, const Point* pPt )
     const SwTxtNode* pTxtNd = GetNode()->GetTxtNode();
     if( pTxtNd && pBreakIt->GetBreakIter().is() )
     {
-        xub_StrLen nPtPos = GetPoint()->nContent.GetIndex();
-        Boundary aBndry( pBreakIt->GetBreakIter()->getWordBoundary(
-                            pTxtNd->GetTxt(), nPtPos,
-                            pBreakIt->GetLocale( pTxtNd->GetLang( nPtPos ) ),
-                            nWordType,
-                            bForward ));
-
-        if( aBndry.startPos != aBndry.endPos )
+        // Should we select the whole fieldmark?
+        const IDocumentMarkAccess* pMarksAccess = GetDoc()->getIDocumentMarkAccess( );
+        sw::mark::IMark* pMark = GetPoint() ? pMarksAccess->getFieldmarkFor( *GetPoint( ) ) : NULL;
+        if ( pMark )
         {
-            GetPoint()->nContent = (xub_StrLen)aBndry.endPos;
-            if( !IsSelOvr() )
+            const SwPosition rStart = pMark->GetMarkStart();
+            GetPoint()->nNode = rStart.nNode;
+            GetPoint()->nContent = rStart.nContent;
+            GetPoint()->nContent++; // Don't select the start delimiter
+
+            const SwPosition rEnd = pMark->GetMarkEnd();
+
+            if ( rStart != rEnd )
             {
                 SetMark();
-                GetMark()->nContent = (xub_StrLen)aBndry.startPos;
+                GetMark()->nNode = rEnd.nNode;
+                GetMark()->nContent = rEnd.nContent;
+                GetMark()->nContent--; //Don't select the end delimiter
+            }
+            bRet = TRUE;
+        }
+        else
+        {
+            xub_StrLen nPtPos = GetPoint()->nContent.GetIndex();
+            Boundary aBndry( pBreakIt->GetBreakIter()->getWordBoundary(
+                                pTxtNd->GetTxt(), nPtPos,
+                                pBreakIt->GetLocale( pTxtNd->GetLang( nPtPos ) ),
+                                nWordType,
+                                bForward ));
+
+            if( aBndry.startPos != aBndry.endPos )
+            {
+                GetPoint()->nContent = (xub_StrLen)aBndry.endPos;
                 if( !IsSelOvr() )
-                    bRet = TRUE;
+                {
+                    SetMark();
+                    GetMark()->nContent = (xub_StrLen)aBndry.startPos;
+                    if( !IsSelOvr() )
+                        bRet = TRUE;
+                }
             }
         }
     }
@@ -1618,7 +1641,7 @@ BOOL SwCursor::LeftRight( BOOL bLeft, USHORT nCnt, USHORT nMode,
     else
         fnGo = CRSR_SKIP_CELLS == nMode ? fnGoCntntCells : fnGoCntnt;
 
-    // ASSERT( not in covered cell )
+    // OSL_ENSURE( not in covered cell )
 
     while( nCnt )
     {
@@ -1812,7 +1835,7 @@ BOOL SwCursor::UpDown( BOOL bUp, USHORT nCnt,
             // set the point to the last frame in the table box. This is
             // only necessary if we do not already have a table selection
             const SwStartNode* pTblNd = GetNode( TRUE )->FindTableBoxStartNode();
-            ASSERT( pTblNd, "pTblCrsr without SwTableNode?" )
+            OSL_ENSURE( pTblNd, "pTblCrsr without SwTableNode?" );
 
             if ( pTblNd ) // safety first
             {
@@ -2358,3 +2381,4 @@ BOOL SwTableCursor::HasReadOnlyBoxSel() const
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
