@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -52,9 +53,7 @@
 #include <ndtxt.hxx>
 #include <scriptinfo.hxx>
 #include <mdiexp.hxx>			// GetSearchDialog
-#ifndef _COMCORE_HRC
 #include <comcore.hrc>			// ResId fuer Abfrage wenn zu Search & Replaces
-#endif
 
 #include <svx/sdr/overlay/overlaymanager.hxx>
 #include <svx/sdrpaintwindow.hxx>
@@ -72,101 +71,9 @@ long SwSelPaintRects::nPixPtY = 0;
 MapMode* SwSelPaintRects::pMapMode = 0;
 
 
-#ifdef SHOW_BOOKMARKS
-// #include <IMark.hxx>
-//
-// class SwBookmarkRects : public SwSelPaintRects
-// {
-// 	virtual void Paint( const Rectangle& rRect );
-// 	virtual void FillRects();
-//
-// public:
-// 	SwBookmarkRects( const SwCrsrShell& rSh ) : SwSelPaintRects( rSh ) {}
-// };
-//
-// void SwBookmarkRects::Paint( const Rectangle& rRect )
-// {
-// 	Window* pWin = GetShell()->GetWin();
-//
-// 	RasterOp eOld( pWin->GetRasterOp() );
-// 	BOOL bLCol = pWin->IsLineColor();
-// 	Color aLCol( pWin->GetLineColor() );
-// 	BOOL bFCol = pWin->IsFillColor();
-// 	Color aFCol( pWin->GetFillColor() );
-//
-// 	pWin->SetRasterOp( ROP_XOR );
-// 	Color aCol( RGB_COLORDATA( 0xF0, 0xC8, 0xF0 ) ^ COL_WHITE );
-// 	pWin->SetFillColor( aCol );
-// 	pWin->SetLineColor( aCol );
-//
-// 	pWin->DrawRect( rRect );
-//
-// 	if( bLCol ) pWin->SetLineColor( aLCol ); else pWin->SetLineColor();
-// 	if( bFCol ) pWin->SetFillColor( aFCol ); else pWin->SetFillColor();
-// 	pWin->SetRasterOp( eOld );
-// }
-//
-// void SwBookmarkRects::FillRects()
-// {
-// 	SwRegionRects aReg( GetShell()->VisArea() );
-//
-//     const SwBookmarks& rBkmkTbl = GetShell()->getIDocumentMarkAccess()->getBookmarks();
-// 	SwShellCrsr* pCrsr = 0;
-// 	for( USHORT n = 0; n < rBkmkTbl.Count(); ++n )
-// 	{
-// 		const SwBookmark& rBkmk = *rBkmkTbl[ n ];
-// 		if( rBkmk.IsBookMark() && rBkmk.GetOtherPos() )
-// 		{
-// 			if( !pCrsr )
-// 			{
-// 				pCrsr = new SwShellCrsr( *GetShell(), rBkmk.GetPos() );
-// 				pCrsr->SetMark();
-// 			}
-// 			else
-// 				*pCrsr->GetPoint() = rBkmk.GetPos();
-// 			*pCrsr->GetMark() = *rBkmk.GetOtherPos();
-// 			pCrsr->FillRects();
-// 			for( USHORT i = 0; i < pCrsr->Count(); ++i )
-// 				aReg -= (*pCrsr)[ i ];
-//
-// 			pCrsr->Remove( 0, i );
-// 		}
-// 	}
-// 	if( pCrsr ) delete pCrsr;
-//
-// 	aReg.Invert();
-// 	SwRects::Insert( &aReg, 0 );
-// }
-//
-// SwBookmarkRects* pBookMarkRects = 0;
-//
-// void ShowBookmarks( const SwCrsrShell* pSh, int nAction, const SwRect* pRect = 0 )
-// {
-//     if( !pBookMarkRects && pSh->getIDocumentMarkAccess()->getBookmarks().Count() )
-// 		pBookMarkRects = new SwBookmarkRects( *pSh );
-//
-// 	if( pBookMarkRects )
-// 	{
-// 		switch( nAction )
-// 		{
-// 		case 1: pBookMarkRects->Show(); break;
-// 		case 2:	pBookMarkRects->Hide(); break;
-// 		case 3: pBookMarkRects->Invalidate( *pRect ); break;
-// 		}
-//
-// 		if( !pBookMarkRects->Count() )
-// 			delete pBookMarkRects, pBookMarkRects = 0;
-// 	}
-// }
-//
-// #define SHOWBOOKMARKS1( nAct )			ShowBookmarks( GetShell(),nAct );
-// #define SHOWBOOKMARKS2( nAct, pRect )	ShowBookmarks( GetShell(),nAct, pRect );
-
-#else
-
+#ifndef SHOW_BOOKMARKS
 #define SHOWBOOKMARKS1( nAct )
 #define SHOWBOOKMARKS2( nAct, pRect )
-
 #endif
 
 #ifdef SHOW_REDLINES
@@ -391,7 +298,7 @@ void SwVisCrsr::Hide()
 
 void __EXPORT SwVisCrsr::Timeout()
 {
-    ASSERT( !bIsDragCrsr, "Timer vorher abschalten" );
+    OSL_ENSURE( !bIsDragCrsr, "Timer vorher abschalten" );
     if( bIsVisible )
     {
         if ( !pCrsrShell->GetWin() ) //SwFrmFmt::GetGraphic setzt das Win temp aus!
@@ -849,7 +756,7 @@ BOOL SwShellCrsr::UpDown( BOOL bUp, USHORT nCnt )
                             &GetPtPos(), GetShell()->GetUpDownX() );
 }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
 
 // JP 05.03.98: zum Testen des UNO-Crsr Verhaltens hier die Implementierung
 //				am sichtbaren Cursor
@@ -946,7 +853,7 @@ void SwShellTableCrsr::FillRects()
         while( pFrm && !pFrm->IsCellFrm() )
             pFrm = pFrm->GetUpper();
 
-        ASSERT( pFrm, "Node nicht in einer Tabelle" );
+        OSL_ENSURE( pFrm, "Node nicht in einer Tabelle" );
 
         while ( pFrm )
         {
@@ -981,14 +888,14 @@ BOOL SwShellTableCrsr::IsInside( const Point& rPt ) const
         SwFrm* pFrm = pCNd->GetFrm( &GetPtPos() );
         while( pFrm && !pFrm->IsCellFrm() )
             pFrm = pFrm->GetUpper();
-        ASSERT( pFrm, "Node nicht in einer Tabelle" );
+        OSL_ENSURE( pFrm, "Node nicht in einer Tabelle" );
         if( pFrm && pFrm->Frm().IsInside( rPt ) )
             return TRUE;
     }
     return FALSE;
 }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
 
 // JP 05.03.98: zum Testen des UNO-Crsr Verhaltens hier die Implementierung
 //				am sichtbaren Cursor
@@ -1004,3 +911,4 @@ BOOL SwShellTableCrsr::IsAtValidPos( BOOL bPoint ) const
     return SwShellCrsr::IsAtValidPos( bPoint );
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
