@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -81,7 +82,7 @@
 #include <ndtxt.hxx>
 #include <swundo.hxx>			// fuer die UndoIds
 #include <undobj.hxx>
-#include <pagedesc.hxx> //DTor
+#include <pagedesc.hxx>			//DTor
 #include <breakit.hxx>
 #include <ndole.hxx>
 #include <ndgrf.hxx>
@@ -119,9 +120,7 @@
 
 #include <osl/diagnose.h>
 #include <osl/interlck.h>
-#ifdef FUTURE_VBA
 #include <vbahelper/vbaaccesshelper.hxx>
-#endif
 
 /* @@@MAINTAINABILITY-HORROR@@@
    Probably unwanted dependency on SwDocShell
@@ -133,7 +132,6 @@
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
-
 // Seiten-Deskriptoren
 SV_IMPL_PTRARR(SwPageDescs,SwPageDescPtr);
 // Verzeichnisse
@@ -141,11 +139,10 @@ SV_IMPL_PTRARR( SwTOXTypes, SwTOXTypePtr )
 // FeldTypen
 SV_IMPL_PTRARR( SwFldTypes, SwFldTypePtr)
 
-/** IInterface
-*/
+/* IInterface */
 sal_Int32 SwDoc::acquire()
 {
-    OSL_ASSERT(mReferenceCount >= 0 && "Negative reference count detected! This is a sign for unbalanced acquire/release calls.");
+    OSL_ENSURE(mReferenceCount >= 0, "Negative reference count detected! This is a sign for unbalanced acquire/release calls.");
     return osl_incrementInterlockedCount(&mReferenceCount);
 }
 
@@ -157,12 +154,11 @@ sal_Int32 SwDoc::release()
 
 sal_Int32 SwDoc::getReferenceCount() const
 {
-    OSL_ASSERT(mReferenceCount >= 0 && "Negative reference count detected! This is a sign for unbalanced acquire/release calls.");
+    OSL_ENSURE(mReferenceCount >= 0, "Negative reference count detected! This is a sign for unbalanced acquire/release calls.");
     return mReferenceCount;
 }
 
-/** IDocumentSettingAccess
-*/
+/* IDocumentSettingAccess */
 bool SwDoc::get(/*[in]*/ DocumentSettingId id) const
 {
     switch (id)
@@ -210,7 +206,7 @@ bool SwDoc::get(/*[in]*/ DocumentSettingId id) const
         case KERN_ASIAN_PUNCTUATION: return mbKernAsianPunctuation;
         case DO_NOT_RESET_PARA_ATTRS_FOR_NUM_FONT: return mbDoNotResetParaAttrsForNumFont;
         default:
-            ASSERT(false, "Invalid setting id");
+            OSL_ENSURE(false, "Invalid setting id");
     }
     return false;
 }
@@ -257,7 +253,6 @@ void SwDoc::set(/*[in]*/ DocumentSettingId id, /*[in]*/ bool value)
                     pOutlineRule->Validate();
                     // --> OD 2005-10-21 - counting of phantoms depends on <IsOldNumbering()>
                     pOutlineRule->SetCountPhantoms( !mbOldNumbering );
-                    // <--
                 }
             }
             break;
@@ -303,59 +298,69 @@ void SwDoc::set(/*[in]*/ DocumentSettingId id, /*[in]*/ bool value)
         case CLIP_AS_CHARACTER_ANCHORED_WRITER_FLY_FRAME:
             mbClipAsCharacterAnchoredWriterFlyFrames = value;
             break;
-        // <--
+
         case UNIX_FORCE_ZERO_EXT_LEADING:
             mbUnixForceZeroExtLeading = value;
             break;
-    case PROTECT_FORM:
-        mbProtectForm = value;
-        break;
+
+        case PROTECT_FORM:
+            mbProtectForm = value;
+            break;
 
         case USE_OLD_PRINTER_METRICS:
             mbOldPrinterMetrics = value;
             break;
         case TABS_RELATIVE_TO_INDENT:
             mbTabRelativeToIndent = value;
-        break;
+            break;
         // --> OD 2008-06-05 #i89181#
         case TAB_AT_LEFT_INDENT_FOR_PARA_IN_LIST:
             mbTabAtLeftIndentForParagraphsInList = value;
-        break;
-        // <--
-    case INVERT_BORDER_SPACING:
-        mbInvertBorderSpacing = value;
-    break;
+            break;
+
+        case INVERT_BORDER_SPACING:
+            mbInvertBorderSpacing = value;
+            break;
+
         case COLLAPSE_EMPTY_CELL_PARA:
             mbCollapseEmptyCellPara = value;
-         break;
+            break;
          // COMPATIBILITY FLAGS END
 
         case BROWSE_MODE:
             mbBrowseMode = value;
             break;
+
         case HTML_MODE:
             mbHTMLMode = value;
             break;
+
         case GLOBAL_DOCUMENT:
             mbIsGlobalDoc = value;
             break;
+
         case GLOBAL_DOCUMENT_SAVE_LINKS:
             mbGlblDocSaveLinks = value;
             break;
+
         case LABEL_DOCUMENT:
             mbIsLabelDoc = value;
             break;
+
         case PURGE_OLE:
             mbPurgeOLE = value;
             break;
+
         case KERN_ASIAN_PUNCTUATION:
             mbKernAsianPunctuation = value;
             break;
+
         case DO_NOT_RESET_PARA_ATTRS_FOR_NUM_FONT:
             mbDoNotResetParaAttrsForNumFont = value;
             break;
+
         default:
-            ASSERT(false, "Invalid setting id");
+            OSL_ENSURE(false, "Invalid setting id");
     }
 }
 
@@ -363,7 +368,7 @@ const i18n::ForbiddenCharacters*
     SwDoc::getForbiddenCharacters(/*[in]*/ USHORT nLang, /*[in]*/ bool bLocaleData ) const
 {
     const i18n::ForbiddenCharacters* pRet = 0;
-    if( xForbiddenCharsTable.isValid() )
+    if( xForbiddenCharsTable.is() )
         pRet = xForbiddenCharsTable->GetForbiddenCharacters( nLang, FALSE );
     if( bLocaleData && !pRet && pBreakIt )
         pRet = &pBreakIt->GetForbidden( (LanguageType)nLang );
@@ -373,7 +378,7 @@ const i18n::ForbiddenCharacters*
 void SwDoc::setForbiddenCharacters(/*[in]*/ USHORT nLang,
                                    /*[in]*/ const i18n::ForbiddenCharacters& rFChars )
 {
-    if( !xForbiddenCharsTable.isValid() )
+    if( !xForbiddenCharsTable.is() )
     {
         uno::Reference<
             lang::XMultiServiceFactory > xMSF =
@@ -397,9 +402,9 @@ void SwDoc::setForbiddenCharacters(/*[in]*/ USHORT nLang,
     SetModified();
 }
 
-vos::ORef<SvxForbiddenCharactersTable>& SwDoc::getForbiddenCharacterTable()
+rtl::Reference<SvxForbiddenCharactersTable>& SwDoc::getForbiddenCharacterTable()
 {
-    if( !xForbiddenCharsTable.isValid() )
+    if( !xForbiddenCharsTable.is() )
     {
         uno::Reference<
             lang::XMultiServiceFactory > xMSF =
@@ -409,7 +414,7 @@ vos::ORef<SvxForbiddenCharactersTable>& SwDoc::getForbiddenCharacterTable()
     return xForbiddenCharsTable;
 }
 
-const vos::ORef<SvxForbiddenCharactersTable>& SwDoc::getForbiddenCharacterTable() const
+const rtl::Reference<SvxForbiddenCharactersTable>& SwDoc::getForbiddenCharacterTable() const
 {
     return xForbiddenCharsTable;
 }
@@ -467,8 +472,7 @@ void SwDoc::setCharacterCompressionType( /*[in]*/SwCharCompressType n )
     }
 }
 
-/** IDocumentDeviceAccess
-*/
+/* IDocumentDeviceAccess */
 SfxPrinter* SwDoc::getPrinter(/*[in]*/ bool bCreate ) const
 {
     SfxPrinter* pRet = 0;
@@ -639,6 +643,8 @@ void SwDoc::setJobsetup(/*[in]*/ const JobSetup &rJobSetup )
 
 SwPrintData* SwDoc::getPrintData() const
 {
+    if(!pPrtData)
+        ((SwDoc*)this)->pPrtData = new SwPrintData;
     return pPrtData;
 }
 
@@ -649,8 +655,7 @@ void SwDoc::setPrintData(/*[in]*/ const SwPrintData& rPrtData )
     *pPrtData = rPrtData;
 }
 
-/** Implementations the next Interface here
-*/
+/* Implementations the next Interface here */
 
 /*
  * Dokumenteditieren (Doc-SS) zum Fuellen des Dokuments
@@ -673,7 +678,7 @@ bool SwDoc::SplitNode( const SwPosition &rPos, bool bChkTableStart )
         return false;
 
     {
-        // Bug 26675:	DataChanged vorm loeschen verschicken, dann bekommt
+        // BUG 26675:	DataChanged vorm loeschen verschicken, dann bekommt
         //			man noch mit, welche Objecte sich im Bereich befinden.
         //			Danach koennen sie vor/hinter der Position befinden.
         SwDataChanged aTmp( this, rPos, 0 );
@@ -768,7 +773,7 @@ bool SwDoc::SplitNode( const SwPosition &rPos, bool bChkTableStart )
     _SaveCntntIdx( this, rPos.nNode.GetIndex(), rPos.nContent.GetIndex(),
                     aBkmkArr, SAVEFLY_SPLIT );
     // FIXME: only SwTxtNode has a valid implementation of SplitCntntNode!
-    ASSERT(pNode->IsTxtNode(), "splitting non-text node?");
+    OSL_ENSURE(pNode->IsTxtNode(), "splitting non-text node?");
     pNode = pNode->SplitCntntNode( rPos );
     if (pNode)
     {
@@ -977,6 +982,7 @@ SwFlyFrmFmt* SwDoc::Insert( const SwPaM &rRg,
                             pDfltGrfFmtColl ),
                             pFlyAttrSet, pGrfAttrSet, pFrmFmt );
 }
+
 SwFlyFrmFmt* SwDoc::Insert( const SwPaM &rRg, const GraphicObject& rGrfObj,
                             const SfxItemSet* pFlyAttrSet,
                             const SfxItemSet* pGrfAttrSet,
@@ -1036,7 +1042,6 @@ SwFlyFrmFmt* SwDoc::InsertOLE(const SwPaM &rRg, const String& rObjName,
 |*				  SwDoc::GetFldType()
 |*	  Beschreibung: liefert den am Doc eingerichteten Feldtypen zurueck
 *************************************************************************/
-
 SwFieldType *SwDoc::GetSysFldType( const USHORT eWhich ) const
 {
     for( USHORT i = 0; i < INIT_FLDTYPES; ++i )
@@ -1044,10 +1049,10 @@ SwFieldType *SwDoc::GetSysFldType( const USHORT eWhich ) const
             return (*pFldTypes)[i];
     return 0;
 }
+
 /*************************************************************************
  *			   void SetDocStat( const SwDocStat& rStat );
  *************************************************************************/
-
 void SwDoc::SetDocStat( const SwDocStat& rStat )
 {
     *pDocStat = rStat;
@@ -1058,9 +1063,6 @@ const SwDocStat& SwDoc::GetDocStat() const
     return *pDocStat;
 }
 
-/*************************************************************************/
-
-
 struct _PostItFld : public _SetGetExpFld
 {
     _PostItFld( const SwNodeIndex& rNdIdx, const SwTxtFld* pFld,  const SwIndex* pIdx = 0 )
@@ -1076,7 +1078,6 @@ struct _PostItFld : public _SetGetExpFld
     }
 };
 
-
 USHORT _PostItFld::GetPageNo( 
     const StringRangeEnumerator &rRangeEnum,
     const std::set< sal_Int32 > &rPossiblePages,
@@ -1109,7 +1110,6 @@ USHORT _PostItFld::GetPageNo(
     return 0;
 }
 
-
 bool lcl_GetPostIts( 
     IDocumentFieldsAccess* pIDFA, 
     _SetGetExpFlds * pSrtLst )
@@ -1147,7 +1147,6 @@ bool lcl_GetPostIts(
     return bHasPostIts;
 }
 
-
 static void lcl_FormatPostIt( 
     IDocumentContentOperations* pIDCO, 
     SwPaM& aPam, 
@@ -1200,7 +1199,6 @@ static void lcl_FormatPostIt(
     pIDCO->InsertString( aPam, aStr );
 }
 
-
 // provide the paper tray to use according to the page style in use,
 // but do that only if the respective item is NOT just the default item
 static sal_Int32 lcl_GetPaperBin( const SwPageFrm *pStartFrm )
@@ -1216,7 +1214,6 @@ static sal_Int32 lcl_GetPaperBin( const SwPageFrm *pStartFrm )
 
     return nRes;
 }
-    
 
 void SwDoc::CalculatePagesForPrinting(
     /* out */ SwRenderData &rData, 
@@ -1342,12 +1339,8 @@ void SwDoc::CalculatePagesForPrinting(
 
     // get PageRange value to use
     OUString aPageRange;
-    if (bIsPDFExport)
-    {
-        // ?? rOptions.getValue( C2U("Selection") );
-        aPageRange = rOptions.getStringValue( "PageRange", OUString() );
-    }
-    else
+    // PL, OD #i116085# - adjusting fix for i113919
+    if ( !bIsPDFExport )
     {
         // PageContent : 
         // 0 -> print all pages (default if aPageRange is empty)
@@ -1381,7 +1374,6 @@ void SwDoc::CalculatePagesForPrinting(
             aPageRange, rData.GetPagesToPrint(),
             1, nDocPageCount, 0, &rData.GetValidPagesSet() );
 }
-    
 
 void SwDoc::UpdatePagesForPrintingWithPostItData( 
     /* out */ SwRenderData &rData, 
@@ -1565,7 +1557,6 @@ void SwDoc::UpdatePagesForPrintingWithPostItData(
         }    
     }    
 }
-    
 
 void SwDoc::CalculatePagePairsForProspectPrinting( 
     /* out */ SwRenderData &rData, 
@@ -1713,7 +1704,6 @@ void SwDoc::CalculatePagePairsForProspectPrinting(
     // thus we are done here.
 }
 
-
 sal_uInt16 SwDoc::GetPageCount() const
 {
     return GetRootFrm() ? GetRootFrm()->GetPageNum() : 0;
@@ -1722,27 +1712,31 @@ sal_uInt16 SwDoc::GetPageCount() const
 const Size SwDoc::GetPageSize( sal_uInt16 nPageNum, bool bSkipEmptyPages ) const
 {
     Size aSize;
-    if( GetRootFrm() && nPageNum )
+    if ( GetRootFrm() && nPageNum )
     {
         const SwPageFrm* pPage = static_cast<const SwPageFrm*>
                                  (GetRootFrm()->Lower());
 
-        while( --nPageNum && pPage->GetNext() )
+        while ( --nPageNum && pPage->GetNext() )
+        {        
             pPage = static_cast<const SwPageFrm*>( pPage->GetNext() );
+        }
 
-        if( !bSkipEmptyPages && pPage->IsEmptyPage() && pPage->GetNext() )
+        // switch to next page for an empty page, if empty pages are not skipped
+        // in order to get a sensible page size for an empty page - e.g. for printing.
+        if ( !bSkipEmptyPages && pPage->IsEmptyPage() && pPage->GetNext() )
+        {        
             pPage = static_cast<const SwPageFrm*>( pPage->GetNext() );
+        }
 
         aSize = pPage->Frm().SSize();
     }
     return aSize;
 }
 
-
 /*************************************************************************
  *			  void UpdateDocStat( const SwDocStat& rStat );
  *************************************************************************/
-
 void SwDoc::UpdateDocStat( SwDocStat& rStat )
 {
     if( rStat.bModified )
@@ -1789,22 +1783,22 @@ void SwDoc::UpdateDocStat( SwDocStat& rStat )
 
         com::sun::star::uno::Sequence < com::sun::star::beans::NamedValue > aStat( rStat.nPage ? 7 : 6);
         sal_Int32 n=0;
-        aStat[n].Name = ::rtl::OUString::createFromAscii("TableCount");
+        aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("TableCount"));
         aStat[n++].Value <<= (sal_Int32)rStat.nTbl;
-        aStat[n].Name = ::rtl::OUString::createFromAscii("ImageCount");
+        aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ImageCount"));
         aStat[n++].Value <<= (sal_Int32)rStat.nGrf;
-        aStat[n].Name = ::rtl::OUString::createFromAscii("ObjectCount");
+        aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ObjectCount"));
         aStat[n++].Value <<= (sal_Int32)rStat.nOLE;
         if ( rStat.nPage )
         {
-            aStat[n].Name = ::rtl::OUString::createFromAscii("PageCount");
+            aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("PageCount"));
             aStat[n++].Value <<= (sal_Int32)rStat.nPage;
         }
-        aStat[n].Name = ::rtl::OUString::createFromAscii("ParagraphCount");
+        aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ParagraphCount"));
         aStat[n++].Value <<= (sal_Int32)rStat.nPara;
-        aStat[n].Name = ::rtl::OUString::createFromAscii("WordCount");
+        aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("WordCount"));
         aStat[n++].Value <<= (sal_Int32)rStat.nWord;
-        aStat[n].Name = ::rtl::OUString::createFromAscii("CharacterCount");
+        aStat[n].Name = ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("CharacterCount"));
         aStat[n++].Value <<= (sal_Int32)rStat.nChar;
 
         // For e.g. autotext documents there is no pSwgInfo (#i79945)
@@ -1831,9 +1825,7 @@ void SwDoc::UpdateDocStat( SwDocStat& rStat )
     }
 }
 
-
 // Dokument - Info
-
 void SwDoc::DocInfoChgd( )
 {
     GetSysFldType( RES_DOCINFOFLD )->UpdateFlds();
@@ -1841,7 +1833,7 @@ void SwDoc::DocInfoChgd( )
     SetModified();
 }
 
-    // returne zum Namen die im Doc gesetzte Referenz
+// returne zum Namen die im Doc gesetzte Referenz
 const SwFmtRefMark* SwDoc::GetRefMark( const String& rName ) const
 {
     const SfxPoolItem* pItem;
@@ -1860,7 +1852,7 @@ const SwFmtRefMark* SwDoc::GetRefMark( const String& rName ) const
     return 0;
 }
 
-    // returne die RefMark per Index - fuer Uno
+// returne die RefMark per Index - fuer Uno
 const SwFmtRefMark* SwDoc::GetRefMark( USHORT nIndex ) const
 {
     const SfxPoolItem* pItem;
@@ -1884,10 +1876,10 @@ const SwFmtRefMark* SwDoc::GetRefMark( USHORT nIndex ) const
    return pRet;
 }
 
-    // returne die Namen aller im Doc gesetzten Referenzen
-    //JP 24.06.96: Ist der ArrayPointer 0 dann returne nur, ob im Doc. eine
-    //				RefMark gesetzt ist
-    // OS 25.06.96: ab jetzt wird immer die Anzahl der Referenzen returnt
+// returne die Namen aller im Doc gesetzten Referenzen
+//JP 24.06.96: Ist der ArrayPointer 0 dann returne nur, ob im Doc. eine
+//				RefMark gesetzt ist
+// OS 25.06.96: ab jetzt wird immer die Anzahl der Referenzen returnt
 USHORT SwDoc::GetRefMarks( SvStringsDtor* pNames ) const
 {
     const SfxPoolItem* pItem;
@@ -2003,7 +1995,6 @@ void SwDoc::ResetModified()
     }
 }
 
-
 void SwDoc::ReRead( SwPaM& rPam, const String& rGrfName,
                     const String& rFltName, const Graphic* pGraphic,
                     const GraphicObject* pGrafObj )
@@ -2076,7 +2067,6 @@ BOOL lcl_CheckSmartTagsAgain( const SwNodePtr& rpNd, void*  )
     return TRUE;
 }
 
-
 /*************************************************************************
  * 		SwDoc::SpellItAgainSam( BOOL bInvalid, BOOL bOnlyWrong )
  *
@@ -2087,10 +2077,9 @@ BOOL lcl_CheckSmartTagsAgain( const SwNodePtr& rpNd, void*  )
  * Mit bOnlyWrong kann man dann steuern, ob nur die Bereiche mit falschen
  * Woertern oder die kompletten Bereiche neu ueberprueft werden muessen.
  ************************************************************************/
-
 void SwDoc::SpellItAgainSam( BOOL bInvalid, BOOL bOnlyWrong, BOOL bSmartTags )
 {
-    ASSERT( GetRootFrm(), "SpellAgain: Where's my RootFrm?" );
+    OSL_ENSURE( GetRootFrm(), "SpellAgain: Where's my RootFrm?" );
     if( bInvalid )
     {
         SwPageFrm *pPage = (SwPageFrm*)GetRootFrm()->Lower();
@@ -2226,8 +2215,8 @@ void SwDoc::Summary( SwDoc* pExtDoc, BYTE nLevel, BYTE nPara, BOOL bImpress )
     }
 }
 
-    // loesche den nicht sichtbaren Content aus dem Document, wie z.B.:
-    // versteckte Bereiche, versteckte Absaetze
+// loesche den nicht sichtbaren Content aus dem Document, wie z.B.:
+// versteckte Bereiche, versteckte Absaetze
 BOOL SwDoc::RemoveInvisibleContent()
 {
     BOOL bRet = FALSE;
@@ -2398,9 +2387,7 @@ BOOL SwDoc::RemoveInvisibleContent()
     EndUndo( UNDO_UI_DELETE_INVISIBLECNTNT, NULL );
     return bRet;
 }
-/*-- 11.06.2004 08:34:04---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 BOOL SwDoc::ConvertFieldsToText()
 {
     BOOL bRet = FALSE;
@@ -2511,7 +2498,7 @@ bool SwDoc::LinksUpdated() const
     return mbLinksUpdated;
 }
 
-    // embedded alle lokalen Links (Bereiche/Grafiken)
+// embedded alle lokalen Links (Bereiche/Grafiken)
 bool SwDoc::EmbedAllLinks()
 {
     BOOL bRet = FALSE;
@@ -2562,10 +2549,6 @@ bool SwDoc::EmbedAllLinks()
     return bRet;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 BOOL SwDoc::IsInsTblFormatNum() const
 {
     return SW_MOD()->IsInsTblFormatNum(get(IDocumentSettingAccess::HTML_MODE));
@@ -2576,16 +2559,12 @@ BOOL SwDoc::IsInsTblChangeNumFormat() const
     return SW_MOD()->IsInsTblChangeNumFormat(get(IDocumentSettingAccess::HTML_MODE));
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 BOOL SwDoc::IsInsTblAlignNum() const
 {
     return SW_MOD()->IsInsTblAlignNum(get(IDocumentSettingAccess::HTML_MODE));
 }
 
-        // setze das InsertDB als Tabelle Undo auf:
+// setze das InsertDB als Tabelle Undo auf:
 void SwDoc::AppendUndoForInsertFromDB( const SwPaM& rPam, BOOL bIsTable )
 {
     if( bIsTable )
@@ -2732,7 +2711,6 @@ void SwDoc::ChkCondColls()
      }
 }
 
-#ifdef FUTURE_VBA
 uno::Reference< script::vba::XVBAEventProcessor >
 SwDoc::GetVbaEventProcessor()
 {
@@ -2751,7 +2729,6 @@ SwDoc::GetVbaEventProcessor()
     }
     return mxVbaEvents;
 }
-#endif
 
 void SwDoc::setExternalData(::sw::tExternalDataType eType,
                             ::sw::tExternalDataPointer pPayload)
@@ -2763,3 +2740,5 @@ void SwDoc::setExternalData(::sw::tExternalDataType eType,
 {
     return m_externalData[eType];
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
