@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -51,7 +52,6 @@
 
 using namespace ::com::sun::star;
 
-
 class CompareLine
 {
 public:
@@ -194,12 +194,8 @@ public:
     Compare( ULONG nDiff, CompareData& rData1, CompareData& rData2 );
 };
 
-// ====================================================================
-
 CompareLine::~CompareLine() {}
 
-// ----------------------------------------------------------------------
-
 CompareData::CompareData()
     : pIndex( 0 ), pChangedFlag( 0 ), nSttLineNum( 0 )
 {
@@ -311,8 +307,6 @@ void CompareData::CheckForChangesInLine( const CompareData& ,
 {
 }
 
-// ----------------------------------------------------------------------
-
 Hash::Hash( ULONG nSize )
     : nCount( 1 )
 {
@@ -375,7 +369,7 @@ void Hash::CalcHashValue( CompareData& rData )
         for( ULONG n = 0; n < rData.GetLineCount(); ++n )
         {
             const CompareLine* pLine = rData.GetLine( n );
-            ASSERT( pLine, "wo ist die Line?" );
+            OSL_ENSURE( pLine, "wo ist die Line?" );
             ULONG nH = pLine->GetHashValue();
 
             ULONG* pFound = &pHashArr[ nH % nPrime ];
@@ -399,8 +393,6 @@ void Hash::CalcHashValue( CompareData& rData )
     }
 }
 
-// ----------------------------------------------------------------------
-
 Compare::Compare( ULONG nDiff, CompareData& rData1, CompareData& rData2 )
 {
     MovedData *pMD1, *pMD2;
@@ -447,8 +439,6 @@ Compare::Compare( ULONG nDiff, CompareData& rData1, CompareData& rData2 )
     delete pMD2;
 }
 
-
-
 void Compare::CountDifference( const CompareData& rData, ULONG* pCounts )
 {
     ULONG nLen = rData.GetLineCount();
@@ -587,8 +577,6 @@ void Compare::CheckDiscard( ULONG nLen, sal_Char* pDiscard )
     }
 }
 
-// ----------------------------------------------------------------------
-
 Compare::MovedData::MovedData( CompareData& rData, sal_Char* pDiscard )
     : pIndex( 0 ), pLineNum( 0 ), nCount( 0 )
 {
@@ -621,9 +609,7 @@ Compare::MovedData::~MovedData()
     delete pLineNum;
 }
 
-// ----------------------------------------------------------------------
-
-    // Suche die verschobenen Lines
+// Suche die verschobenen Lines
 Compare::CompareSequence::CompareSequence(
                             CompareData& rD1, CompareData& rD2,
                             const MovedData& rMD1, const MovedData& rMD2 )
@@ -839,8 +825,6 @@ void Compare::ShiftBoundaries( CompareData& rData1, CompareData& rData2 )
     }
 }
 
-/*  */
-
 class SwCompareLine : public CompareLine
 {
     const SwNode& rNode;
@@ -891,8 +875,6 @@ public:
     void SetRedlinesToDoc( BOOL bUseDocInfo );
 };
 
-// ----------------------------------------------------------------
-
 SwCompareLine::SwCompareLine( const SwNode& rNd )
     : rNode( rNd )
 {
@@ -1246,8 +1228,6 @@ BOOL SwCompareLine::ChangesInLine( const SwCompareLine& rLine,
     return bRet;
 }
 
-// ----------------------------------------------------------------
-
 SwCompareData::~SwCompareData()
 {
     if( pDelRing )
@@ -1292,7 +1272,6 @@ ULONG SwCompareData::PrevIdx( const SwNode* pNd )
     return pNd->GetIndex() - 1;
 }
 
-
 void SwCompareData::CheckRanges( CompareData& rData )
 {
     const SwNodes& rSrcNds = ((SwCompareData&)rData).rDoc.GetNodes();
@@ -1346,7 +1325,6 @@ void SwCompareData::CheckRanges( CompareData& rData )
     }
 }
 
-
 void SwCompareData::ShowInsert( ULONG nStt, ULONG nEnd )
 {
     SwPaM* pTmp = new SwPaM( ((SwCompareLine*)GetLine( nStt ))->GetNode(), 0,
@@ -1566,11 +1544,7 @@ void SwCompareData::SetRedlinesToDoc( BOOL bUseDocInfo )
     }
 }
 
-/*  */
-
-
-
-    // returnt (?die Anzahl der Unterschiede?) ob etwas unterschiedlich ist
+// returnt (?die Anzahl der Unterschiede?) ob etwas unterschiedlich ist
 long SwDoc::CompareDoc( const SwDoc& rDoc )
 {
     if( &rDoc == this )
@@ -1614,7 +1588,6 @@ long SwDoc::CompareDoc( const SwDoc& rDoc )
     return nRet;
 }
 
-
 typedef void (SwDoc::*FNInsUndo)( SwUndo* );
 
 class _SaveMergeRedlines : public Ring
@@ -1873,4 +1846,4 @@ long SwDoc::MergeDoc( const SwDoc& rDoc )
     return nRet;
 }
 
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
