@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -55,9 +56,7 @@
 #include <frmtool.hxx>
 #include <pagedesc.hxx>
 #include <poolfmt.hxx>
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
 #include <ndindex.hxx>
 #include <ftnidx.hxx>
 #include <fmtftn.hxx>
@@ -69,9 +68,7 @@
 #include <swwait.hxx>
 #include <GetMetricVal.hxx>
 #include <unotools/syslocale.hxx>
-#ifndef _STATSTR_HRC
 #include <statstr.hrc>
-#endif
 
 #include <SwUndoPageDesc.hxx>
 
@@ -199,7 +196,7 @@ void lcl_DescSetAttr( const SwFrmFmt &rSource, SwFrmFmt &rDest,
 
 void SwDoc::ChgPageDesc( USHORT i, const SwPageDesc &rChged )
 {
-    ASSERT( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
+    OSL_ENSURE( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
 
     SwPageDesc *pDesc = aPageDescs[i];
 
@@ -488,7 +485,7 @@ void SwDoc::PreDelPageDesc(SwPageDesc * pDel)
                     ((SwFmt*)pMod)->SetFmtAttr( aDfltDesc );
                 else
                 {
-                    ASSERT( !this, "was ist das fuer ein Mofify-Obj?" );
+                    OSL_ENSURE( !this, "was ist das fuer ein Mofify-Obj?" );
                     aPageDescs[0]->Add( pLast );
                 }
             }
@@ -557,8 +554,8 @@ void SwDoc::BroadcastStyleOperation(String rName, SfxStyleFamily eFamily,
 
 void SwDoc::DelPageDesc( USHORT i, BOOL bBroadcast )
 {
-    ASSERT( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
-    ASSERT( i != 0, "Default Pagedesc loeschen is nicht." );
+    OSL_ENSURE( i < aPageDescs.Count(), "PageDescs ueberindiziert." );
+    OSL_ENSURE( i != 0, "Default Pagedesc loeschen is nicht." );
     if ( i == 0 )
         return;
 
@@ -664,8 +661,8 @@ void SwDoc::PrtDataChanged()
 //!!!!!!!! Bei Aenderungen hier bitte ggf. InJobSetup im Sw3io mitpflegen
 
     // --> FME 2005-01-21 #i41075#
-    ASSERT( get(IDocumentSettingAccess::USE_VIRTUAL_DEVICE) ||
-            0 != getPrinter( sal_False ), "PrtDataChanged will be called recursive!" )
+    OSL_ENSURE( get(IDocumentSettingAccess::USE_VIRTUAL_DEVICE) ||
+            0 != getPrinter( sal_False ), "PrtDataChanged will be called recursive!" );
     // <--
 
     SwWait *pWait = 0;
@@ -1016,3 +1013,5 @@ sal_Bool SwDoc::IsSquaredPageMode() const
                         (const SwTextGridItem&)GetDefault( RES_TEXTGRID );
     return rGrid.IsSquaredMode();
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
