@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -357,7 +358,7 @@ BOOL SwDoc::SplitDoc( USHORT eDocType, const String& rPath,
                                 aTmp.Exchange();
                                 if( !aTmp.Move( fnMoveBackward, fnGoNode ))
                                 {
-                                    ASSERT( FALSE, "kein Node mehr vorhanden" );
+                                    OSL_ENSURE( FALSE, "kein Node mehr vorhanden" );
                                 }
                             }
                                 // Bookmarks usw. verschieben
@@ -708,7 +709,7 @@ BOOL SwDoc::SplitDoc( USHORT eDocType, const String& rPath, int nOutlineLevel )
                                 aTmp.Exchange();
                                 if( !aTmp.Move( fnMoveBackward, fnGoNode ))
                                 {
-                                    ASSERT( FALSE, "kein Node mehr vorhanden" );
+                                    OSL_ENSURE( FALSE, "kein Node mehr vorhanden" );
                                 }
                             }
                                 // Bookmarks usw. verschieben
@@ -853,3 +854,4 @@ BOOL SwDoc::SplitDoc( USHORT eDocType, const String& rPath, int nOutlineLevel )
     return pRet && pRet->GetValue();
 }//<-end,zhaojianwei
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
