@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -58,9 +59,7 @@
 #include <node2lay.hxx>
 #include <doctxm.hxx>
 #include <fmtftntx.hxx>
-#ifndef _COMCORE_HRC
 #include <comcore.hrc>
-#endif
 // --> OD 2005-12-01 #i27138#
 #include <viewsh.hxx>
 #include <txtfrm.hxx>
@@ -94,7 +93,7 @@ bool lcl_IsInSameTblBox( SwNodes& _rNds,
                  ? !_rNds.GoPrevSection( &aChkIdx, FALSE, FALSE )
                  : !_rNds.GoNextSection( &aChkIdx, FALSE, FALSE ) )
             {
-                ASSERT( false, "<lcl_IsInSameTblBox(..)> - no previous/next!" );
+                OSL_ENSURE( false, "<lcl_IsInSameTblBox(..)> - no previous/next!" );
                 return false;
             }
             else
@@ -167,7 +166,7 @@ SwDoc::InsertSwSection(SwPaM const& rRange, SwSectionData & rNewData,
     if( rRange.HasMark() &&
         0 == ( nRegionRet = IsInsRegionAvailable( rRange, &pPrvNd ) ))
     {
-        ASSERT( !this, "Selection ueber verschiedene Sections" );
+        OSL_ENSURE( !this, "Selection ueber verschiedene Sections" );
         return 0;
     }
 
@@ -213,7 +212,7 @@ SwDoc::InsertSwSection(SwPaM const& rRange, SwSectionData & rNewData,
                     *pEndPos = (SwPosition*)rRange.End();
         if( pPrvNd && 3 == nRegionRet )
         {
-            ASSERT( pPrvNd, "der SectionNode fehlt" );
+            OSL_ENSURE( pPrvNd, "der SectionNode fehlt" );
             SwNodeIndex aStt( pSttPos->nNode ), aEnd( pEndPos->nNode, +1 );
             while( pPrvNd != aStt.GetNode().StartOfSectionNode() )
                 aStt--;
@@ -834,7 +833,7 @@ SwSectionNode* SwNodes::InsertTextSection(SwNodeIndex const& rNdIdx,
     if( !pEnde )		// kein Bereich also neue Section davor/hinter anlegen
     {
         // #i26762#
-        ASSERT(!pEnde || rNdIdx <= *pEnde,
+        OSL_ENSURE(!pEnde || rNdIdx <= *pEnde,
                "Section start and end in wrong order!");
 
         if( bInsAtStart )
@@ -1057,7 +1056,7 @@ SwFrm* SwClearDummies( SwFrm* pFrm )
     SwFrm* pTmp = pFrm;
     while( pTmp )
     {
-        ASSERT( !pTmp->GetUpper(), "SwClearDummies: No Upper allowed!" );
+        OSL_ENSURE( !pTmp->GetUpper(), "SwClearDummies: No Upper allowed!" );
         if( pTmp->IsSctFrm() )
         {
             SwSectionFrm* pSectFrm = (SwSectionFrm*)pFrm;
@@ -1151,7 +1150,7 @@ void SwSectionNode::MakeFrms(const SwNodeIndex & rIdx )
             SwFrm *pFrm, *pNew;
             while( 0 != (pFrm = aNode2Layout.NextFrm()) )
             {
-                ASSERT( pFrm->IsSctFrm(), "Depend von Section keine Section." );
+                OSL_ENSURE( pFrm->IsSctFrm(), "Depend von Section keine Section." );
                 pNew = rIdx.GetNode().GetCntntNode()->MakeFrm();
 
                 SwSectionNode* pS = rIdx.GetNode().FindSectionNode();
@@ -1181,7 +1180,7 @@ void SwSectionNode::MakeFrms(const SwNodeIndex & rIdx )
                     SwLayoutFrm* pUp = pSct;
                     while( pUp->Lower() )  // for columned sections
                     {
-                        ASSERT( pUp->Lower()->IsLayoutFrm(),"Who's in there?" );
+                        OSL_ENSURE( pUp->Lower()->IsLayoutFrm(),"Who's in there?" );
                         pUp = (SwLayoutFrm*)pUp->Lower();
                     }
                     pNew->Paste( pUp, NULL );
@@ -1241,7 +1240,7 @@ void SwSectionNode::MakeFrms(const SwNodeIndex & rIdx )
 
 void SwSectionNode::MakeFrms( SwNodeIndex* pIdxBehind, SwNodeIndex* pEndIdx )
 {
-    ASSERT( pIdxBehind, "kein Index" );
+    OSL_ENSURE( pIdxBehind, "kein Index" );
     SwNodes& rNds = GetNodes();
     SwDoc* pDoc = rNds.GetDoc();
 
@@ -1311,7 +1310,7 @@ SwSectionNode* SwSectionNode::MakeCopy( SwDoc* pDoc, const SwNodeIndex& rIdx ) c
     ::std::auto_ptr<SwTOXBase> pTOXBase;
     if (TOX_CONTENT_SECTION == GetSection().GetType())
     {
-        ASSERT( GetSection().ISA( SwTOXBaseSection ), "no TOXBaseSection!" );
+        OSL_ENSURE( GetSection().ISA( SwTOXBaseSection ), "no TOXBaseSection!" );
         SwTOXBaseSection const& rTBS(
             dynamic_cast<SwTOXBaseSection const&>(GetSection()));
         pTOXBase.reset( new SwTOXBase(rTBS, pDoc) );
@@ -1379,7 +1378,7 @@ SwSectionNode* SwSectionNode::MakeCopy( SwDoc* pDoc, const SwNodeIndex& rIdx ) c
 
 BOOL SwSectionNode::IsCntntHidden() const
 {
-    ASSERT( !m_pSection->IsHidden(),
+    OSL_ENSURE( !m_pSection->IsHidden(),
             "That's simple: Hidden Section => Hidden Content" );
     SwNodeIndex aTmp( *this, 1 );
     ULONG nEnd = EndOfSectionIndex();
@@ -1396,7 +1395,7 @@ BOOL SwSectionNode::IsCntntHidden() const
         {
             if( aTmp.GetNode().IsCntntNode() || aTmp.GetNode().IsTableNode() )
                 return FALSE; // Nicht versteckter Inhalt wurde gefunden
-            ASSERT( aTmp.GetNode().IsEndNode(), "EndNode expected" );
+            OSL_ENSURE( aTmp.GetNode().IsEndNode(), "EndNode expected" );
         }
         aTmp++;
     }
@@ -1440,7 +1439,7 @@ void SwSectionNode::NodesArrChgd()
         // verschieben vom Nodes- ins UndoNodes-Array?
         if( rNds.IsDocNodes() )
         {
-            ASSERT( pDoc == GetDoc(),
+            OSL_ENSURE( pDoc == GetDoc(),
                     "verschieben in unterschiedliche Documente?" );
             if (m_pSection->IsLinkType())
             {
@@ -1520,3 +1519,4 @@ String SwDoc::GetUniqueSectionName( const String* pChkStr ) const
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
