@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -142,7 +143,7 @@ SwTxtNode* GetFirstTxtNode( const SwDoc& rDoc, SwPosition& rPos,
         while( 0 != (pCNd = rNodes.GoNext( &rPos.nNode ) ) &&
                 0 == ( pTxtNode = pCNd->GetTxtNode() ) )
                         ;
-        ASSERT( pTxtNode, "wo ist der 1.TextNode" );
+        OSL_ENSURE( pTxtNode, "wo ist der 1.TextNode" );
         rPos.nContent.Assign( pTxtNode, 0 );
     }
     else if ( !pCFrm->IsValid() )
@@ -171,7 +172,7 @@ const SwTxtNode* GetBodyTxtNode( const SwDoc& rDoc, SwPosition& rPos,
         {
             // hole das FlyFormat
             SwFrmFmt* pFlyFmt = ((SwFlyFrm*)pLayout)->GetFmt();
-            ASSERT( pFlyFmt, "kein FlyFormat gefunden, wo steht das Feld" );
+            OSL_ENSURE( pFlyFmt, "kein FlyFormat gefunden, wo steht das Feld" );
 
             const SwFmtAnchor &rAnchor = pFlyFmt->GetAnchor();
 
@@ -186,7 +187,7 @@ const SwTxtNode* GetBodyTxtNode( const SwDoc& rDoc, SwPosition& rPos,
                      (FLY_AT_CHAR == rAnchor.GetAnchorId()) ||
                      (FLY_AS_CHAR == rAnchor.GetAnchorId()))
             {
-                ASSERT( rAnchor.GetCntntAnchor(), "keine gueltige Position" );
+                OSL_ENSURE( rAnchor.GetCntntAnchor(), "keine gueltige Position" );
                 rPos = *rAnchor.GetCntntAnchor();
                 pTxtNode = rPos.nNode.GetNode().GetTxtNode();
                 if ( FLY_AT_PARA == rAnchor.GetAnchorId() )
@@ -339,7 +340,7 @@ void SwGetExpField::ChangeExpansion( const SwFrm& rFrm, const SwTxtFld& rFld )
     if( bIsInBodyTxt )		// nur Felder in Footer, Header, FootNote, Flys
         return;
 
-    ASSERT( !rFrm.IsInDocBody(), "Flag ist nicht richtig, Frame steht im DocBody" );
+    OSL_ENSURE( !rFrm.IsInDocBody(), "Flag ist nicht richtig, Frame steht im DocBody" );
 
     // bestimme mal das Dokument (oder geht es noch einfacher?)
     const SwTxtNode* pTxtNode = &rFld.GetTxtNode();
@@ -423,7 +424,7 @@ void SwGetExpField::SetLanguage(USHORT nLng)
 /*-----------------07.03.98 16:08-------------------
 
 --------------------------------------------------*/
-BOOL SwGetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwGetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -457,12 +458,12 @@ BOOL SwGetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
     default:
         return SwField::QueryValue(rAny, nWhichId);
     }
-    return TRUE;
+    return true;
 }
 /*-----------------07.03.98 16:08-------------------
 
 --------------------------------------------------*/
-BOOL SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
 {
     sal_Int32 nTmp = 0;
     String sTmp;
@@ -499,7 +500,7 @@ BOOL SwGetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
     default:
         return SwField::PutValue(rAny, nWhichId);
     }
-    return TRUE;
+    return true;
 }
 
 /*-----------------JP: 17.06.93 -------------------
@@ -645,7 +646,7 @@ void SwSetExpFieldType::SetChapter( SwSetExpField& rFld, const SwNode& rNd )
             }
             else
             {
-                ASSERT( false,
+                OSL_ENSURE( false,
                         "<SwSetExpFieldType::SetChapter(..)> - text node with numbering rule, but without number. This is a serious defect -> inform OD" );
             }
         }
@@ -655,7 +656,7 @@ void SwSetExpFieldType::SetChapter( SwSetExpField& rFld, const SwNode& rNd )
 /* -----------------24.03.99 09:44-------------------
  *
  * --------------------------------------------------*/
-BOOL SwSetExpFieldType::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwSetExpFieldType::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -677,10 +678,10 @@ BOOL SwSetExpFieldType::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
     default:
         DBG_ERROR("illegal property");
     }
-    return TRUE;
+    return true;
 }
 
-BOOL SwSetExpFieldType::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwSetExpFieldType::PutValue( const uno::Any& rAny, USHORT nWhichId )
 {
     switch( nWhichId )
     {
@@ -714,7 +715,7 @@ BOOL SwSetExpFieldType::PutValue( const uno::Any& rAny, USHORT nWhichId )
     default:
         DBG_ERROR("illegal property");
     }
-    return TRUE;
+    return true;
 }
 
 BOOL SwSeqFldList::InsertSort( _SeqFldLstElem* pNew )
@@ -1069,7 +1070,7 @@ String SwInputField::Expand() const
 /*-----------------06.03.98 11:12-------------------
 
 --------------------------------------------------*/
-BOOL SwInputField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwInputField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -1088,12 +1089,12 @@ BOOL SwInputField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
     default:
         DBG_ERROR("illegal property");
     }
-    return TRUE;
+    return true;
 }
 /*-----------------06.03.98 11:12-------------------
 
 --------------------------------------------------*/
-BOOL SwInputField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwInputField::PutValue( const uno::Any& rAny, USHORT nWhichId )
 {
     switch( nWhichId )
     {
@@ -1112,7 +1113,7 @@ BOOL SwInputField::PutValue( const uno::Any& rAny, USHORT nWhichId )
     default:
         DBG_ERROR("illegal property");
     }
-    return TRUE;
+    return true;
 }
 /*--------------------------------------------------------------------
     Beschreibung: Bedingung setzen
@@ -1179,7 +1180,7 @@ void SwInputField::SetSubType(USHORT nSub)
 /*-----------------05.03.98 17:22-------------------
 
 --------------------------------------------------*/
-BOOL SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
+bool SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
 {
     switch( nWhichId )
     {
@@ -1241,12 +1242,12 @@ BOOL SwSetExpField::QueryValue( uno::Any& rAny, USHORT nWhichId ) const
     default:
         return SwField::QueryValue(rAny, nWhichId);
     }
-    return TRUE;
+    return true;
 }
 /*-----------------05.03.98 17:22-------------------
 
 --------------------------------------------------*/
-BOOL SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
+bool SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
 {
     sal_Int32 nTmp32 = 0;
     sal_Int16 nTmp16 = 0;
@@ -1323,8 +1324,9 @@ BOOL SwSetExpField::PutValue( const uno::Any& rAny, USHORT nWhichId )
     default:
         return SwField::PutValue(rAny, nWhichId);
     }
-    return TRUE;
+    return true;
 }
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
