@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -103,8 +104,8 @@
  *
  * --------------------------------------------------*/
 
-#ifndef DBG_UTIL
-#error Wer fummelt denn an den makefiles rum?
+#if !defined(OSL_DEBUG_LEVEL) || OSL_DEBUG_LEVEL == 0
+#error Who broken the makefiles?
 #endif
 
 
@@ -136,7 +137,7 @@ SwImplProtocol* SwProtocol::pImpl = NULL;
 
 ULONG lcl_GetFrameId( const SwFrm* pFrm )
 {
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     static BOOL bFrameId = FALSE;
     if( bFrameId )
         return pFrm->GetFrmId();
@@ -864,3 +865,4 @@ void SwFrmChangesLeave::Leave()
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
