@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -47,9 +48,7 @@
 #include <sfx2/app.hxx>
 #include <sfx2/linkmgr.hxx>
 #include <unotools/configitem.hxx>
-#ifndef _OUTDEV_HXX //autogen
 #include <vcl/outdev.hxx>
-#endif
 #include <fmtanchr.hxx>
 #include <frmfmt.hxx>
 #include <doc.hxx>
@@ -58,9 +57,7 @@
 #include <section.hxx>
 #include <cntfrm.hxx>
 #include <frmatr.hxx>
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
 #include <ndole.hxx>
 
 #include <comphelper/classids.hxx>
@@ -68,9 +65,7 @@
 #include <sot/formats.hxx>
 #include <unotools/ucbstreamhelper.hxx>
 #include <svtools/filter.hxx>
-#ifndef _COMCORE_HRC
 #include <comcore.hrc>
-#endif
 
 using rtl::OUString;
 using namespace utl;
@@ -293,7 +288,7 @@ Graphic* SwOLENode::GetHCGraphic()
 SwCntntNode *SwOLENode::SplitCntntNode( const SwPosition & )
 {
     // OLE-Objecte vervielfaeltigen ??
-    ASSERT( FALSE, "OleNode: can't split." );
+    OSL_ENSURE( FALSE, "OleNode: can't split." );
     return this;
 }
 
@@ -310,7 +305,7 @@ BOOL SwOLENode::RestorePersistentData()
         {
             // TODO/LATER: reicht hier nicht ein EmbeddedObjectContainer? Was passiert mit
             // diesem Dokument?
-            ASSERT( !this, "warum wird hier eine DocShell angelegt?" );
+            OSL_ENSURE( !this, "warum wird hier eine DocShell angelegt?" );
             p = new SwDocShell( GetDoc(), SFX_CREATE_MODE_INTERNAL );
             p->DoInitNew( NULL );
         }
@@ -388,7 +383,7 @@ SwOLENode * SwNodes::MakeOLENode( const SwNodeIndex & rWhere,
                                     SwGrfFmtColl* pGrfColl,
                                     SwAttrSet* pAutoAttr )
 {
-    ASSERT( pGrfColl,"SwNodes::MakeOLENode: Formatpointer ist 0." );
+    OSL_ENSURE( pGrfColl,"SwNodes::MakeOLENode: Formatpointer ist 0." );
 
     SwOLENode *pNode =
         new SwOLENode( rWhere, xObj, pGrfColl, pAutoAttr );
@@ -410,7 +405,7 @@ SwOLENode * SwNodes::MakeOLENode( const SwNodeIndex & rWhere,
 SwOLENode * SwNodes::MakeOLENode( const SwNodeIndex & rWhere,
     const String &rName, sal_Int64 nAspect, SwGrfFmtColl* pGrfColl, SwAttrSet* pAutoAttr )
 {
-    ASSERT( pGrfColl,"SwNodes::MakeOLENode: Formatpointer ist 0." );
+    OSL_ENSURE( pGrfColl,"SwNodes::MakeOLENode: Formatpointer ist 0." );
 
     SwOLENode *pNode =
         new SwOLENode( rWhere, rName, nAspect, pGrfColl, pAutoAttr );
@@ -442,8 +437,8 @@ SwCntntNode* SwOLENode::MakeCopy( SwDoc* pDoc, const SwNodeIndex& rIdx ) const
     {
         // TODO/LATER: reicht hier nicht ein EmbeddedObjectContainer? Was passiert mit
         // diesem Dokument?
-        ASSERT( pDoc->GetRefForDocShell(),
-                        "wo ist die Ref-Klasse fuer die DocShell?")
+        OSL_ENSURE( pDoc->GetRefForDocShell(),
+                        "wo ist die Ref-Klasse fuer die DocShell?");
         p = new SwDocShell( pDoc, SFX_CREATE_MODE_INTERNAL );
         *pDoc->GetRefForDocShell() = p;
         p->DoInitNew( NULL );
@@ -751,7 +746,7 @@ void SwOLEObj::SetNode( SwOLENode* pNode )
         {
             // TODO/LATER: reicht hier nicht ein EmbeddedObjectContainer? Was passiert mit
             // diesem Dokument?
-            ASSERT( !this, "warum wird hier eine DocShell angelegt?" );
+            OSL_ENSURE( !this, "warum wird hier eine DocShell angelegt?" );
             p = new SwDocShell( pDoc, SFX_CREATE_MODE_INTERNAL );
             p->DoInitNew( NULL );
         }
@@ -786,10 +781,10 @@ uno::Reference < embed::XEmbeddedObject > SwOLEObj::GetOleRef()
     if( !xOLERef.is() )
     {
         SfxObjectShell* p = pOLENd->GetDoc()->GetPersist();
-        ASSERT( p, "kein SvPersist vorhanden" );
+        OSL_ENSURE( p, "kein SvPersist vorhanden" );
 
         uno::Reference < embed::XEmbeddedObject > xObj = p->GetEmbeddedObjectContainer().GetEmbeddedObject( aName );
-        ASSERT( !xOLERef.is(), "rekursiver Aufruf von GetOleRef() ist nicht erlaubt" )
+        OSL_ENSURE( !xOLERef.is(), "rekursiver Aufruf von GetOleRef() ist nicht erlaubt" );
 
         if ( !xObj.is() )
         {
@@ -843,7 +838,7 @@ BOOL SwOLEObj::UnloadObject()
 {
     BOOL bRet = TRUE;
     //Nicht notwendig im Doc DTor (MM)
-    //ASSERT( pOLERef && pOLERef->Is() && 1 < (*pOLERef)->GetRefCount(),
+    // OSL_ENSURE( pOLERef && pOLERef->Is() && 1 < (*pOLERef)->GetRefCount(),
     //        "Falscher RefCount fuers Unload" );
     if ( pOLENd )
     {
@@ -923,7 +918,7 @@ String SwOLEObj::GetDescription()
 
 SwOLELRUCache::SwOLELRUCache()
     : SvPtrarr( 64, 16 ),
-    utl::ConfigItem( OUString::createFromAscii( "Office.Common/Cache" )),
+    utl::ConfigItem(OUString(RTL_CONSTASCII_USTRINGPARAM("Office.Common/Cache"))),
     nLRU_InitSize( 20 ),
     bInUnload( sal_False )
 {
@@ -935,7 +930,7 @@ uno::Sequence< rtl::OUString > SwOLELRUCache::GetPropertyNames()
 {
     Sequence< OUString > aNames( 1 );
     OUString* pNames = aNames.getArray();
-    pNames[0] = OUString::createFromAscii( "Writer/OLE_Objects" );
+    pNames[0] = OUString(RTL_CONSTASCII_USTRINGPARAM("Writer/OLE_Objects"));
     return aNames;
 }
 
@@ -1016,3 +1011,5 @@ void SwOLELRUCache::RemoveObj( SwOLEObj& rObj )
     if( !Count() )
         DELETEZ( pOLELRU_Cache );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
