@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
  /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,9 +28,7 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-#ifndef _COM_SUN_STAR_I18N_SCRIPTTYPE_HDL_
 #include <com/sun/star/i18n/ScriptType.hdl>
-#endif
 #include <vcl/outdev.hxx>
 #include <IDocumentSettingAccess.hxx>
 
@@ -271,9 +270,9 @@ bool lcl_CheckKashidaWidth ( SwScriptInfo& rSI, SwTxtSizeInfo& rInf, SwTxtIter&
 void SwTxtAdjuster::CalcNewBlock( SwLineLayout *pCurrent,
                                   const SwLinePortion *pStopAt, SwTwips nReal, bool bSkipKashida )
 {
-    ASSERT( GetInfo().IsMulti() || SVX_ADJUST_BLOCK == GetAdjust(),
+    OSL_ENSURE( GetInfo().IsMulti() || SVX_ADJUST_BLOCK == GetAdjust(),
             "CalcNewBlock: Why?" );
-    ASSERT( pCurrent->Height(), "SwTxtAdjuster::CalcBlockAdjust: missing CalcLine()" );
+    OSL_ENSURE( pCurrent->Height(), "SwTxtAdjuster::CalcBlockAdjust: missing CalcLine()" );
 
     pCurrent->InitSpaceAdd();
     xub_StrLen nGluePortion = 0;
@@ -423,8 +422,8 @@ void SwTxtAdjuster::CalcNewBlock( SwLineLayout *pCurrent,
 
 SwTwips SwTxtAdjuster::CalcKanaAdj( SwLineLayout* pCurrent )
 {
-    ASSERT( pCurrent->Height(), "SwTxtAdjuster::CalcBlockAdjust: missing CalcLine()" );
-    ASSERT( !pCurrent->GetpKanaComp(), "pKanaComp already exists!!" );
+    OSL_ENSURE( pCurrent->Height(), "SwTxtAdjuster::CalcBlockAdjust: missing CalcLine()" );
+    OSL_ENSURE( !pCurrent->GetpKanaComp(), "pKanaComp already exists!!" );
 
     SvUShorts *pNewKana = new SvUShorts;
     pCurrent->SetKanaComp( pNewKana );
@@ -714,7 +713,7 @@ void SwTxtAdjuster::CalcFlyAdjust( SwLineLayout *pCurrent )
 
 void SwTxtAdjuster::CalcAdjLine( SwLineLayout *pCurrent )
 {
-    ASSERT( pCurrent->IsFormatAdj(), "CalcAdjLine: Why?" );
+    OSL_ENSURE( pCurrent->IsFormatAdj(), "CalcAdjLine: Why?" );
 
     pCurrent->SetFormatAdj(sal_False);
 
@@ -815,8 +814,8 @@ SwFlyPortion *SwTxtAdjuster::CalcFlyPortion( const long nRealWidth,
 
 void SwTxtAdjuster::CalcDropAdjust()
 {
-    ASSERT( 1<GetDropLines() && SVX_ADJUST_LEFT!=GetAdjust() && SVX_ADJUST_BLOCK!=GetAdjust(),
-            "CalcDropAdjust: No reason for DropAdjustment." )
+    OSL_ENSURE( 1<GetDropLines() && SVX_ADJUST_LEFT!=GetAdjust() && SVX_ADJUST_BLOCK!=GetAdjust(),
+            "CalcDropAdjust: No reason for DropAdjustment." );
 
     const MSHORT nLineNumber = GetLineNr();
 
@@ -917,3 +916,4 @@ void SwTxtAdjuster::CalcDropRepaint()
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
