@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -100,10 +101,10 @@ void SwTxtPainter::CtorInitTxtPainter( SwTxtFrm *pNewFrm, SwTxtPaintInfo *pNewIn
     pInf = pNewInf;
     SwFont *pMyFnt = GetFnt();
     GetInfo().SetFont( pMyFnt );
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     if( ALIGN_BASELINE != pMyFnt->GetAlign() )
     {
-        ASSERT( ALIGN_BASELINE == pMyFnt->GetAlign(),
+        OSL_ENSURE( ALIGN_BASELINE == pMyFnt->GetAlign(),
                 "+SwTxtPainter::CTOR: font alignment revolution" );
         pMyFnt->SetAlign( ALIGN_BASELINE );
     }
@@ -495,7 +496,7 @@ void SwTxtPainter::DrawTextLine( const SwRect &rPaint, SwSaveClip &rClip,
                 if( ( nDiff > 0 &&
                       ( GetEnd() < GetInfo().GetTxt().Len() ||
                         ( nDiff > nTmpHeight/2 && GetPrevLine() ) ) ) ||
-                    nDiff >= 0 && bNextUndersized )
+                    (nDiff >= 0 && bNextUndersized) )
 
                 {
                     SwArrowPortion aArrow( GetInfo() );
@@ -537,8 +538,8 @@ void SwTxtPainter::CheckSpecialUnderline( const SwLinePortion* pPor,
     Range aRange( 0, GetInfo().GetTxt().Len() );
     MultiSelection aUnderMulti( aRange );
 
-    ASSERT( GetFnt() && UNDERLINE_NONE != GetFnt()->GetUnderline(),
-            "CheckSpecialUnderline without underlined font" )
+    OSL_ENSURE( GetFnt() && UNDERLINE_NONE != GetFnt()->GetUnderline(),
+            "CheckSpecialUnderline without underlined font" );
     const SwFont* pParaFnt = GetAttrHandler().GetFont();
     if( pParaFnt && pParaFnt->GetUnderline() == GetFnt()->GetUnderline() )
         aUnderMulti.SelectAll();
@@ -716,3 +717,5 @@ void SwTxtPainter::CheckSpecialUnderline( const SwLinePortion* pPor,
         // I'm sorry, we do not have a special underlining font for you.
         GetInfo().SetUnderFnt( 0 );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
