@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -29,8 +30,8 @@
 #include "precompiled_sw.hxx"
 
 
-#ifndef DBG_UTIL
-#error Wer fummelt denn an den makefiles?
+#if !defined(OSL_DEBUG_LEVEL) || OSL_DEBUG_LEVEL == 0
+#error Who broke the makefiles?
 #endif
 
 #include "viewsh.hxx"       // IsDbg()
@@ -286,9 +287,14 @@ SvStream &operator<<( SvStream &rOs, const SwpHints & ) //$ ostream
 
 sal_Bool IsDbg( const SwTxtFrm *pFrm )
 {
+// Hmm, so IsTest4 etc are defined only if OSL_DEBUG_LEVEL > 1,
+// but this file is compiled if DBG_UTIL is defined. So should the IsTest4 etc
+// then instead be conditional on DBG_UTIL? Such crack.
+#if OSL_DEBUG_LEVEL > 1
     if( pFrm && pFrm->GetShell() )
         return pFrm->GetShell()->GetViewOptions()->IsTest4();
     else
+#endif
         return sal_False;
 }
 
@@ -298,7 +304,7 @@ static void Error()
 {
     // wegen PM und BCC
     sal_Bool bFalse = sal_False;
-    ASSERT( bFalse, "txtio: No debug version" );
+    OSL_ENSURE( bFalse, "txtio: No debug version" );
 }
 
 #define IMPL_OUTOP(class) \
@@ -459,7 +465,7 @@ const char *GetPrepName( const PrepareHint ePrep )
         pPREP_UL_SPACE, pPREP_MUST_FIT, pPREP_WIDOWS, pPREP_QUOVADIS,
         pPREP_PAGE
     };
-    ASSERT( ePrep < PREP_END, "GetPrepName: unknown PrepareHint" );
+    OSL_ENSURE( ePrep < PREP_END, "GetPrepName: unknown PrepareHint" );
     return( ppNameArr[ePrep] );
 }
 
@@ -947,3 +953,4 @@ SvStream &SwDropPortion::operator<<( SvStream &rOs ) const //$ ostream
 #endif /* OSL_DEBUG_LEVEL */
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
