@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -53,11 +54,6 @@
 #include <comcore.hrc> // #111827#
 #include <undo.hrc>
 
-// #include <editeng/svxacorr.hxx>
-// #include <comphelper/processfactory.hxx>
-// #include <editeng/unolingu.hxx>
-// #include <unotools/localedatawrapper.hxx>
-
 // using namespace comphelper;
 
 inline SwDoc& SwUndoIter::GetDoc() const { return *pAktPam->GetDoc(); }
@@ -143,7 +139,7 @@ SwUndoDelete::SwUndoDelete( SwPaM& rPam, BOOL bFullPara, BOOL bCalledByTblCpy )
     // Step 1. deletion/record of content indizes
     if( bDelFullPara )
     {
-        ASSERT( rPam.HasMark(), "PaM ohne Mark" );
+        OSL_ENSURE( rPam.HasMark(), "PaM ohne Mark" );
         DelCntntIndex( *rPam.GetMark(), *rPam.GetPoint(),
                         DelCntntType(nsDelCntntType::DELCNT_ALL | nsDelCntntType::DELCNT_CHKNOCNTNT) );
 
@@ -896,7 +892,7 @@ void SwUndoDelete::Redo( SwUndoIter& rUndoIter )
 
         if( bDelFullPara )
         {
-            ASSERT( rPam.HasMark(), "PaM ohne Mark" );
+            OSL_ENSURE( rPam.HasMark(), "PaM ohne Mark" );
             DelCntntIndex( *rPam.GetMark(), *rPam.GetPoint(),
                             DelCntntType(nsDelCntntType::DELCNT_ALL | nsDelCntntType::DELCNT_CHKNOCNTNT) );
 
@@ -912,7 +908,7 @@ void SwUndoDelete::Redo( SwUndoIter& rUndoIter )
     {
         if( bDelFullPara )
         {
-            ASSERT( rPam.HasMark(), "PaM ohne Mark" );
+            OSL_ENSURE( rPam.HasMark(), "PaM ohne Mark" );
             DelCntntIndex( *rPam.GetMark(), *rPam.GetPoint(),
                             DelCntntType(nsDelCntntType::DELCNT_ALL | nsDelCntntType::DELCNT_CHKNOCNTNT) );
 
@@ -1008,3 +1004,5 @@ void SwUndoDelete::SetTableName(const String & rName)
 {
     sTableName = rName;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
