@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -216,7 +217,7 @@ public:
         pDocSh( pDSh ),
         pHeaderAttrs( pDSh ? pDSh->GetHeaderAttributes() : 0 )
     {
-        ASSERT( pDocSh, "Keine DocShell, keine Controls" );
+        OSL_ENSURE( pDocSh, "Keine DocShell, keine Controls" );
     }
 
     const uno::Reference< XMultiServiceFactory >& GetServiceFactory();
@@ -285,7 +286,7 @@ const uno::Reference< XMultiServiceFactory >& SwHTMLForm_Impl::GetServiceFactory
         xServiceFactory =
             uno::Reference< XMultiServiceFactory >( pDocSh->GetBaseModel(),
                                                UNO_QUERY );
-        ASSERT( xServiceFactory.is(),
+        OSL_ENSURE( xServiceFactory.is(),
                 "XServiceFactory nicht vom Model erhalten" );
     }
     return xServiceFactory;
@@ -298,10 +299,10 @@ const uno::Reference< drawing::XDrawPage >& SwHTMLForm_Impl::GetDrawPage()
     {
         uno::Reference< drawing::XDrawPageSupplier > xTxtDoc( pDocSh->GetBaseModel(),
                                                          UNO_QUERY );
-        ASSERT( xTxtDoc.is(),
+        OSL_ENSURE( xTxtDoc.is(),
                 "drawing::XDrawPageSupplier nicht vom XModel erhalten" );
         xDrawPage = xTxtDoc->getDrawPage();
-        ASSERT( xDrawPage.is(), "drawing::XDrawPage nicht erhalten" );
+        OSL_ENSURE( xDrawPage.is(), "drawing::XDrawPage nicht erhalten" );
     }
     return xDrawPage;
 }
@@ -314,7 +315,7 @@ const uno::Reference< container::XIndexContainer >& SwHTMLForm_Impl::GetForms()
         if( xDrawPage.is() )
         {
             uno::Reference< XFormsSupplier > xFormsSupplier( xDrawPage, UNO_QUERY );
-            ASSERT( xFormsSupplier.is(),
+            OSL_ENSURE( xFormsSupplier.is(),
                     "XFormsSupplier nicht vom drawing::XDrawPage erhalten" );
 
             uno::Reference< container::XNameContainer > xNameCont =
@@ -322,7 +323,7 @@ const uno::Reference< container::XIndexContainer >& SwHTMLForm_Impl::GetForms()
             xForms = uno::Reference< container::XIndexContainer >( xNameCont,
                                                               UNO_QUERY );
 
-            ASSERT( xForms.is(), "XForms nicht erhalten" );
+            OSL_ENSURE( xForms.is(), "XForms nicht erhalten" );
         }
     }
     return xForms;
@@ -337,7 +338,7 @@ const uno::Reference< drawing::XShapes > & SwHTMLForm_Impl::GetShapes()
         if( xDrawPage.is() )
         {
             xShapes = uno::Reference< drawing::XShapes >( xDrawPage, UNO_QUERY );
-            ASSERT( xShapes.is(),
+            OSL_ENSURE( xShapes.is(),
                     "XShapes nicht vom drawing::XDrawPage erhalten" );
         }
     }
@@ -351,7 +352,7 @@ const uno::Reference< script::XEventAttacherManager >&
     {
         xControlEventManager =
             uno::Reference< script::XEventAttacherManager >( xFormComps, UNO_QUERY );
-        ASSERT( xControlEventManager.is(),
+        OSL_ENSURE( xControlEventManager.is(),
     "uno::Reference< XEventAttacherManager > nicht von xFormComps erhalten" );
     }
 
@@ -368,7 +369,7 @@ const uno::Reference< script::XEventAttacherManager >&
         {
             xFormEventManager =
                 uno::Reference< script::XEventAttacherManager >( xForms, UNO_QUERY );
-            ASSERT( xFormEventManager.is(),
+            OSL_ENSURE( xFormEventManager.is(),
         "uno::Reference< XEventAttacherManager > nicht von xForms erhalten" );
         }
     }
@@ -437,7 +438,7 @@ SwHTMLImageWatcher::SwHTMLImageWatcher(
     uno::Reference< awt::XControlModel > xControlModel(
             xControlShape->getControl() );
     xSrc = uno::Reference< XImageProducerSupplier >( xControlModel, UNO_QUERY );
-    ASSERT( xSrc.is(), "Kein XImageProducerSupplier" );
+    OSL_ENSURE( xSrc.is(), "Kein XImageProducerSupplier" );
 
     // Als Event-Listener am Shape anmelden, damit wir es beim dispose
     // loslassen konnen ...
@@ -476,7 +477,7 @@ void SwHTMLImageWatcher::clear()
 void SwHTMLImageWatcher::init( sal_Int32 Width, sal_Int32 Height )
     throw( uno::RuntimeException )
 {
-    ASSERT( bSetWidth || bSetHeight,
+    OSL_ENSURE( bSetWidth || bSetHeight,
             "Breite oder Hoehe muss angepasst werden" );
 
     // Wenn keine Breite oder Hoehe angegeben ist, ist das das init von
@@ -534,7 +535,7 @@ void SwHTMLImageWatcher::init( sal_Int32 Width, sal_Int32 Height )
                     xTunnel->getSomething(SwXShape::getUnoTunnelId()) ))
                 : 0;
 
-        ASSERT( pSwShape, "Wo ist das SW-Shape?" );
+        OSL_ENSURE( pSwShape, "Wo ist das SW-Shape?" );
         if( pSwShape )
         {
             SwFrmFmt *pFrmFmt = pSwShape->GetFrmFmt();
@@ -636,25 +637,25 @@ static void lcl_html_setFixedFontProperty(
                                     DEFAULTFONT_FLAGS_ONLYONE )  );
     Any aTmp;
     aTmp <<= OUString( aFixedFont.GetName() );
-    rPropSet->setPropertyValue( OUString::createFromAscii("FontName"), aTmp );
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("FontName")), aTmp );
 
     aTmp <<= OUString( aFixedFont.GetStyleName() );
-    rPropSet->setPropertyValue( OUString::createFromAscii("FontStyleName"),
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("FontStyleName")),
                                 aTmp );
 
     aTmp <<= (sal_Int16) aFixedFont.GetFamily();
-    rPropSet->setPropertyValue( OUString::createFromAscii("FontFamily"), aTmp );
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("FontFamily")), aTmp );
 
     aTmp <<= (sal_Int16) aFixedFont.GetCharSet();
-    rPropSet->setPropertyValue( OUString::createFromAscii("FontCharset"),
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("FontCharset")),
                                 aTmp );
 
     aTmp <<= (sal_Int16) aFixedFont.GetPitch();
-    rPropSet->setPropertyValue( OUString::createFromAscii("FontPitch"), aTmp );
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("FontPitch")), aTmp );
 
     float fVal(10.);
     aTmp.setValue( &fVal, ::getCppuType(&fVal ));
-    rPropSet->setPropertyValue( OUString::createFromAscii("FontHeight"), aTmp );
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("FontHeight")), aTmp );
 }
 
 class SwHTMLFormPendingStackData_Impl: public SwPendingStackData
@@ -683,14 +684,14 @@ public:
 
 void SwHTMLParser::SetPendingControlSize( int nToken )
 {
-    ASSERT( pPendStack, "Wo ist der Pending Stack?" );
+    OSL_ENSURE( pPendStack, "Wo ist der Pending Stack?" );
     SwHTMLFormPendingStackData_Impl *pData =
         (SwHTMLFormPendingStackData_Impl *)pPendStack->pData;
 
     SwPendingStack* pTmp = pPendStack->pNext;
     delete pPendStack;
     pPendStack = pTmp;
-    ASSERT( !pPendStack, "Wo kommt der Pending-Stack her?" );
+    OSL_ENSURE( !pPendStack, "Wo kommt der Pending-Stack her?" );
 
     SetControlSize( pData->GetShape(), pData->GetTextSize(),
                     pData->IsMinWidth(), pData->IsMinHeight(),
@@ -741,16 +742,16 @@ void SwHTMLParser::SetControlSize( const uno::Reference< drawing::XShape >& rSha
             xTunnel->getSomething(SwXShape::getUnoTunnelId()) ))
         : 0;
 
-    ASSERT( pSwShape, "Wo ist das SW-Shape?" );
+    OSL_ENSURE( pSwShape, "Wo ist das SW-Shape?" );
 
     // es muss ein Draw-Format sein
     SwFrmFmt *pFrmFmt = pSwShape->GetFrmFmt();
-    ASSERT( RES_DRAWFRMFMT == pFrmFmt->Which(), "Kein DrawFrmFmt" );
+    OSL_ENSURE( RES_DRAWFRMFMT == pFrmFmt->Which(), "Kein DrawFrmFmt" );
 
     // Schauen, ob es ein SdrObject dafuer gibt
     const SdrObject *pObj = pFrmFmt->FindSdrObject();
-    ASSERT( pObj, "SdrObject nicht gefunden" );
-    ASSERT( FmFormInventor == pObj->GetObjInventor(), "falscher Inventor" );
+    OSL_ENSURE( pObj, "SdrObject nicht gefunden" );
+    OSL_ENSURE( FmFormInventor == pObj->GetObjInventor(), "falscher Inventor" );
 
     const SdrView* pDrawView = pVSh ? pVSh->GetDrawView() : 0;
 
@@ -777,7 +778,7 @@ void SwHTMLParser::SetControlSize( const uno::Reference< drawing::XShape >& rSha
         if( rTextSz.Width() || rTextSz.Height())
         {
             uno::Reference< awt::XTextLayoutConstrains > xLC( xControl, UNO_QUERY );
-            ASSERT( xLC.is(), "kein XTextLayoutConstrains" );
+            OSL_ENSURE( xLC.is(), "kein XTextLayoutConstrains" );
             if( xLC.is() )
             {
                 awt::Size aTmpSz( rTextSz.Width(), rTextSz.Height() );
@@ -968,7 +969,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
 
         uno::Reference< XInterface > xCreate =
             rServiceFactory ->createInstance(
-                OUString::createFromAscii("com.sun.star.drawing.ControlShape"));
+        OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.drawing.ControlShape")));
         if( !xCreate.is() )
             return xShape;
 
@@ -1008,11 +1009,11 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             Any aAny2;
             aAny2 <<= (sal_Int32)nLeftSpace;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "LeftMargin" ), aAny2 );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("LeftMargin")), aAny2 );
 
             aAny2 <<= (sal_Int32)nRightSpace;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "RightMargin" ), aAny2 );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("RightMargin")), aAny2 );
         }
 
         // oberen/unteren Rand setzen
@@ -1039,16 +1040,16 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             uno::Any aAny2;
             aAny2 <<= (sal_Int32)nUpperSpace;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "TopMargin" ), aAny2 );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("TopMargin")), aAny2 );
 
             aAny2 <<= (sal_Int32)nLowerSpace;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "BottomMargin" ), aAny2 );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("BottomMargin")), aAny2 );
         }
 
         uno::Reference< beans::XPropertySetInfo > xPropSetInfo =
             rFCompPropSet->getPropertySetInfo();
-        OUString sPropName = OUString::createFromAscii( "BackgroundColor" );
+        OUString sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("BackgroundColor"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_BACKGROUND, sal_True,
                                                      &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1066,7 +1067,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
 
         }
 
-        sPropName = OUString::createFromAscii( "TextColor" );
+        sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("TextColor"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_CHRATR_COLOR, sal_True,
                                                      &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1076,7 +1077,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             rFCompPropSet->setPropertyValue( sPropName, aTmp );
         }
 
-        sPropName = OUString::createFromAscii( "FontHeight" );
+        sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontHeight"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_CHRATR_FONTSIZE,
                                                      sal_True, &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1091,31 +1092,31 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
                                                      &pItem ) )
         {
             const SvxFontItem *pFontItem = (SvxFontItem *)pItem;
-            sPropName = OUString::createFromAscii( "FontName" );
+            sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontName"));
             if( xPropSetInfo->hasPropertyByName( sPropName ) )
             {
                 aTmp <<= OUString( pFontItem->GetFamilyName() );
                 rFCompPropSet->setPropertyValue( sPropName, aTmp );
             }
-            sPropName = OUString::createFromAscii( "FontStyleName" );
+            sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontStyleName"));
             if( xPropSetInfo->hasPropertyByName( sPropName ) )
             {
                 aTmp <<= OUString( pFontItem->GetStyleName() );
                 rFCompPropSet->setPropertyValue( sPropName, aTmp );
             }
-            sPropName = OUString::createFromAscii( "FontFamily" );
+            sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontFamily"));
             if( xPropSetInfo->hasPropertyByName( sPropName ) )
             {
                 aTmp <<= (sal_Int16)pFontItem->GetFamily() ;
                 rFCompPropSet->setPropertyValue( sPropName, aTmp );
             }
-            sPropName = OUString::createFromAscii( "FontCharset" );
+            sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontCharset"));
             if( xPropSetInfo->hasPropertyByName( sPropName ) )
             {
                 aTmp <<= (sal_Int16)pFontItem->GetCharSet() ;
                 rFCompPropSet->setPropertyValue( sPropName, aTmp );
             }
-            sPropName = OUString::createFromAscii( "FontPitch" );
+            sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontPitch"));
             if( xPropSetInfo->hasPropertyByName( sPropName ) )
             {
                 aTmp <<= (sal_Int16)pFontItem->GetPitch() ;
@@ -1123,7 +1124,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             }
         }
 
-        sPropName = OUString::createFromAscii( "FontWeight" );
+        sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontWeight"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_CHRATR_WEIGHT,
                                                      sal_True, &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1134,7 +1135,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             rFCompPropSet->setPropertyValue( sPropName, aTmp );
         }
 
-        sPropName = OUString::createFromAscii( "FontSlant" );
+        sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontSlant"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_CHRATR_POSTURE,
                                                      sal_True, &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1143,7 +1144,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             rFCompPropSet->setPropertyValue( sPropName, aTmp );
         }
 
-        sPropName = OUString::createFromAscii( "FontUnderline" );
+        sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontUnderline"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_CHRATR_UNDERLINE,
                                                      sal_True, &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1152,7 +1153,7 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             rFCompPropSet->setPropertyValue( sPropName, aTmp );
         }
 
-        sPropName = OUString::createFromAscii( "FontStrikeout" );
+        sPropName = OUString(RTL_CONSTASCII_USTRINGPARAM("FontStrikeout"));
         if( SFX_ITEM_SET==rCSS1ItemSet.GetItemState( RES_CHRATR_CROSSEDOUT,
                                                      sal_True, &pItem ) &&
             xPropSetInfo->hasPropertyByName( sPropName ) )
@@ -1240,18 +1241,18 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             }
             aTmp <<= (sal_Int16)nVertOri ;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "VertOrient" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("VertOrient")), aTmp );
         }
 
         aTmp <<= (sal_Int16)nAnchorType ;
         xShapePropSet->setPropertyValue(
-                OUString::createFromAscii( "AnchorType" ), aTmp );
+            OUString(RTL_CONSTASCII_USTRINGPARAM("AnchorType")), aTmp );
 
         if( text::TextContentAnchorType_AT_PAGE == nAnchorType )
         {
             aTmp <<= (sal_Int16) 1 ;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "AnchorPageNo" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("AnchorPageNo")), aTmp );
         }
         else
         {
@@ -1264,30 +1265,30 @@ uno::Reference< drawing::XShape > SwHTMLParser::InsertControl(
             aTmp.setValue( &xTxtRg,
                            ::getCppuType((uno::Reference< text::XTextRange>*)0));
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "TextRange" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("TextRange")), aTmp );
         }
 
         if( bSetPos )
         {
             aTmp <<= (sal_Int16)text::HoriOrientation::NONE;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "HoriOrient" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("HoriOrient")), aTmp );
             aTmp <<= (sal_Int32)nXPos ;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "HoriOrientPosition" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("HoriOrientPosition")), aTmp );
 
             aTmp <<= (sal_Int16)text::VertOrientation::NONE;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "VertOrient" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("VertOrient")), aTmp );
             aTmp <<= (sal_Int32)nYPos ;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "VertOrientPosition" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("VertOrientPosition")), aTmp );
         }
         if( bSetSurround )
         {
             aTmp <<= (sal_Int16)nSurround ;
             xShapePropSet->setPropertyValue(
-                    OUString::createFromAscii( "Surround" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("Surround")), aTmp );
         }
 
         pFormImpl->GetShapes()->add(xShape);
@@ -1414,7 +1415,7 @@ void SwHTMLParser::NewForm( sal_Bool bAppend )
         return;
 
     uno::Reference< XInterface > xInt = rSrvcMgr->createInstance(
-            OUString::createFromAscii( "com.sun.star.form.component.Form" ) );
+        OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.form.component.Form")) );
     if( !xInt.is() )
         return;
 
@@ -1428,7 +1429,7 @@ void SwHTMLParser::NewForm( sal_Bool bAppend )
 
     Any aTmp;
     aTmp <<= OUString(sName);
-    xFormPropSet->setPropertyValue( OUString::createFromAscii( "Name" ), aTmp );
+    xFormPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Name")), aTmp );
 
     if( aAction.Len() )
     {
@@ -1441,24 +1442,24 @@ void SwHTMLParser::NewForm( sal_Bool bAppend )
         aAction = aURLObj.GetPartBeforeLastName();
     }
     aTmp <<= OUString(aAction);
-    xFormPropSet->setPropertyValue( OUString::createFromAscii( "TargetURL" ),
+    xFormPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("TargetURL")),
                                     aTmp );
 
     FormSubmitMethod eMethod = (FormSubmitMethod)nMethod;
     aTmp.setValue( &eMethod, ::getCppuType((const FormSubmitMethod*)0) );
-    xFormPropSet->setPropertyValue( OUString::createFromAscii( "SubmitMethod" ),
+    xFormPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("SubmitMethod")),
                                     aTmp );
 
      FormSubmitEncoding eEncType = (FormSubmitEncoding)nEncType;
     aTmp.setValue( &eEncType, ::getCppuType((const FormSubmitEncoding*)0) );
     xFormPropSet->setPropertyValue(
-            OUString::createFromAscii( "SubmitEncoding" ), aTmp );
+        OUString(RTL_CONSTASCII_USTRINGPARAM("SubmitEncoding")), aTmp );
 
     if( sTarget.Len() )
     {
         aTmp <<= OUString(sTarget);
         xFormPropSet->setPropertyValue(
-                OUString::createFromAscii( "TargetFrame" ), aTmp );
+            OUString(RTL_CONSTASCII_USTRINGPARAM("TargetFrame")), aTmp );
     }
 
     const uno::Reference< container::XIndexContainer > & rForms =
@@ -1712,7 +1713,7 @@ void SwHTMLParser::InsertInput()
         return;
 
     String sServiceName(
-            OUString::createFromAscii("com.sun.star.form.component.") );
+        OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.form.component.")) );
     sServiceName.AppendAscii( pType );
     uno::Reference< XInterface > xInt =
         rServiceFactory->createInstance( sServiceName );
@@ -1727,21 +1728,21 @@ void SwHTMLParser::InsertInput()
 
     Any aTmp;
     aTmp <<= OUString(sName);
-    xPropSet->setPropertyValue( OUString::createFromAscii( "Name" ), aTmp );
+    xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Name")), aTmp );
 
     if( HTML_IT_HIDDEN != eType  )
     {
         if( nTabIndex >= TABINDEX_MIN && nTabIndex <= TABINDEX_MAX  )
         {
             aTmp <<= (sal_Int16) (sal_Int16)nTabIndex ;
-            xPropSet->setPropertyValue( OUString::createFromAscii( "TabIndex" ), aTmp );
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("TabIndex")), aTmp );
         }
 
         if( bDisabled )
         {
             BOOL bFalse = sal_False;
             aTmp.setValue(&bFalse, ::getBooleanCppuType()  );
-            xPropSet->setPropertyValue( OUString::createFromAscii( "Enabled" ), aTmp );
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Enabled")), aTmp );
         }
     }
 
@@ -1758,10 +1759,10 @@ void SwHTMLParser::InsertInput()
         {
             if( !bValue )
                 aTmp <<= OUString::createFromAscii( OOO_STRING_SVTOOLS_HTML_on );
-            xPropSet->setPropertyValue( OUString::createFromAscii( "RefValue" ),
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("RefValue")),
                                         aTmp );
             aTmp <<= OUString();
-            xPropSet->setPropertyValue( OUString::createFromAscii( "Label" ),
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Label")),
                                         aTmp );
             // #53559#: Beim RadioButton darf die DefaultChecked-Property
             // erst gesetzt werden, wenn das Control angelegt und ein
@@ -1771,7 +1772,7 @@ void SwHTMLParser::InsertInput()
             {
                 aTmp <<= (sal_Int16) nChecked ;
                 xPropSet->setPropertyValue(
-                        OUString::createFromAscii( "DefaultState" ), aTmp );
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultState")), aTmp );
             }
 
             SvxMacro *pMacro = aMacroTbl.Get( HTML_ET_ONCLICK );
@@ -1800,10 +1801,10 @@ void SwHTMLParser::InsertInput()
             aTmp.setValue( &eButtonType,
                            ::getCppuType((const FormButtonType*)0));
             xPropSet->setPropertyValue(
-                    OUString::createFromAscii( "ButtonType" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("ButtonType")), aTmp );
 
             aTmp <<= (sal_Int16) 0  ;
-            xPropSet->setPropertyValue( OUString::createFromAscii( "Border" ),
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Border")),
                                         aTmp );
         }
         break;
@@ -1832,13 +1833,13 @@ void SwHTMLParser::InsertInput()
                 ;
             }
             aTmp <<= OUString(sText);
-            xPropSet->setPropertyValue( OUString::createFromAscii( "Label" ),
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Label")),
                                         aTmp );
 
             aTmp.setValue( &eButtonType,
                            ::getCppuType((const FormButtonType*)0));
             xPropSet->setPropertyValue(
-                            OUString::createFromAscii( "ButtonType" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("ButtonType")), aTmp );
 
             bMinWidth = bMinHeight = sal_True;
             bUseSize = sal_True;
@@ -1852,19 +1853,19 @@ void SwHTMLParser::InsertInput()
         {
         // Beim File-Control wird der VALUE aus Sicherheitsgruenden ignoriert.
             xPropSet->setPropertyValue(
-                    OUString::createFromAscii( "DefaultText" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultText")), aTmp );
             if( nMaxLen != 0 )
             {
                 aTmp <<= (sal_Int16) nMaxLen ;
                 xPropSet->setPropertyValue(
-                        OUString::createFromAscii( "MaxTextLen" ), aTmp );
+                    OUString(RTL_CONSTASCII_USTRINGPARAM("MaxTextLen")), aTmp );
             }
         }
 
         if( HTML_IT_PASSWORD == eType )
         {
             aTmp <<= (sal_Int16)'*' ;
-            xPropSet->setPropertyValue( OUString::createFromAscii( "EchoChar" ),
+            xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("EchoChar")),
                                         aTmp );
         }
 
@@ -1877,7 +1878,7 @@ void SwHTMLParser::InsertInput()
         break;
 
     case HTML_IT_HIDDEN:
-        xPropSet->setPropertyValue( OUString::createFromAscii( "HiddenValue" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("HiddenValue")),
                                     aTmp );
         bHidden = sal_True;
         break;
@@ -1893,7 +1894,7 @@ void SwHTMLParser::InsertInput()
             aNewSz = Application::GetDefaultDevice()
                         ->PixelToLogic( aNewSz, MapMode( MAP_100TH_MM ) );
             aSz.Width() = aNewSz.Width();
-            ASSERT( !aTextSz.Width(), "Text-Breite ist gegeben" );
+            OSL_ENSURE( !aTextSz.Width(), "Text-Breite ist gegeben" );
             bMinWidth = sal_False;
         }
     }
@@ -1951,14 +1952,14 @@ void SwHTMLParser::InsertInput()
                                              bHidden );
     if( aTextSz.Width() || aTextSz.Height() || bMinWidth || bMinHeight )
     {
-        ASSERT( !(bSetGrfWidth || bSetGrfHeight), "Grafikgroesse anpassen???" );
+        OSL_ENSURE( !(bSetGrfWidth || bSetGrfHeight), "Grafikgroesse anpassen???" );
         SetControlSize( xShape, aTextSz, bMinWidth, bMinHeight, HTML_INPUT );
     }
 
     if( HTML_IT_RADIO == eType )
     {
         aTmp <<= (sal_Int16) nChecked ;
-        xPropSet->setPropertyValue( OUString::createFromAscii( "DefaultState" ), aTmp );
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultState")), aTmp );
     }
 
     if( HTML_IT_IMAGE == eType )
@@ -1967,7 +1968,7 @@ void SwHTMLParser::InsertInput()
         // Download der Grafik erst dann am XModel anmelden kann,
         // wenn das Control eingefuegt ist.
         aTmp <<= OUString( URIHelper::SmartRel2Abs(INetURLObject(sBaseURL), sImgSrc, Link(), false));
-        xPropSet->setPropertyValue( OUString::createFromAscii( "ImageURL" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("ImageURL")),
                                     aTmp );
     }
 
@@ -1988,8 +1989,8 @@ void SwHTMLParser::NewTextArea()
         return;
     }
 
-    ASSERT( !bTextArea, "TextArea in TextArea???" );
-    ASSERT( !pFormImpl || !pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( !bTextArea, "TextArea in TextArea???" );
+    OSL_ENSURE( !pFormImpl || !pFormImpl->GetFCompPropSet().is(),
             "TextArea in Control???" );
 
     if( !pFormImpl || !pFormImpl->GetFormComps().is() )
@@ -2116,7 +2117,7 @@ void SwHTMLParser::NewTextArea()
         return;
     }
     uno::Reference< uno::XInterface >  xInt = rSrvcMgr->createInstance(
-        OUString::createFromAscii( "com.sun.star.form.component.TextField" ) );
+        OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.form.component.TextField")) );
     if( !xInt.is() )
     {
         FinishTextArea();
@@ -2130,24 +2131,24 @@ void SwHTMLParser::NewTextArea()
 
     Any aTmp;
     aTmp <<= OUString(sName);
-    xPropSet->setPropertyValue( OUString::createFromAscii( "Name" ), aTmp );
+    xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Name")), aTmp );
 
     BOOL bTrue = sal_True;
     aTmp.setValue( &bTrue, ::getBooleanCppuType() );
-    xPropSet->setPropertyValue( OUString::createFromAscii( "MultiLine" ),
+    xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("MultiLine")),
                                 aTmp );
-    xPropSet->setPropertyValue( OUString::createFromAscii( "VScroll" ), aTmp );
+    xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("VScroll")), aTmp );
     if( HTML_WM_OFF == nWrap )
-        xPropSet->setPropertyValue( OUString::createFromAscii( "HScroll" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("HScroll")),
                                     aTmp );
     if( HTML_WM_HARD == nWrap )
         xPropSet->setPropertyValue(
-                OUString::createFromAscii( "HardLineBreaks" ), aTmp );
+            OUString(RTL_CONSTASCII_USTRINGPARAM("HardLineBreaks")), aTmp );
 
     if( nTabIndex >= TABINDEX_MIN && nTabIndex <= TABINDEX_MAX  )
     {
         aTmp <<= (sal_Int16)nTabIndex ;
-        xPropSet->setPropertyValue( OUString::createFromAscii( "TabIndex" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("TabIndex")),
                                     aTmp );
     }
 
@@ -2157,11 +2158,11 @@ void SwHTMLParser::NewTextArea()
     {
         BOOL bFalse = sal_False;
         aTmp.setValue( &bFalse, ::getBooleanCppuType() );
-        xPropSet->setPropertyValue( OUString::createFromAscii( "Enabled" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Enabled")),
                                     aTmp );
     }
 
-    ASSERT( !pFormImpl->GetText().Len(), "Text ist nicht leer!" );
+    OSL_ENSURE( !pFormImpl->GetText().Len(), "Text ist nicht leer!" );
 
     if( !nCols )
         nCols = 20;
@@ -2217,8 +2218,8 @@ void SwHTMLParser::NewTextArea()
 
 void SwHTMLParser::EndTextArea()
 {
-    ASSERT( bTextArea, "keine TextArea oder falscher Typ" );
-    ASSERT( pFormImpl && pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( bTextArea, "keine TextArea oder falscher Typ" );
+    OSL_ENSURE( pFormImpl && pFormImpl->GetFCompPropSet().is(),
             "TextArea fehlt" );
 
     const uno::Reference< beans::XPropertySet > & rPropSet =
@@ -2226,7 +2227,7 @@ void SwHTMLParser::EndTextArea()
 
     Any aTmp;
     aTmp <<= OUString(pFormImpl->GetText());
-    rPropSet->setPropertyValue( OUString::createFromAscii( "DefaultText" ),
+    rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultText")),
                                 aTmp );
     pFormImpl->EraseText();
 
@@ -2247,8 +2248,8 @@ void SwHTMLParser::EndTextArea()
 
 void SwHTMLParser::InsertTextAreaText( sal_uInt16 nToken )
 {
-    ASSERT( bTextArea, "keine TextArea oder falscher Typ" );
-    ASSERT( pFormImpl && pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( bTextArea, "keine TextArea oder falscher Typ" );
+    OSL_ENSURE( pFormImpl && pFormImpl->GetFCompPropSet().is(),
             "TextArea fehlt" );
 
     String& rText = pFormImpl->GetText();
@@ -2283,8 +2284,8 @@ void SwHTMLParser::NewSelect()
         return;
     }
 
-    ASSERT( !bSelect, "Select in Select???" );
-    ASSERT( !pFormImpl || !pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( !bSelect, "Select in Select???" );
+    OSL_ENSURE( !pFormImpl || !pFormImpl->GetFCompPropSet().is(),
             "Select in Control???" );
 
     if( !pFormImpl || !pFormImpl->GetFormComps().is() )
@@ -2396,7 +2397,7 @@ void SwHTMLParser::NewSelect()
         return;
     }
     uno::Reference< uno::XInterface >  xInt = rSrvcMgr->createInstance(
-        OUString::createFromAscii( "com.sun.star.form.component.ListBox" ) );
+        OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.form.component.ListBox")) );
     if( !xInt.is() )
     {
         FinishTextArea();
@@ -2410,12 +2411,12 @@ void SwHTMLParser::NewSelect()
 
     Any aTmp;
     aTmp <<= OUString(sName);
-    xPropSet->setPropertyValue( OUString::createFromAscii( "Name" ), aTmp );
+    xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Name")), aTmp );
 
     if( nTabIndex >= TABINDEX_MIN && nTabIndex <= TABINDEX_MAX  )
     {
         aTmp <<= (sal_Int16)nTabIndex ;
-        xPropSet->setPropertyValue( OUString::createFromAscii( "TabIndex" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("TabIndex")),
                                     aTmp );
     }
 
@@ -2423,7 +2424,7 @@ void SwHTMLParser::NewSelect()
     {
         BOOL bFalse = sal_False;
         aTmp.setValue( &bFalse, ::getBooleanCppuType() );
-        xPropSet->setPropertyValue( OUString::createFromAscii( "Enabled" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Enabled")),
                                     aTmp );
     }
 
@@ -2433,7 +2434,7 @@ void SwHTMLParser::NewSelect()
     {
         BOOL bTrue = sal_True;
         aTmp.setValue( &bTrue, ::getBooleanCppuType() );
-        xPropSet->setPropertyValue( OUString::createFromAscii( "Dropdown" ),
+        xPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("Dropdown")),
                                     aTmp );
     }
     else
@@ -2446,7 +2447,7 @@ void SwHTMLParser::NewSelect()
             BOOL bTrue = sal_True;
             aTmp.setValue( &bTrue, ::getBooleanCppuType() );
             xPropSet->setPropertyValue(
-                    OUString::createFromAscii( "MultiSelection" ), aTmp );
+                OUString(RTL_CONSTASCII_USTRINGPARAM("MultiSelection")), aTmp );
         }
         aTextSz.Height() = nSelectEntryCnt;
         bMinHeight = sal_False;
@@ -2509,8 +2510,8 @@ void SwHTMLParser::EndSelect()
         return;
     }
 
-    ASSERT( bSelect, "keine Select" );
-    ASSERT( pFormImpl && pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( bSelect, "keine Select" );
+    OSL_ENSURE( pFormImpl && pFormImpl->GetFCompPropSet().is(),
             "kein Select-Control" );
 
     const uno::Reference< beans::XPropertySet > & rPropSet =
@@ -2541,15 +2542,15 @@ void SwHTMLParser::EndSelect()
         Any aAny( &aList, ::getCppuType((uno::Sequence<OUString>*)0) );
 
         rPropSet->setPropertyValue(
-                OUString::createFromAscii( "StringItemList" ), aAny );
+            OUString(RTL_CONSTASCII_USTRINGPARAM("StringItemList")), aAny );
 
         aAny <<= ListSourceType_VALUELIST;
         rPropSet->setPropertyValue(
-                OUString::createFromAscii( "ListSourceType" ), aAny );
+            OUString(RTL_CONSTASCII_USTRINGPARAM("ListSourceType")), aAny );
 
         aAny.setValue( &aValueList, ::getCppuType((uno::Sequence<OUString>*)0) );
 
-        rPropSet->setPropertyValue( OUString::createFromAscii( "ListSource" ),
+        rPropSet->setPropertyValue( OUString(RTL_CONSTASCII_USTRINGPARAM("ListSource")),
                                     aAny );
 
         sal_uInt16 nSelCnt = pFormImpl->GetSelectedList().Count();
@@ -2570,7 +2571,7 @@ void SwHTMLParser::EndSelect()
                        ::getCppuType((uno::Sequence<sal_Int16>*)0) );
 
         rPropSet->setPropertyValue(
-                OUString::createFromAscii( "DefaultSelection" ), aAny );
+            OUString(RTL_CONSTASCII_USTRINGPARAM("DefaultSelection")), aAny );
 
         pFormImpl->EraseStringList();
         pFormImpl->EraseValueList();
@@ -2580,7 +2581,7 @@ void SwHTMLParser::EndSelect()
 
     if( bFixSelectWidth )
     {
-        ASSERT( pFormImpl->GetShape().is(), "Kein Shape gemerkt" );
+        OSL_ENSURE( pFormImpl->GetShape().is(), "Kein Shape gemerkt" );
         Size aTextSz( -1, 0 );
         SetControlSize( pFormImpl->GetShape(), aTextSz, sal_False, sal_False,
                         HTML_SELECT_OFF );
@@ -2602,8 +2603,8 @@ void SwHTMLParser::EndSelect()
 
 void SwHTMLParser::InsertSelectOption()
 {
-    ASSERT( bSelect, "keine Select" );
-    ASSERT( pFormImpl && pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( bSelect, "keine Select" );
+    OSL_ENSURE( pFormImpl && pFormImpl->GetFCompPropSet().is(),
             "kein Select-Control" );
 
     bLBEntrySelected = sal_False;
@@ -2639,8 +2640,8 @@ void SwHTMLParser::InsertSelectOption()
 
 void SwHTMLParser::InsertSelectText()
 {
-    ASSERT( bSelect, "keine Select" );
-    ASSERT( pFormImpl && pFormImpl->GetFCompPropSet().is(),
+    OSL_ENSURE( bSelect, "keine Select" );
+    OSL_ENSURE( pFormImpl && pFormImpl->GetFCompPropSet().is(),
             "kein Select-Control" );
 
     sal_uInt16 nEntryCnt = pFormImpl->GetStringList().Count();
@@ -2659,3 +2660,4 @@ void SwHTMLParser::InsertSelectText()
     }
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
