@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -31,9 +32,7 @@
 
 #include <stdlib.h>
 
-#ifndef _SVX_SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
 #include <i18npool/mslangid.hxx>
 #include <svtools/ctrltool.hxx>
 #include <svl/urihelper.hxx>
@@ -185,13 +184,13 @@ static CSS1PropertyEnum __READONLY_DATA aBorderWidthTable[] =
     { 0,					0	}
 };
 
-enum CSS1BorderStyle { CSS1_BS_NONE, CSS1_BS_SINGLE, CSS1_BS_DOUBLE };
+enum CSS1BorderStyle { CSS1_BS_NONE, CSS1_BS_SINGLE, CSS1_BS_DOUBLE, CSS1_BS_DOTTED, CSS1_BS_DASHED };
 
 static CSS1PropertyEnum __READONLY_DATA aBorderStyleTable[] =
 {
     { sCSS1_PV_none,		CSS1_BS_NONE		},
-    { sCSS1_PV_dotted, 		CSS1_BS_SINGLE		},
-    { sCSS1_PV_dashed, 		CSS1_BS_SINGLE		},
+    { sCSS1_PV_dotted, 		CSS1_BS_DOTTED		},
+    { sCSS1_PV_dashed, 		CSS1_BS_DASHED		},
     { sCSS1_PV_solid, 		CSS1_BS_SINGLE		},
     { sCSS1_PV_double, 		CSS1_BS_DOUBLE		},
     { sCSS1_PV_groove, 		CSS1_BS_SINGLE		},
@@ -369,6 +368,12 @@ void SvxCSS1BorderInfo::SetBorderLine( USHORT nLine, SvxBoxItem &rBoxItem ) cons
 
     // Linien-Stil doppelt oder einfach?
     BOOL bDouble = eStyle == CSS1_BS_DOUBLE;
+    if ( eStyle == CSS1_BS_DOTTED )
+        aBorderLine.SetStyle( DOTTED );
+    else if ( eStyle == CSS1_BS_DASHED )
+        aBorderLine.SetStyle( DASHED );
+    else
+        aBorderLine.SetStyle( SOLID );
 
     // benannte Breite umrechnenen, wenn keine absolute gegeben ist
     if( nAbsWidth==USHRT_MAX )
@@ -1092,12 +1097,10 @@ static void ParseCSS1_font_size( const CSS1Expression *pExpr,
             nHeight = (ULONG)nPHeight;
         }
         break;
-//#ifdef PERCENTAGE_POSSIBLE
     case CSS1_PERCENTAGE:
         // nur fuer Drop-Caps!
         nPropHeight = (USHORT)pExpr->GetNumber();
         break;
-//#endif
     case CSS1_IDENT:
         {
             USHORT nSize;
@@ -3309,3 +3312,5 @@ void SvxCSS1Parser::ParseProperty( const String& rProperty,
         (((CSS1PropEntry*)pFound)->pFunc)( pExpr, *pItemSet, *pPropInfo, *this );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
