@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -80,17 +81,13 @@
 #include <swtable.hxx>
 #include <fldbas.hxx>
 #include <fmtclds.hxx>
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
 #include <wrthtml.hxx>
 #include <htmlnum.hxx>
 #include <htmlfly.hxx>
 #include <swmodule.hxx>
 
-#ifndef _STATSTR_HRC
 #include <statstr.hrc>		// ResId fuer Statusleiste
-#endif
 #include <swerror.h>
 
 #define MAX_INDENT_LEVEL 20
@@ -216,7 +213,7 @@ ULONG SwHTMLWriter::WriteStream()
     sal_Bool bOldHTMLMode = sal_False;
     sal_uInt16 nOldTxtFmtCollCnt = 0, nOldCharFmtCnt = 0;
 
-    ASSERT( !pTemplate, "Wo kommt denn die HTML-Vorlage hier her?" );
+    OSL_ENSURE( !pTemplate, "Wo kommt denn die HTML-Vorlage hier her?" );
     pTemplate = ((HTMLReader*)ReadHTML)->GetTemplateDoc();
     if( pTemplate )
     {
@@ -308,7 +305,7 @@ ULONG SwHTMLWriter::WriteStream()
             }
             else
             {
-                ASSERT( FILE_LINK_SECTION != pSNd->GetSection().GetType(),
+                OSL_ENSURE( FILE_LINK_SECTION != pSNd->GetSection().GetType(),
                         "Export gelinkter Bereiche am Dok-Anfang ist nicht implemntiert" );
 
                 // nur das Tag fuer die Section merken
@@ -391,7 +388,7 @@ ULONG SwHTMLWriter::WriteStream()
 
     // loesche die Tabelle mit den freifliegenden Rahmen
     sal_uInt16 i;
-    ASSERT( !pHTMLPosFlyFrms, "Wurden nicht alle Rahmen ausgegeben" );
+    OSL_ENSURE( !pHTMLPosFlyFrms, "Wurden nicht alle Rahmen ausgegeben" );
     if( pHTMLPosFlyFrms )
     {
         pHTMLPosFlyFrms->DeleteAndDestroy( 0, pHTMLPosFlyFrms->Count() );
@@ -437,7 +434,7 @@ ULONG SwHTMLWriter::WriteStream()
     delete pxFormComps;
     pxFormComps = 0;
 
-    ASSERT( !pFootEndNotes,
+    OSL_ENSURE( !pFootEndNotes,
             "SwHTMLWriter::Write: Ftns nicht durch OutFootEndNotes geloescht" );
 
     pCurrPageDesc = 0;
@@ -459,13 +456,13 @@ ULONG SwHTMLWriter::WriteStream()
         sal_uInt16 nTxtFmtCollCnt = pTemplate->GetTxtFmtColls()->Count();
         while( nTxtFmtCollCnt > nOldTxtFmtCollCnt )
             pTemplate->DelTxtFmtColl( --nTxtFmtCollCnt );
-        ASSERT( pTemplate->GetTxtFmtColls()->Count() == nOldTxtFmtCollCnt,
+        OSL_ENSURE( pTemplate->GetTxtFmtColls()->Count() == nOldTxtFmtCollCnt,
                 "falsche Anzahl TxtFmtColls geloescht" );
 
         sal_uInt16 nCharFmtCnt = pTemplate->GetCharFmts()->Count();
         while( nCharFmtCnt > nOldCharFmtCnt )
             pTemplate->DelCharFmt( --nCharFmtCnt );
-        ASSERT( pTemplate->GetCharFmts()->Count() == nOldCharFmtCnt,
+        OSL_ENSURE( pTemplate->GetCharFmts()->Count() == nOldCharFmtCnt,
                 "falsche Anzahl CharFmts geloescht" );
 
         // HTML-Modus wieder restaurieren
@@ -532,7 +529,7 @@ void lcl_html_OutSectionStartTag( SwHTMLWriter& rHTMLWrt,
                                   const SwFmtCol *pCol,
                                   sal_Bool bContinued=sal_False )
 {
-    ASSERT( pCol || !bContinued, "Continuation of DIV" );
+    OSL_ENSURE( pCol || !bContinued, "Continuation of DIV" );
 
     if( rHTMLWrt.bLFPossible )
         rHTMLWrt.OutNewLine();
@@ -659,7 +656,7 @@ static Writer& OutHTML_Section( Writer& rWrt, const SwSectionNode& rSectNd )
 
     const SwSection& rSection = rSectNd.GetSection();
     const SwSectionFmt *pFmt = rSection.GetFmt();
-    ASSERT( pFmt, "Section without a format?" );
+    OSL_ENSURE( pFmt, "Section without a format?" );
 
     sal_Bool bStartTag = sal_True;
     sal_Bool bEndTag = sal_True;
@@ -758,7 +755,7 @@ void SwHTMLWriter::Out_SwDoc( SwPaM* pPam )
         {
             SwNode * pNd = pCurPam->GetNode();
 
-            ASSERT( !(pNd->IsGrfNode() || pNd->IsOLENode()),
+            OSL_ENSURE( !(pNd->IsGrfNode() || pNd->IsOLENode()),
                     "Grf- oder OLE-Node hier unerwartet" );
             if( pNd->IsTxtNode() )
             {
@@ -885,7 +882,7 @@ sal_uInt16 SwHTMLWriter::OutHeaderAttrs()
             0==(pTxtNd=pDoc->GetNodes()[nIdx]->GetTxtNode()) )
         nIdx++;
 
-    ASSERT( pTxtNd, "Kein Text-Node gefunden" );
+    OSL_ENSURE( pTxtNd, "Kein Text-Node gefunden" );
     if( !pTxtNd || !pTxtNd->HasHints() )
         return 0;
 
@@ -1437,3 +1434,4 @@ void GetHTMLWriter( const String&, const String& rBaseURL, WriterRef& xRet )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
