@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,17 +28,13 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
 
 #include <ctype.h>
 #include <hintids.hxx>
 
-#ifndef _COM_SUN_STAR_I18N_SCRIPTTYPE_HDL_
+#include <sal/macros.h>
 #include <com/sun/star/i18n/ScriptType.hdl>
-#endif
-#ifndef _GRAPH_HXX //autogen
 #include <vcl/graph.hxx>
-#endif
 #include <svl/urihelper.hxx>
 #include <svtools/rtftoken.h>
 #include <svl/zforlist.hxx>
@@ -60,9 +57,7 @@
 #include <docufld.hxx>
 #include <flddat.hxx>
 #include <charfmt.hxx>
-#ifndef _fmtruby_HXX
 #include <fmtruby.hxx>
-#endif
 #include <breakit.hxx>
 #include <reffld.hxx>
 #include <SwStyleNameMapper.hxx>
@@ -144,14 +139,14 @@ static RTF_FLD_TYPES _WhichFld( String& rName, String& rNext )
 
     String sNm( rName );
     sNm = sNm.EraseLeadingChars().GetToken(0, ' ');
-    ASSERT( sNm.Len(), "Feldname hat keine Laenge!" );
+    OSL_ENSURE( sNm.Len(), "Feldname hat keine Laenge!" );
     if( !sNm.Len() )
         return RTFFLD_UNKNOWN;
 
     xub_StrLen nTokenStt = rName.Search( sNm );
     sNm.ToLowerAscii();
 
-    for (size_t n = 0; n < sizeof(aFldNmArr) / sizeof(aFldNmArr[0]); ++n)
+    for (size_t n = 0; n < SAL_N_ELEMENTS(aFldNmArr); ++n)
     {
         const sal_Char* pCmp = aFldNmArr[n].pFldNm;
         int nLen = *pCmp++;
@@ -186,7 +181,7 @@ static USHORT CheckNumberFmtStr( const String& rNStr )
         "\x04""PAGE"              /* PAGEDESC          */
     };
 
-    ASSERT(sizeof(aNumberTypeTab) / sizeof(sal_Char *)
+    OSL_ENSURE(sizeof(aNumberTypeTab) / sizeof(sal_Char *)
            >= SVX_NUM_PAGEDESC - SVX_NUM_CHARS_UPPER_LETTER, "impossible");
 
     for (USHORT n = SVX_NUM_CHARS_UPPER_LETTER;  n <= SVX_NUM_PAGEDESC; ++n)
@@ -1053,7 +1048,7 @@ void SwRTFParser::ReadField()
                         {
                             const SwField *pFld = pFldAttr->GetFld().GetFld();
                             SwFieldType *pTyp = pFld ? pFld->GetTyp() : 0;
-                            ASSERT(pTyp->Which() == RES_USERFLD, "expected a user field");
+                            OSL_ENSURE(pTyp->Which() == RES_USERFLD, "expected a user field");
                             if (pTyp->Which() == RES_USERFLD)
                             {
                                 SwUserFieldType *pUsrTyp = (SwUserFieldType*)pTyp;
@@ -1228,4 +1223,4 @@ INSINGLECHAR:
     SkipToken( -1 );		// die schliesende Klammer wird "oben" ausgewertet
 }
 
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
