@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -520,7 +521,7 @@ SprmDumpInfo& WW8GetSprmDumpInfo( USHORT nId )
     if( !bInit )
     {
         qsort( (void*)aSprmDumpTab,
-            sizeof( aSprmDumpTab      ) / sizeof (aSprmDumpTab[ 0 ]),
+            SAL_N_ELEMENTS(aSprmDumpTab),
             sizeof( aSprmDumpTab[ 0 ] ),
             CompSprmDumpId );
         bInit = TRUE;
@@ -531,7 +532,7 @@ SprmDumpInfo& WW8GetSprmDumpInfo( USHORT nId )
     aSrch.nId = nId;
     if( 0 == ( pFound = bsearch( (char *) &aSrch,
                         (void*) aSprmDumpTab,
-                        sizeof( aSprmDumpTab      ) / sizeof (aSprmDumpTab[ 0 ]),
+                        SAL_N_ELEMENTS(aSprmDumpTab),
                         sizeof( aSprmDumpTab[ 0 ] ),
                         CompSprmDumpId )))
     {
@@ -544,3 +545,4 @@ SprmDumpInfo& WW8GetSprmDumpInfo( USHORT nId )
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
