@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -27,7 +28,6 @@
 
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
-/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil -*- */
 
 #include <com/sun/star/util/XCloseable.hpp>
 
@@ -233,7 +233,7 @@ namespace sw
                 }
                 else
                 {
-                    ASSERT(!this, "Impossible");
+                    OSL_ENSURE(!this, "Impossible");
                     meWriterType = eTxtBox;
                 }
                 break;
@@ -248,7 +248,7 @@ namespace sw
                 }
                 else
                 {
-                    ASSERT(!this, "Impossible");
+                    OSL_ENSURE(!this, "Impossible");
                     meWriterType = eDrawing;
                 }
                 break;
@@ -303,7 +303,7 @@ namespace sw
 
         bool DrawingOLEAdaptor::TransferToDoc( ::rtl::OUString &rName )
         {
-            ASSERT(mxIPRef.is(), "Transferring invalid object to doc");
+            OSL_ENSURE(mxIPRef.is(), "Transferring invalid object to doc");
             if (!mxIPRef.is())
                 return false;
 
@@ -466,9 +466,21 @@ namespace sw
         }
         //SetLayer boilerplate end
 
-        void GetPoolItems(const SfxItemSet &rSet, PoolItems &rItems)
+        void GetPoolItems(const SfxItemSet &rSet, PoolItems &rItems, bool bExportParentItemSet )
         {
-            if (rSet.Count())
+            if( bExportParentItemSet )
+            {
+                USHORT nTotal = rSet.TotalCount();
+                for( USHORT nItem =0; nItem < nTotal; ++nItem )
+                {
+                    const SfxPoolItem* pItem = 0;
+                    if( SFX_ITEM_SET == rSet.GetItemState( rSet.GetWhichByPos( nItem ), true, &pItem ) )
+                    {
+                        rItems[pItem->Which()] = pItem;
+                    }
+                }
+            }
+            else if( rSet.Count())
             {
                 SfxItemIter aIter(rSet);
                 if (const SfxPoolItem *pItem = aIter.GetCurItem())
@@ -567,21 +579,6 @@ namespace sw
             return aRet;
         }
 
-#if 0        
-        Frames GetFramesBetweenNodes(const Frames &rFrames,
-            const SwNode &rStart, const SwNode &rEnd)
-        {
-            Frames aRet;
-            ULONG nEnd = rEnd.GetIndex();
-            for (ULONG nI = rStart.GetIndex(); nI < nEnd; ++nI)
-            {
-                my_copy_if(rFrames.begin(), rFrames.end(),
-                    std::back_inserter(aRet), anchoredto(nI));
-            }
-            return aRet;
-
-        }
-#endif
         Frames GetFramesInNode(const Frames &rFrames, const SwNode &rNode)
         {
             Frames aRet;
@@ -601,7 +598,7 @@ namespace sw
                 return &(pRule->Get( static_cast< USHORT >(rTxtNode.GetActualListLevel()) ));
             }
 
-            ASSERT(rTxtNode.GetDoc(), "No document for node?, suspicious");
+            OSL_ENSURE(rTxtNode.GetDoc(), "No document for node?, suspicious");
             if (!rTxtNode.GetDoc())
                 return 0;
 
@@ -639,7 +636,7 @@ namespace sw
         SwNoTxtNode *GetNoTxtNodeFromSwFrmFmt(const SwFrmFmt &rFmt)
         {
             const SwNodeIndex *pIndex = rFmt.GetCntnt().GetCntntIdx();
-            ASSERT(pIndex, "No NodeIndex in SwFrmFmt ?, suspicious");
+            OSL_ENSURE(pIndex, "No NodeIndex in SwFrmFmt ?, suspicious");
             if (!pIndex)
                 return 0;
             SwNodeIndex aIdx(*pIndex, 1);
@@ -653,7 +650,7 @@ namespace sw
             {
                 const SwTable& rTable = rNd.GetTableNode()->GetTable();
                 const SwFrmFmt* pApply = rTable.GetFrmFmt();
-                ASSERT(pApply, "impossible");
+                OSL_ENSURE(pApply, "impossible");
                 if (pApply)
                     pBreak = &(ItemGet<SvxFmtBreakItem>(*pApply, RES_BREAK));
             }
@@ -731,13 +728,13 @@ namespace sw
                 }
             }
 
-            ASSERT(aGrTwipSz.Width() && aGrTwipSz.Height(), "0 x 0 graphic ?");
+            OSL_ENSURE(aGrTwipSz.Width() && aGrTwipSz.Height(), "0 x 0 graphic ?");
             return aGrTwipSz;
         }
 
         void RedlineStack::open(const SwPosition& rPos, const SfxPoolItem& rAttr)
         {
-            ASSERT(rAttr.Which() == RES_FLTR_REDLINE, "not a redline");
+            OSL_ENSURE(rAttr.Which() == RES_FLTR_REDLINE, "not a redline");
             maStack.push_back(new SwFltStackEntry(rPos,rAttr.Clone()));
         }
 
@@ -856,4 +853,5 @@ namespace sw
 */
     }
 }
-/* vi:set tabstop=4 shiftwidth=4 expandtab: */
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
