@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,7 +31,7 @@
 #include <hintids.hxx>
 #include <tools/urlobj.hxx>
 
-#include <tools/debug.hxx>
+#include <osl/diagnose.h>
 #include <tools/link.hxx>
 
 #define _SVSTDARR_STRINGSDTOR
@@ -71,9 +72,7 @@
 #include <srcview.hxx>
 #include <wrtsh.hxx>
 #include <docsh.hxx>
-#ifndef _CMDID_H
 #include <cmdid.h>		  	// Funktion-Ids
-#endif
 #include <initui.hxx>
 #include <uitool.hxx>
 #include <swmodule.hxx>
@@ -87,9 +86,7 @@
 #include <prtopt.hxx>
 #include <modcfg.hxx>
 #include <globals.h>		// globale Konstanten z.B.
-#ifndef _APP_HRC
 #include <app.hrc>
-#endif
 #include <fontcfg.hxx>
 #include <barcfg.hxx>
 #include <uinums.hxx>
@@ -209,15 +206,12 @@ void SwModule::StateOther(SfxItemSet &rSet)
                                             IsInsTblFormatNum( bWebView )));
             break;
             default:
-                DBG_ERROR("::StateOther: default");
+                OSL_ENSURE(false, "::StateOther: default");
         }
         nWhich = aIter.NextWhich();
     }
 }
 
-/*-- 06.04.2004 15:21:43---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 SwView* lcl_LoadDoc(SwView* pView, const String& rURL)
 {
     SwView* pNewView = 0;
@@ -304,20 +298,20 @@ SwMailMergeWizardExecutor::SwMailMergeWizardExecutor()
 
 SwMailMergeWizardExecutor::~SwMailMergeWizardExecutor()
 {
-    DBG_ASSERT( m_pWizard == 0, "SwMailMergeWizardExecutor: m_pWizard must be Null!" );
-    DBG_ASSERT( m_pMMConfig == 0, "SwMailMergeWizardExecutor: m_pMMConfig must be Null!" );
+    OSL_ENSURE( m_pWizard == 0, "SwMailMergeWizardExecutor: m_pWizard must be Null!" );
+    OSL_ENSURE( m_pMMConfig == 0, "SwMailMergeWizardExecutor: m_pMMConfig must be Null!" );
 }
 
 void SwMailMergeWizardExecutor::ExecuteMailMergeWizard( const SfxItemSet * pArgs )
 {
     if ( m_pView )
     {
-        DBG_ERROR( "SwMailMergeWizardExecutor::ExecuteMailMergeWizard: Already executing the wizard!" );
+        OSL_ENSURE(false, "SwMailMergeWizardExecutor::ExecuteMailMergeWizard: Already executing the wizard!" );
         return;
     }
 
     m_pView = ::GetActiveView(); // not owner!
-    DBG_ASSERT(m_pView, "no current view?");
+    OSL_ENSURE(m_pView, "no current view?");
     if(m_pView)
     {
         // keep self alive until done.
@@ -338,7 +332,7 @@ void SwMailMergeWizardExecutor::ExecuteMailMergeWizard( const SfxItemSet * pArgs
             m_pView->SetMailMergeConfigItem(0, 0, sal_True);
             SfxViewFrame* pViewFrame = m_pView->GetViewFrame();
             pViewFrame->ShowChildWindow(FN_MAILMERGE_CHILDWINDOW, FALSE);
-            DBG_ASSERT(m_pMMConfig, "no MailMergeConfigItem available");
+            OSL_ENSURE(m_pMMConfig, "no MailMergeConfigItem available");
             bRestoreWizard = true;
         }
         // to make it bullet proof ;-)
@@ -434,7 +428,7 @@ IMPL_LINK( SwMailMergeWizardExecutor, EndDialogHdl, AbstractMailMergeWizard*, EM
 #endif
 {
 #if OSL_DEBUG_LEVEL > 1
-    DBG_ASSERT( pDialog == m_pWizard, "wrong dialog passed to EndDialogHdl!" );
+    OSL_ENSURE( pDialog == m_pWizard, "wrong dialog passed to EndDialogHdl!" );
     (void) pDialog;
 #endif
 
@@ -476,7 +470,7 @@ IMPL_LINK( SwMailMergeWizardExecutor, EndDialogHdl, AbstractMailMergeWizard*, EM
             uno::Reference< frame::XFrame > xFrame =
                 m_pView->GetViewFrame()->GetFrame().GetFrameInterface();
             xFrame->getContainerWindow()->setVisible(sal_False);
-            DBG_ASSERT(pTargetView, "No target view has been created");
+            OSL_ENSURE(pTargetView, "No target view has been created");
             if(pTargetView)
             {
                 // destroy wizard asynchronously
@@ -515,7 +509,7 @@ IMPL_LINK( SwMailMergeWizardExecutor, EndDialogHdl, AbstractMailMergeWizard*, EM
         {
             SwView* pTargetView = m_pMMConfig->GetTargetView();
             SwView* pSourceView = m_pMMConfig->GetSourceView();
-            DBG_ASSERT(pTargetView && pSourceView, "source or target view not available" );
+            OSL_ENSURE(pTargetView && pSourceView, "source or target view not available" );
             if(pTargetView && pSourceView)
             {
                 m_pView2Close = pTargetView;
@@ -685,11 +679,11 @@ void SwModule::ExecOther(SfxRequest& rReq)
 }
 
 /*--------------------------------------------------------------------
-    Beschreibung: Notifies abfangen
+    Beschreibung: Catch notifications
  --------------------------------------------------------------------*/
 
 
-    // Hint abfangen fuer DocInfo
+// Catch hint for DocInfo
 void SwModule::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
 {
     if( rHint.ISA( SfxEventHint ) )
@@ -701,14 +695,6 @@ void SwModule::Notify( SfxBroadcaster& /*rBC*/, const SfxHint& rHint )
             SwWrtShell* pWrtSh = pDocSh ? pDocSh->GetWrtShell() : 0;
             switch( rEvHint.GetEventId() )
             {
-/*          MA 07. Mar. 96: UpdateInputFlds() nur noch bei Dokument neu.
-                                (Und bei Einfuegen Textbaust.)
-                case SFX_EVENT_OPENDOC:
-                // dann am aktuellen Dokument die Input-Fedler updaten
-                if( pWrtSh )
-                    pWrtSh->UpdateInputFlds();
-                break;
-*/
             case SFX_EVENT_CREATEDOC:
                 // alle FIX-Date/Time Felder auf akt. setzen
                 if( pWrtSh )
@@ -807,7 +793,7 @@ void SwModule::ConfigurationChanged( utl::ConfigurationBroadcaster* pBrdCst, sal
         if(!nNew || !nOld)
         {
             sal_Bool bUndo = nNew != 0;
-            //ueber DocShells iterieren und Undo umschalten
+            // Iterate through DocShells and switch undos
 
             TypeId aType(TYPE(SwDocShell));
             SwDocShell* pDocShell = (SwDocShell*)SfxObjectShell::GetFirst(&aType);
@@ -872,18 +858,13 @@ void SwModule::ConfigurationChanged( utl::ConfigurationBroadcaster* pBrdCst, sal
 
 }
 
-/* -----------------------------20.02.01 12:43--------------------------------
-
- ---------------------------------------------------------------------------*/
 SwDBConfig*	SwModule::GetDBConfig()
 {
     if(!pDBConfig)
         pDBConfig = new SwDBConfig;
     return pDBConfig;
 }
-/* -----------------------------11.04.2002 15:27------------------------------
 
- ---------------------------------------------------------------------------*/
 svtools::ColorConfig& SwModule::GetColorConfig()
 {
     if(!pColorConfig)
@@ -894,9 +875,7 @@ svtools::ColorConfig& SwModule::GetColorConfig()
     }
     return *pColorConfig;
 }
-/* -----------------------------06.05.2002 09:42------------------------------
 
- ---------------------------------------------------------------------------*/
 SvtAccessibilityOptions& SwModule::GetAccessibilityOptions()
 {
     if(!pAccessibilityOptions)
@@ -906,9 +885,7 @@ SvtAccessibilityOptions& SwModule::GetAccessibilityOptions()
     }
     return *pAccessibilityOptions;
 }
-/* -----------------06.05.2003 14:52-----------------
 
- --------------------------------------------------*/
 SvtCTLOptions& SwModule::GetCTLOptions()
 {
     if(!pCTLOptions)
@@ -918,9 +895,7 @@ SvtCTLOptions& SwModule::GetCTLOptions()
     }
     return *pCTLOptions;
 }
-/* -----------------07.07.2003 09:31-----------------
 
- --------------------------------------------------*/
 SvtUserOptions& SwModule::GetUserOptions()
 {
     if(!pUserOptions)
@@ -930,9 +905,7 @@ SvtUserOptions& SwModule::GetUserOptions()
     }
     return *pUserOptions;
 }
-/* -----------------18.07.2003 13:31-----------------
 
- --------------------------------------------------*/
 SvtUndoOptions& SwModule::GetUndoOptions()
 {
     if(!pUndoOptions)
@@ -942,9 +915,7 @@ SvtUndoOptions& SwModule::GetUndoOptions()
     }
     return *pUndoOptions;
 }
-/*-----------------30.01.97 08.30-------------------
 
---------------------------------------------------*/
 const SwMasterUsrPref *SwModule::GetUsrPref(sal_Bool bWeb) const
 {
     SwModule* pNonConstModule = (SwModule*)this;
@@ -980,3 +951,5 @@ void NewXForms( SfxRequest& rReq )
     // set return value
     rReq.SetReturnValue( SfxVoidItem( rReq.GetSlot() ) );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
