@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,18 +29,14 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 #include <hintids.hxx>
-#ifndef _CMDID_H
 #include <cmdid.h>		  	// Funktion-Ids
-#endif
 
 #include <com/sun/star/i18n/ScriptType.hpp>
 
 #define _SVSTDARR_STRINGSDTOR
 #include <svl/svstdarr.hxx>
 
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <svl/eitem.hxx>
 #include <sfx2/request.hxx>
 #include <sfx2/app.hxx>
@@ -47,9 +44,7 @@
 #include <svx/htmlmode.hxx>
 #include <sfx2/bindings.hxx>
 #include <editeng/brshitem.hxx>
-#ifndef _SVX_TSTPITEM_HXX //autogen
 #include <editeng/tstpitem.hxx>
-#endif
 #include <svx/optgrid.hxx>
 #include <svx/svxdlg.hxx>
 #include <svx/dialogs.hrc>
@@ -59,37 +54,25 @@
 #include <optcomp.hxx>
 #include <edtwin.hxx>
 #include <swmodule.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <wrtsh.hxx>
-#ifndef IDOCUMENTDEVICEACCESS_HXX_INCLUDED
 #include <IDocumentDeviceAccess.hxx>
-#endif
 #include <uitool.hxx>
 #include <initui.hxx>					// fuer ::GetGlossaries()
 #include <fldbas.hxx>	   //fuer UpdateFields
-#ifndef _WVIEW_HXX
 #include <wview.hxx>
-#endif
 #include <cfgitems.hxx>
 #include <prtopt.hxx>
-#ifndef _PVIEW_HXX
 #include <pview.hxx>
-#endif
 #include <usrpref.hxx>
-#ifndef _MODCFG_HXX
 #include <modcfg.hxx>
-#endif
 #include <glosdoc.hxx>
 #include <uiitems.hxx>
 #include <editeng/langitem.hxx>
 #include <unotools/lingucfg.hxx>
 #include <editeng/unolingu.hxx>
 
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
 #include <globals.h>		// globale Konstanten z.B.
 #include <svl/slstitm.hxx>
 #include "swabstdlg.hxx"
@@ -100,10 +83,6 @@
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::lang;
 
-/* -----------------12.02.99 12:28-------------------
- *
- * --------------------------------------------------*/
-
 SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
 {
     BOOL bTextDialog = (nId == SID_SW_EDITOPTIONS) ? TRUE : FALSE;
@@ -128,9 +107,7 @@ SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
         }
 
     /********************************************************************/
-    /*																	*/
-    /* Optionen/Bearbeiten  											*/
-    /*																	*/
+    /* Options/Edit                                              */
     /********************************************************************/
     SfxItemSet*	pRet = new SfxItemSet (GetPool(),	FN_PARAM_DOCDISP,		FN_PARAM_ELEM,
                                     SID_PRINTPREVIEW, 		SID_PRINTPREVIEW,
@@ -149,7 +126,7 @@ SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
                                     SID_ATTR_LANGUAGE,      SID_ATTR_LANGUAGE,
                                     SID_ATTR_CHAR_CJK_LANGUAGE,   SID_ATTR_CHAR_CJK_LANGUAGE,
                                     SID_ATTR_CHAR_CTL_LANGUAGE, SID_ATTR_CHAR_CTL_LANGUAGE,
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
                                     FN_PARAM_SWTEST,		FN_PARAM_SWTEST,
 #endif
                                     0);
@@ -182,15 +159,6 @@ SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
     }
     else
     {
-/* 		Der Drucker wird jetzt von der TabPage erzeugt und auch geloescht
- * 		SfxItemSet* pSet = new SfxItemSet( SFX_APP()->GetPool(),
-                    SID_PRINTER_NOTFOUND_WARN, SID_PRINTER_NOTFOUND_WARN,
-                    SID_PRINTER_CHANGESTODOC, SID_PRINTER_CHANGESTODOC,
-                    0 );
-
-        pPrt = new SfxPrinter(pSet);
-        pRet->Put(SwPtrItem(FN_PARAM_PRINTER, pPrt));*/
-
         SvtLinguConfig aLinguCfg;
         Locale aLocale;
         LanguageType nLang;
@@ -244,10 +212,7 @@ SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
             pRet->Put(SfxUInt16Item( SID_ATTR_DEFTABSTOP, (UINT16)pPref->GetDefTab()));
     }
 
-    /*-----------------01.02.97 11.13-------------------
-    Optionen fuer GridTabPage
-    --------------------------------------------------*/
-
+    // Options for GridTabPage
     SvxGridItem aGridItem( SID_ATTR_GRID_OPTIONS);
 
     aGridItem.SetUseGridSnap( aViewOpt.IsSnap());
@@ -263,9 +228,7 @@ SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
 
     pRet->Put(aGridItem);
 
-    /*-----------------01.02.97 13.02-------------------
-        Optionen fuer PrintTabPage
-    --------------------------------------------------*/
+    // Options for PrintTabPage
     SwPrintData* pOpt = pAppView ?
                         pAppView->GetWrtShell().getIDocumentDeviceAccess()->getPrintData() :
                         0;
@@ -276,42 +239,17 @@ SfxItemSet*	 SwModule::CreateItemSet( USHORT nId )
     SwAddPrinterItem aAddPrinterItem (FN_PARAM_ADDPRINTER, *pOpt );
     pRet->Put(aAddPrinterItem);
 
-    /*-----------------01.02.97 13.12-------------------
-        Optionen fuer Web-Hintergrund
-    --------------------------------------------------*/
+    // Options for Web background
     if(!bTextDialog)
     {
         pRet->Put(SvxBrushItem(aViewOpt.GetRetoucheColor(), RES_BACKGROUND));
     }
 
-#ifdef DBG_UTIL
-    /*-----------------01.02.97 13.02-------------------
-        Test-Optionen
-    --------------------------------------------------*/
-        SwTestItem aTestItem(FN_PARAM_SWTEST);
-        aTestItem.bTest1 = aViewOpt.IsTest1();
-        aTestItem.bTest2 = aViewOpt.IsTest2();
-        aTestItem.bTest3 = aViewOpt.IsTest3();
-        aTestItem.bTest4 =  aViewOpt.IsTest4();
-        aTestItem.bTest5 = aViewOpt.IsTest5();
-        aTestItem.bTest6 = aViewOpt.IsTest6();
-        aTestItem.bTest7 = aViewOpt.IsTest7();
-        aTestItem.bTest8 = aViewOpt.IsTest8();
-        aTestItem.bTest9 = SwViewOption::IsTest9();
-        aTestItem.bTest10 = aViewOpt.IsTest10();
-        pRet->Put(aTestItem);
-#endif
-    /*-----------------01.02.97 13.04-------------------
-
-    --------------------------------------------------*/
     if(!bTextDialog)
         pRet->Put(SfxUInt16Item(SID_HTML_MODE, HTMLMODE_ON));
-//	delete pPrt;
     return pRet;
 }
-/* -----------------12.02.99 12:28-------------------
- *
- * --------------------------------------------------*/
+
 void SwModule::ApplyItemSet( USHORT nId, const SfxItemSet& rSet )
 {
     BOOL bTextDialog = nId == SID_SW_EDITOPTIONS;
@@ -323,7 +261,7 @@ void SwModule::ApplyItemSet( USHORT nId, const SfxItemSet& rSet )
         // the text dialog mustn't apply data to the web view and vice versa
         BOOL bWebView = 0 != PTR_CAST(SwWebView, pAppView);
         if( (bWebView == bTextDialog))
-            pAppView = 0; //
+            pAppView = 0;
     }
 
     SwViewOption aViewOpt = *GetUsrPref(!bTextDialog);
@@ -499,34 +437,11 @@ void SwModule::ApplyItemSet( USHORT nId, const SfxItemSet& rSet )
     }
 
 
-#ifdef DBG_UTIL
-    /*--------------------------------------------------------------------------
-                Writer Testseite auswerten
-    ----------------------------------------------------------------------------*/
-
-            if( SFX_ITEM_SET == rSet.GetItemState(
-                        FN_PARAM_SWTEST, FALSE, &pItem ))
-            {
-                const SwTestItem* pTestItem = (const SwTestItem*)pItem;
-                aViewOpt.SetTest1((BOOL)pTestItem->bTest1);
-                aViewOpt.SetTest2((BOOL)pTestItem->bTest2);
-                aViewOpt.SetTest3((BOOL)pTestItem->bTest3);
-                aViewOpt.SetTest4((BOOL)pTestItem->bTest4);
-                aViewOpt.SetTest5((BOOL)pTestItem->bTest5);
-                aViewOpt.SetTest6((BOOL)pTestItem->bTest6);
-                aViewOpt.SetTest7((BOOL)pTestItem->bTest7);
-                aViewOpt.SetTest8((BOOL)pTestItem->bTest8);
-                SwViewOption::SetTest9((BOOL)pTestItem->bTest9);
-                aViewOpt.SetTest10((BOOL)pTestItem->bTest10);
-            }
-#endif
         // dann an der akt. View und Shell die entsp. Elemente setzen
     ApplyUsrPref( aViewOpt, pAppView,
                  bTextDialog? VIEWOPT_DEST_TEXT : VIEWOPT_DEST_WEB);
 }
-/* -----------------12.02.99 12:28-------------------
- *
- * --------------------------------------------------*/
+
 SfxTabPage* SwModule::CreateTabPage( USHORT nId, Window* pParent, const SfxItemSet& rSet )
 {
     SfxTabPage* pRet = NULL;
@@ -622,7 +537,7 @@ SfxTabPage* SwModule::CreateTabPage( USHORT nId, Window* pParent, const SfxItemS
             }
         }
         break;
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
         case  RID_SW_TP_OPTTEST_PAGE:
         {
             SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
@@ -660,9 +575,10 @@ SfxTabPage* SwModule::CreateTabPage( USHORT nId, Window* pParent, const SfxItemS
         break;
     }
 
-    DBG_ASSERT( pRet, "SwModule::CreateTabPage(): Unknown tabpage id" );
+    OSL_ENSURE( pRet, "SwModule::CreateTabPage(): Unknown tabpage id" );
     return pRet;
 }
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
