@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,9 +38,7 @@
 #include <unotools/syslocale.hxx>
 #include <editeng/boxitem.hxx>
 #include <editeng/numitem.hxx>
-// --> OD 2008-02-13 #newlistlevelattrs#
 #include <editeng/lrspitem.hxx>
-// <--
 #include <fmtcol.hxx>
 #include <uitool.hxx>
 #include <swmodule.hxx>
@@ -66,10 +65,8 @@
 #include <numrule.hxx>
 #include <fmthdft.hxx>
 #include <svx/svxids.hrc>
-// --> OD 2008-02-12 #newlistlevelattrs#
 #include <SwRewriter.hxx>
 #include <undobj.hxx>
-// <--
 
 // MD 06.02.95: Die Formatnamen in der Liste aller Namen haben als
 // erstes Zeichen die Familie:
@@ -324,7 +321,6 @@ USHORT lcl_FindName( const SwPoolFmtList& rLst, SfxStyleFamily eFam,
 {
     if( rLst.Count() )
     {
-        // suchen
         String sSrch( ' ' );
         switch( eFam )
         {
@@ -393,8 +389,6 @@ void SwPoolFmtList::Erase()
     DeleteAndDestroy( 0, Count() );
 }
 
-/*  */
-
 /*--------------------------------------------------------------------
     Beschreibung:  UI-seitige implementierung von StyleSheets
                    greift auf die Core-Engine zu
@@ -417,9 +411,7 @@ SwDocStyleSheet::SwDocStyleSheet(	SwDoc&			rDocument,
     aCoreSet(GetPool().GetPool(),
             RES_CHRATR_BEGIN,		RES_CHRATR_END - 1,
             RES_PARATR_BEGIN,       RES_PARATR_END - 1,
-            // --> OD 2008-02-25 #refactorlists#
             RES_PARATR_LIST_BEGIN,  RES_PARATR_LIST_END - 1,
-            // <--
             RES_FRMATR_BEGIN, 		RES_FRMATR_END - 1,
             RES_UNKNOWNATR_BEGIN, 	RES_UNKNOWNATR_END-1,
             SID_ATTR_PAGE, 			SID_ATTR_PAGE_EXT1,
@@ -482,7 +474,7 @@ const String&  SwDocStyleSheet::GetParent() const
 {
     if( !bPhysical )
     {
-        // dann pruefe, ob schon im Doc vorhanden
+        // check if it's already in document
         SwFmt* pFmt = 0;
         SwGetPoolIdFromName eGetType;
         switch(nFamily)
@@ -505,7 +497,7 @@ const String&  SwDocStyleSheet::GetParent() const
         case SFX_STYLE_FAMILY_PAGE:
         case SFX_STYLE_FAMILY_PSEUDO:
         default:
-            return aEmptyStr;		// es gibt keinen Parent
+            return aEmptyStr;       // there's no parent
         }
 
         String sTmp;
@@ -558,7 +550,7 @@ BOOL  SwDocStyleSheet::HasFollowSupport() const
         case SFX_STYLE_FAMILY_CHAR :
         case SFX_STYLE_FAMILY_PSEUDO: return FALSE;
         default:
-            ASSERT(!this, "unbekannte Style-Familie");
+            OSL_ENSURE(!this, "unknown style family");
     }
     return FALSE;
 }
@@ -667,7 +659,7 @@ String  SwDocStyleSheet::GetDescription(SfxMapUnit eUnit)
                     case SID_ATTR_AUTO_STYLE_UPDATE:
                     case SID_PARA_BACKGRND_DESTINATION:
                     case RES_PAGEDESC:
-                    //CTL no yet supported
+                    //CTL not yet supported
                     case RES_CHRATR_CTL_FONT:
                     case RES_CHRATR_CTL_FONTSIZE:
                     case RES_CHRATR_CTL_LANGUAGE:
@@ -758,9 +750,6 @@ String  SwDocStyleSheet::GetDescription(SfxMapUnit eUnit)
     }
     else if( SFX_STYLE_FAMILY_PSEUDO == nFamily )
     {
-//		if( pNumRule )
-//			return pNumRule->GetName();
-        //os: was sollte man bei Numerierungen schon anzeigen?
         return aEmptyStr;
     }
 
@@ -796,7 +785,7 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
     {
         case SFX_STYLE_FAMILY_CHAR :
         {
-            ASSERT(pCharFmt, "SwCharFormat fehlt!");
+            OSL_ENSURE(pCharFmt, "SwCharFormat missing!");
             if( pCharFmt && pCharFmt->GetName() != rStr )
             {
                 pCharFmt->SetName( rStr );
@@ -806,7 +795,7 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
         }
         case SFX_STYLE_FAMILY_PARA :
         {
-            ASSERT(pColl, "Collektion fehlt!");
+            OSL_ENSURE(pColl, "Collection missing!");
             if( pColl && pColl->GetName() != rStr )
             {
                 if (pColl->GetName().Len() > 0)
@@ -820,7 +809,7 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
         }
         case SFX_STYLE_FAMILY_FRAME:
         {
-            ASSERT(pFrmFmt, "FrmFmt fehlt!");
+            OSL_ENSURE(pFrmFmt, "FrmFmt missing!");
             if( pFrmFmt && pFrmFmt->GetName() != rStr )
             {
                 if (pFrmFmt->GetName().Len() > 0)
@@ -833,13 +822,12 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
             break;
         }
         case SFX_STYLE_FAMILY_PAGE :
-            ASSERT(pDesc, "PageDesc fehlt!");
+            OSL_ENSURE(pDesc, "PageDesc missing!");
             if( pDesc && pDesc->GetName() != rStr )
             {
                 //PageDesc setzen - mit vorherigem kopieren - ist fuer das
                 //setzen des Namens wohl nicht notwendig. Deshalb erlauben
                 //wir hier mal einen cast.
-                // -> #116530#
                 SwPageDesc aPageDesc(*((SwPageDesc*)pDesc));
                 String aOldName(aPageDesc.GetName());
 
@@ -849,16 +837,14 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
                 rDoc.DoUndo(aOldName.Len() > 0);
                 rDoc.ChgPageDesc(aOldName, aPageDesc);
                 rDoc.DoUndo(bDoesUndo);
-                // <- #116530#
 
                 rDoc.SetModified();
                 bChg = TRUE;
             }
             break;
         case SFX_STYLE_FAMILY_PSEUDO:
-            ASSERT(pNumRule, "NumRule fehlt!");
+            OSL_ENSURE(pNumRule, "NumRule missing!");
 
-            // -> #106897#
             if (pNumRule)
             {
                 String aOldName = pNumRule->GetName();
@@ -876,25 +862,23 @@ BOOL  SwDocStyleSheet::SetName( const String& rStr)
                 }
                 else
                 {
-                    // --> OD 2008-07-08 #i91400#
+                    // #i91400#
                     ((SwNumRule*)pNumRule)->SetName( rStr, rDoc );
-                    // <--
                     rDoc.SetModified();
 
                     bChg = TRUE;
                 }
             }
-            // <- #106897#
 
             break;
 
         default:
-            ASSERT(!this, "unbekannte Style-Familie");
+            OSL_ENSURE(!this, "unknown style family");
     }
 
     if( bChg )
     {
-        rPool.First();		// interne Liste muss geupdatet werden
+        rPool.First();  // internal list has to be updated
         rPool.Broadcast( SfxStyleSheetHint( SFX_STYLESHEET_MODIFIED, *this ) );
         SwEditShell* pSh = rDoc.GetEditShell();
         if( pSh )
@@ -914,19 +898,19 @@ BOOL   SwDocStyleSheet::SetParent( const String& rStr)
     switch(nFamily)
     {
         case SFX_STYLE_FAMILY_CHAR :
-            ASSERT( pCharFmt, "SwCharFormat fehlt!" )
+            OSL_ENSURE( pCharFmt, "SwCharFormat missing!" );
             if( 0 != ( pFmt = pCharFmt ) && rStr.Len() )
                 pParent = lcl_FindCharFmt(rDoc, rStr);
             break;
 
         case SFX_STYLE_FAMILY_PARA :
-            ASSERT( pColl, "Collektion fehlt!")
+            OSL_ENSURE( pColl, "Collektion missing!");
             if( 0 != ( pFmt = pColl ) && rStr.Len() )
                 pParent = lcl_FindParaFmt( rDoc, rStr );
             break;
 
         case SFX_STYLE_FAMILY_FRAME:
-            ASSERT(pFrmFmt, "FrameFormat fehlt!");
+            OSL_ENSURE(pFrmFmt, "FrameFormat missing!");
             if( 0 != ( pFmt = pFrmFmt ) && rStr.Len() )
                 pParent = lcl_FindFrmFmt( rDoc, rStr );
             break;
@@ -935,7 +919,7 @@ BOOL   SwDocStyleSheet::SetParent( const String& rStr)
         case SFX_STYLE_FAMILY_PSEUDO:
             break;
         default:
-            ASSERT(!this, "unbekannte Style-Familie");
+            OSL_ENSURE(!this, "unknown style family");
     }
 
     BOOL bRet = FALSE;
@@ -973,7 +957,7 @@ BOOL   SwDocStyleSheet::SetFollow( const String& rStr)
     {
     case SFX_STYLE_FAMILY_PARA :
     {
-        ASSERT(pColl, "Collection fehlt!");
+        OSL_ENSURE(pColl, "Collection missing!");
         if( pColl )
         {
             SwTxtFmtColl* pFollow = pColl;
@@ -986,7 +970,7 @@ BOOL   SwDocStyleSheet::SetFollow( const String& rStr)
     }
     case SFX_STYLE_FAMILY_PAGE :
     {
-        ASSERT(pDesc, "PageDesc fehlt!");
+        OSL_ENSURE(pDesc, "PageDesc missing!");
         if( pDesc )
         {
             const SwPageDesc* pFollowDesc = rStr.Len()
@@ -1009,7 +993,7 @@ BOOL   SwDocStyleSheet::SetFollow( const String& rStr)
     case SFX_STYLE_FAMILY_PSEUDO:
         break;
     default:
-        ASSERT(!this, "unbekannte Style-Familie");
+        OSL_ENSURE(!this, "unknwown style family");
     }
 
     return TRUE;
@@ -1028,8 +1012,9 @@ SfxItemSet&   SwDocStyleSheet::GetItemSet()
     {
         case SFX_STYLE_FAMILY_CHAR:
             {
-                ASSERT(pCharFmt, "Wo ist das SwCharFmt");
+                OSL_ENSURE(pCharFmt, "Where's SwCharFmt");
                 aCoreSet.Put(pCharFmt->GetAttrSet());
+
                 if(pCharFmt->DerivedFrom())
                     aCoreSet.SetParent(&pCharFmt->DerivedFrom()->GetAttrSet());
             }
@@ -1046,19 +1031,21 @@ SfxItemSet&   SwDocStyleSheet::GetItemSet()
                 aBoxInfo.SetValid( VALID_DISABLE, TRUE );
                 if ( nFamily == SFX_STYLE_FAMILY_PARA )
                 {
-                    ASSERT(pColl, "Wo ist die Collektion");
+                    OSL_ENSURE(pColl, "Where's Collection");
                     aCoreSet.Put(pColl->GetAttrSet());
                     aCoreSet.Put( aBoxInfo );
                     aCoreSet.Put(SfxBoolItem(SID_ATTR_AUTO_STYLE_UPDATE, pColl->IsAutoUpdateFmt()));
+
                     if(pColl->DerivedFrom())
                         aCoreSet.SetParent(&pColl->DerivedFrom()->GetAttrSet());
                 }
                 else
                 {
-                    ASSERT(pFrmFmt, "Wo ist das FrmFmt");
+                    OSL_ENSURE(pFrmFmt, "Where's FrmFmt");
                     aCoreSet.Put(pFrmFmt->GetAttrSet());
                     aCoreSet.Put( aBoxInfo );
                     aCoreSet.Put(SfxBoolItem(SID_ATTR_AUTO_STYLE_UPDATE, pFrmFmt->IsAutoUpdateFmt()));
+
                     if(pFrmFmt->DerivedFrom())
                         aCoreSet.SetParent(&pFrmFmt->DerivedFrom()->GetAttrSet());
                 }
@@ -1067,21 +1054,21 @@ SfxItemSet&   SwDocStyleSheet::GetItemSet()
 
         case SFX_STYLE_FAMILY_PAGE :
             {
-                ASSERT(pDesc, "Kein PageDescriptor");
+                OSL_ENSURE(pDesc, "No PageDescriptor");
                 ::PageDescToItemSet(*((SwPageDesc*)pDesc), aCoreSet);
             }
             break;
 
         case SFX_STYLE_FAMILY_PSEUDO:
             {
-                ASSERT(pNumRule, "Keine NumRule");
+                OSL_ENSURE(pNumRule, "No NumRule");
                 SvxNumRule aRule = pNumRule->MakeSvxNumRule();
                 aCoreSet.Put(SvxNumBulletItem(aRule));
             }
             break;
 
         default:
-            ASSERT(!this, "unbekannte Style-Familie");
+            OSL_ENSURE(!this, "unknown style family");
     }
     // Member der Basisklasse
     pSet = &aCoreSet;
@@ -1089,7 +1076,6 @@ SfxItemSet&   SwDocStyleSheet::GetItemSet()
     return aCoreSet;
 }
 
-// --> OD 2008-02-13 #newlistlevelattrs#
 void SwDocStyleSheet::MergeIndentAttrsOfListStyle( SfxItemSet& rSet )
 {
     if ( nFamily != SFX_STYLE_FAMILY_PARA )
@@ -1097,10 +1083,10 @@ void SwDocStyleSheet::MergeIndentAttrsOfListStyle( SfxItemSet& rSet )
         return;
     }
 
-    ASSERT( pColl, "<SwDocStyleSheet::MergeIndentAttrsOfListStyle(..)> - missing paragraph style");
+    OSL_ENSURE( pColl, "<SwDocStyleSheet::MergeIndentAttrsOfListStyle(..)> - missing paragraph style");
     if ( pColl->AreListLevelIndentsApplicable() )
     {
-        ASSERT( pColl->GetItemState( RES_PARATR_NUMRULE ) == SFX_ITEM_SET,
+        OSL_ENSURE( pColl->GetItemState( RES_PARATR_NUMRULE ) == SFX_ITEM_SET,
                 "<SwDocStyleSheet::MergeIndentAttrsOfListStyle(..)> - list level indents are applicable at paragraph style, but no list style found. Serious defect -> please inform OD." );
         const String sNumRule = pColl->GetNumRule().GetValue();
         if( sNumRule.Len() )
@@ -1120,13 +1106,7 @@ void SwDocStyleSheet::MergeIndentAttrsOfListStyle( SfxItemSet& rSet )
         }
     }
 }
-// <--
 
-/*--------------------------------------------------------------------
-    Beschreibung:	ItemSet setzen
- --------------------------------------------------------------------*/
-
-// --> OD 2008-02-12 #newlistlevelattrs#
 // handling of parameter <bResetIndentAttrsAtParagraphStyle>
 void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
                                   const bool bResetIndentAttrsAtParagraphStyle )
@@ -1137,16 +1117,14 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
 
     SwImplShellAction aTmpSh( rDoc );
 
-    ASSERT( &rSet != &aCoreSet, "SetItemSet mit eigenem Set ist nicht erlaubt" );
+    OSL_ENSURE( &rSet != &aCoreSet, "SetItemSet with own Set is not allowed" );
 
-    // --> OD 2008-02-12 #newlistlevelattrs#
     if ( rDoc.DoesUndo() )
     {
         SwRewriter aRewriter;
         aRewriter.AddRule( UNDO_ARG1, GetName() );
         rDoc.StartUndo( UNDO_INSFMTATTR, &aRewriter );
     }
-    // <--
 
     SwFmt* pFmt = 0;
     SwPageDesc* pNewDsc = 0;
@@ -1156,14 +1134,14 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
     {
         case SFX_STYLE_FAMILY_CHAR :
             {
-                ASSERT(pCharFmt, "Wo ist das CharFormat");
+                OSL_ENSURE(pCharFmt, "Where's CharFormat");
                 pFmt = pCharFmt;
             }
             break;
 
         case SFX_STYLE_FAMILY_PARA :
         {
-            ASSERT(pColl, "Wo ist die Collection");
+            OSL_ENSURE(pColl, "Where's Collection");
             const SfxPoolItem* pAutoUpdate;
             if(SFX_ITEM_SET == rSet.GetItemState(SID_ATTR_AUTO_STYLE_UPDATE,FALSE, &pAutoUpdate ))
             {
@@ -1192,7 +1170,7 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
                     }
                 }
 
-                // Document auf die neue Bedingungen updaten
+                // Update document to new conditions
                 SwCondCollCondChg aMsg( pColl );
                 pColl->Modify( &aMsg, &aMsg );
             }
@@ -1205,11 +1183,10 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
                 if( pColl != &pColl->GetNextTxtFmtColl() )
                     pCColl->SetNextTxtFmtColl( pColl->GetNextTxtFmtColl() );
 
-                //pCColl->SetOutlineLevel( pColl->GetOutlineLevel() );//#outline level,zhaojianwei
                 if( pColl->IsAssignedToListLevelOfOutlineStyle())
                     pCColl->AssignToListLevelOfOutlineStyle(pColl->GetAssignedOutlineStyleLevel());
                 else
-                    pCColl->DeleteAssignmentToListLevelOfOutlineStyle();//<--end,zhaojianwei
+                    pCColl->DeleteAssignmentToListLevelOfOutlineStyle();
                 
 
 
@@ -1229,7 +1206,6 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
                 rDoc.DelTxtFmtColl( pColl );
                 pColl = pCColl;
             }
-            // --> OD 2008-02-12 #newlistlevelattrs#
             if ( bResetIndentAttrsAtParagraphStyle &&
                  rSet.GetItemState( RES_PARATR_NUMRULE, FALSE, 0 ) == SFX_ITEM_SET &&
                  rSet.GetItemState( RES_LR_SPACE, FALSE, 0 ) != SFX_ITEM_SET &&
@@ -1237,7 +1213,6 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
             {
                 rDoc.ResetAttrAtFormat( RES_LR_SPACE, *pColl );
             }
-            // <--
 
             // #i56252: If a standard numbering style is assigned to a standard paragraph style
             // we have to create a physical instance of the numbering style. If we do not and
@@ -1291,7 +1266,7 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
         }
         case SFX_STYLE_FAMILY_FRAME:
         {
-            ASSERT(pFrmFmt, "Wo ist das FrmFmt");
+            OSL_ENSURE(pFrmFmt, "Where's FrmFmt");
             const SfxPoolItem* pAutoUpdate;
             if(SFX_ITEM_SET == rSet.GetItemState(SID_ATTR_AUTO_STYLE_UPDATE,FALSE, &pAutoUpdate ))
             {
@@ -1303,7 +1278,7 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
 
         case SFX_STYLE_FAMILY_PAGE :
             {
-                ASSERT(pDesc, "Wo ist der PageDescriptor");
+                OSL_ENSURE(pDesc, "Where's PageDescriptor");
 
                 if( rDoc.FindPageDescByName( pDesc->GetName(), &nPgDscPos ))
                 {
@@ -1323,7 +1298,7 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
 
         case SFX_STYLE_FAMILY_PSEUDO:
             {
-                ASSERT(pNumRule, "Wo ist die NumRule");
+                OSL_ENSURE(pNumRule, "Where's NumRule");
 
                 if (!pNumRule)
                     break;
@@ -1335,7 +1310,6 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
                 {
                     SvxNumRule* pSetRule = ((SvxNumBulletItem*)pItem)->GetNumRule();
                     pSetRule->UnLinkGraphics();
-                    //SwNumRule aSetRule(rDoc.GetUniqueNumRuleName());
                     SwNumRule aSetRule(*pNumRule);
                     aSetRule.SetSvxRule(*pSetRule, &rDoc);
                     rDoc.ChgNumRuleFmts( aSetRule );
@@ -1345,12 +1319,9 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
                     // NumRule auf default Werte
                     // was sind die default Werte?
                     {
-                        // --> OD 2008-02-11 #newlistlevelattrs#
                         SwNumRule aRule( pNumRule->GetName(),
-                                         // --> OD 2008-06-06 #i89178#
+                                         // #i89178#
                                          numfunc::GetDefaultPositionAndSpaceMode() );
-                                         // <--
-                        // <--
                         rDoc.ChgNumRuleFmts( aRule );
                     }
                     break;
@@ -1359,7 +1330,7 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
             break;
 
         default:
-            ASSERT(!this, "unbekannte Style-Familie");
+            OSL_ENSURE(!this, "unknown style family");
     }
 
     if( pFmt && rSet.Count())
@@ -1370,10 +1341,8 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
         {
             if( IsInvalidItem( pItem ) )			// Clearen
             {
-                // --> OD 2008-02-12 #newlistlevelattrs#
                 // use method <SwDoc::ResetAttrAtFormat(..)> in order to
                 // create an Undo object for the attribute reset.
-//                pFmt->ResetAttr( rSet.GetWhichByPos(aIter.GetCurPos()));
                 rDoc.ResetAttrAtFormat( rSet.GetWhichByPos(aIter.GetCurPos()),
                                         *pFmt );
             }
@@ -1401,19 +1370,17 @@ void SwDocStyleSheet::SetItemSet( const SfxItemSet& rSet,
     else
     {
         aCoreSet.ClearItem();
-        if( pNewDsc ) 			// den muessen wir noch vernichten!!
+        if( pNewDsc )       // we still need to delete it
         {
             rDoc.PreDelPageDesc(pNewDsc); // #i7983#
             delete pNewDsc;
         }
     }
 
-    // --> OD 2008-02-12 #newlistlevelattrs#
     if ( rDoc.DoesUndo() )
     {
         rDoc.EndUndo( UNDO_INSFMTATTR, NULL );
     }
-    // <--
 }
 
 void lcl_SaveStyles( USHORT nFamily, SvPtrarr& rArr, SwDoc& rDoc )
@@ -1728,7 +1695,7 @@ BOOL SwDocStyleSheet::FillStyleSheet( FillStyleType eFType )
 
         if( pFmt )
         {
-            ASSERT( bPhysical, "Format nicht gefunden" );
+            OSL_ENSURE( bPhysical, "Format not found" );
 
             nHelpId = pFmt->GetPoolHelpId();
             if( pFmt->GetPoolHlpFileId() != UCHAR_MAX )
@@ -1796,24 +1763,19 @@ void SwDocStyleSheet::Create()
             pNumRule = lcl_FindNumRule( rDoc, aName );
             if( !pNumRule )
             {
-                //JP 05.02.99: temp Namen erzeugen, damit kein ASSERT kommt
                 String sTmpNm( aName );
                 if( !aName.Len() )
                     sTmpNm = rDoc.GetUniqueNumRuleName();
 
-                // --> OD 2008-02-11 #newlistlevelattrs#
                 SwNumRule* pRule = rDoc.GetNumRuleTbl()[
                     rDoc.MakeNumRule( sTmpNm, 0, FALSE,
-                                      // --> OD 2008-06-06 #i89178#
+                                      // #i89178#
                                       numfunc::GetDefaultPositionAndSpaceMode() ) ];
-                                      // <--
-                // <--
                 pRule->SetAutoRule( FALSE );
                 if( !aName.Len() )
                 {
-                    // --> OD 2008-07-08 #i91400#
+                    // #i91400#
                     pRule->SetName( aName, rDoc );
-                    // <--
                 }
                 pNumRule = pRule;
             }
@@ -1824,12 +1786,6 @@ void SwDocStyleSheet::Create()
     aCoreSet.ClearItem();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:	Konkrete Formate rausholen
- --------------------------------------------------------------------*/
-
-
-
 SwCharFmt* SwDocStyleSheet::GetCharFmt()
 {
     if(!bPhysical)
@@ -1837,7 +1793,6 @@ SwCharFmt* SwDocStyleSheet::GetCharFmt()
     return pCharFmt;
 }
 
-
 SwTxtFmtColl* SwDocStyleSheet::GetCollection()
 {
     if(!bPhysical)
@@ -1845,7 +1800,6 @@ SwTxtFmtColl* SwDocStyleSheet::GetCollection()
     return pColl;
 }
 
-
 const SwPageDesc* SwDocStyleSheet::GetPageDesc()
 {
     if(!bPhysical)
@@ -1862,7 +1816,7 @@ const SwNumRule * SwDocStyleSheet::GetNumRule()
 
 void SwDocStyleSheet::SetNumRule(const SwNumRule& rRule)
 {
-    DBG_ASSERT(pNumRule, "Wo ist die NumRule");
+    OSL_ENSURE(pNumRule, "Wo ist die NumRule");
     rDoc.ChgNumRuleFmts( rRule );
 }
 
@@ -1908,7 +1862,6 @@ SwFrmFmt* SwDocStyleSheet::GetFrmFmt()
     return pFrmFmt;
 }
 
-
 BOOL  SwDocStyleSheet::IsUsed() const
 {
     if( !bPhysical )
@@ -1917,7 +1870,6 @@ BOOL  SwDocStyleSheet::IsUsed() const
         pThis->FillStyleSheet( FillOnlyName );
     }
 
-    // immer noch nicht ?
     if( !bPhysical )
         return FALSE;
 
@@ -1933,7 +1885,7 @@ BOOL  SwDocStyleSheet::IsUsed() const
             return pNumRule ? rDoc.IsUsed( *pNumRule ) : FALSE;
 
     default:
-        ASSERT(!this, "unbekannte Style-Familie");
+        OSL_ENSURE(!this, "unknown style family");
         return FALSE;
     }
     return rDoc.IsUsed( *pMod );
@@ -2010,7 +1962,7 @@ static String sTemplateHelpFile = String::CreateFromAscii("swrhlppi.hlp");
         break;
 
     default:
-        ASSERT(!this, "unbekannte Style-Familie");
+        OSL_ENSURE(!this, "unknown style family");
         return 0;
     }
 
@@ -2026,7 +1978,6 @@ static String sTemplateHelpFile = String::CreateFromAscii("swrhlppi.hlp");
         const String *pTemplate = rDoc.GetDocPattern( nFileId );
         if( pTemplate )
         {
-//			const String aHelpPath(MakeHelpPath(*pTemplate));
             rFile = *pTemplate;
         }
     }
@@ -2065,7 +2016,7 @@ void  SwDocStyleSheet::SetHelpId( const String& r, ULONG nId )
         break;
 
     default:
-        ASSERT(!this, "unbekannte Style-Familie");
+        OSL_ENSURE(!this, "unknown style family");
         return ;
     }
     if( pTmpFmt )
@@ -2075,9 +2026,6 @@ void  SwDocStyleSheet::SetHelpId( const String& r, ULONG nId )
     }
 }
 
-
-/*  */
-
 /*--------------------------------------------------------------------
     Beschreibung:	Methoden fuer den DocStyleSheetPool
  --------------------------------------------------------------------*/
@@ -2124,7 +2072,7 @@ SfxStyleSheetBase&	 SwDocStyleSheetPool::Make(
 
 SfxStyleSheetBase*   SwDocStyleSheetPool::Create( const SfxStyleSheetBase& /*rOrg*/)
 {
-    ASSERT(!this , "Create im SW-Stylesheet-Pool geht nicht" );
+    OSL_ENSURE(!this , "Create im SW-Stylesheet-Pool geht nicht" );
     return NULL;
 }
 
@@ -2132,7 +2080,7 @@ SfxStyleSheetBase*   SwDocStyleSheetPool::Create( const SfxStyleSheetBase& /*rOr
 SfxStyleSheetBase*	 SwDocStyleSheetPool::Create( const String &,
                                                 SfxStyleFamily, USHORT )
 {
-    ASSERT( !this, "Create im SW-Stylesheet-Pool geht nicht" );
+    OSL_ENSURE( !this, "Create im SW-Stylesheet-Pool geht nicht" );
     return NULL;
 }
 
@@ -2295,7 +2243,7 @@ void SwDocStyleSheetPool::Remove( SfxStyleSheetBase* pStyle)
         break;
 
     default:
-        ASSERT(!this, "unbekannte Style-Familie");
+        OSL_ENSURE(!this, "unknown style family");
         bBroadcast = FALSE;
     }
 
@@ -2331,7 +2279,7 @@ BOOL  SwDocStyleSheetPool::SetParent( SfxStyleFamily eFam,
         break;
 
     default:
-        ASSERT(!this, "unbekannte Style-Familie");
+        OSL_ENSURE(!this, "unknown style family");
     }
 
     BOOL bRet = FALSE;
@@ -2421,7 +2369,7 @@ SfxStyleSheetBase* SwDocStyleSheetPool::Find( const String& rName,
             break;
 
         default:
-            ASSERT(!this, "unbekannte Style-Familie");
+            OSL_ENSURE(!this, "unknown style family");
         }
     }
 
@@ -2441,8 +2389,6 @@ SfxStyleSheetBase* SwDocStyleSheetPool::Find( const String& rName,
     return bFnd ? mxStyleSheet.get() : 0;
 }
 
-/*  */
-
 SwStyleSheetIterator::SwStyleSheetIterator( SwDocStyleSheetPool* pBase,
                                 SfxStyleFamily eFam, USHORT n )
     : SfxStyleSheetIterator( pBase, eFam, n ),
@@ -2481,12 +2427,12 @@ SfxStyleSheetBase*  SwStyleSheetIterator::operator[]( USHORT nIdx )
 
 SfxStyleSheetBase*  SwStyleSheetIterator::First()
 {
-    // Alte Liste loeschen
+    // Delete old list
     bFirstCalled = TRUE;
     nLastPos = 0;
     aLst.Erase();
 
-    // aktuellen loeschen
+    // Delete current
     mxIterSheet->Reset();
 
     SwDoc& rDoc = ((SwDocStyleSheetPool*)pBasePool)->GetDoc();
@@ -2606,7 +2552,6 @@ SfxStyleSheetBase*  SwStyleSheetIterator::First()
                 case SWSTYLEBIT_EXTRA:
                     if((nId  & COLL_GET_RANGE_BITS) != COLL_EXTRA_BITS) continue;
                     break;
-
                 case SWSTYLEBIT_HTML | SFXSTYLEBIT_USERDEF:
                     if(IsPoolUserFmt(nId))
                         break;
@@ -2876,7 +2821,7 @@ void SwStyleSheetIterator::AppendStyleList(const SvStringsDtor& rList,
                         bUsed = rDoc.IsPoolPageDescUsed( nId );
                         break;
                 default:
-                    ASSERT( !this, "unknown PoolFmt-Id" );
+                    OSL_ENSURE( !this, "unknown PoolFmt-Id" );
             }
             if ( bUsed )
                 aLst.Append( cType, *rList[i] );
@@ -2906,3 +2851,4 @@ void  SwStyleSheetIterator::Notify( SfxBroadcaster&, const SfxHint& rHint )
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
