@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,9 +34,7 @@
 
 
 #include <hintids.hxx>
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
 #include <vcl/svapp.hxx>
 #ifndef _SVSTDARR_HXX
 #define _SVSTDARR_STRINGSDTOR
@@ -55,15 +54,9 @@
 #include <fmtcol.hxx>
 #include <charatr.hxx>
 #include <swtypes.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
-#ifndef IDOCUMENTDEVICEACCESS_HXX_INCLUDED
 #include <IDocumentDeviceAccess.hxx>
-#endif
 #include <swmodule.hxx>
 #include <wrtsh.hxx>
 #include <uitool.hxx>
@@ -73,26 +66,14 @@
 #include <initui.hxx>
 #include <optpage.hxx>
 #include <swprtopt.hxx>
-#ifndef _MODCFG_HXX
 #include <modcfg.hxx>
-#endif
-#ifndef _SRCVIEW_HXX
 #include <srcview.hxx>
-#endif
 #include <crstate.hxx>
 #include <viewopt.hxx>
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
-#ifndef _CONFIG_HRC
 #include <config.hrc>
-#endif
-#ifndef _REDLOPT_HRC
 #include <redlopt.hrc>
-#endif
-#ifndef _OPTDLG_HRC
 #include <optdlg.hrc>
-#endif
 #include <svx/strarray.hxx>
 #include <svl/slstitm.hxx>
 #include <sfx2/request.hxx>
@@ -101,17 +82,8 @@
 
 #include <unomid.h>
 
-
 using namespace ::com::sun::star;
 
-
-/*******************************************************
- ******************************************************/
-
-/*-----------------31.08.96 10.16-------------------
-    TabPage Anzeige/Inhalt
---------------------------------------------------*/
-
 SwContentOptPage::SwContentOptPage( Window* pParent,
                                       const SfxItemSet& rCoreSet ) :
     SfxTabPage( pParent, SW_RES( TP_CONTENT_OPT ), rCoreSet ),
@@ -180,20 +152,20 @@ SwContentOptPage::SwContentOptPage( Window* pParent,
             case FUNIT_LINE:
             {
                 // nur diese Metriken benutzen
-                                // a horizontal ruler has not the 'line' unit
-                                // there isn't 'line' unit in HTML format
-                                if ( eFUnit != FUNIT_LINE )
-                                {
-                        USHORT nPos = aMetricLB.InsertEntry( sMetric );
-                        aMetricLB.SetEntryData( nPos, (void*)(long)eFUnit );
-                            aHMetric.InsertEntry( sMetric );
-                                    aHMetric.SetEntryData( nPos, (void*)(long)eFUnit );
-                                }
-                                // a vetical ruler has not the 'character' unit
+                // a horizontal ruler has not the 'line' unit
+                // there isn't 'line' unit in HTML format
+                if ( eFUnit != FUNIT_LINE )
+                {
+                   USHORT nPos = aMetricLB.InsertEntry( sMetric );
+                   aMetricLB.SetEntryData( nPos, (void*)(long)eFUnit );
+                   aHMetric.InsertEntry( sMetric );
+                   aHMetric.SetEntryData( nPos, (void*)(long)eFUnit );
+                }
+                // a vertical ruler has not the 'character' unit
                 if ( eFUnit != FUNIT_CHAR )
                 {
-                            USHORT nPos = aVMetric.InsertEntry( sMetric );
-                            aVMetric.SetEntryData( nPos, (void*)(long)eFUnit );
+                   USHORT nPos = aVMetric.InsertEntry( sMetric );
+                   aVMetric.SetEntryData( nPos, (void*)(long)eFUnit );
                 }
             }
             default:;//prevent warning
@@ -201,24 +173,16 @@ SwContentOptPage::SwContentOptPage( Window* pParent,
     }
 }
 
-/*-----------------31.08.96 13.58-------------------
-
---------------------------------------------------*/
 SwContentOptPage::~SwContentOptPage()
 {
 }
 
-/*-----------------31.08.96 13.58-------------------
-
---------------------------------------------------*/
 SfxTabPage*	SwContentOptPage::Create( Window* pParent,
                                 const SfxItemSet& rAttrSet)
 {
     return new SwContentOptPage(pParent, rAttrSet);
 }
-/* -----------------------------07.04.01 16:57--------------------------------
 
- ---------------------------------------------------------------------------*/
 static void lcl_SelectMetricLB(ListBox& rMetric, USHORT nSID, const SfxItemSet& rSet)
 {
     const SfxPoolItem* pItem;
@@ -236,9 +200,7 @@ static void lcl_SelectMetricLB(ListBox& rMetric, USHORT nSID, const SfxItemSet&
     }
     rMetric.SaveValue();
 }
-/*-----------------31.08.96 13.58-------------------
 
---------------------------------------------------*/
 void SwContentOptPage::Reset(const SfxItemSet& rSet)
 {
     const SwElemItem* pElemAttr = 0;
@@ -270,9 +232,6 @@ void SwContentOptPage::Reset(const SfxItemSet& rSet)
     AnyRulerHdl(&aAnyRulerCB);
 }
 
-/*-----------------31.08.96 13.58-------------------
-
---------------------------------------------------*/
 BOOL SwContentOptPage::FillItemSet(SfxItemSet& rSet)
 {
     const SwElemItem*   pOldAttr = (const SwElemItem*)
@@ -329,17 +288,13 @@ BOOL SwContentOptPage::FillItemSet(SfxItemSet& rSet)
     }
     return bRet;
 }
-/* -----------------------------05.03.2002 15:07------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwContentOptPage, VertRulerHdl, CheckBox*, pBox)
 {
     aVRulerRightCBox.Enable(pBox->IsEnabled() && pBox->IsChecked());
     return 0;
 }
-/* -----------------20.09.2002 11:30-----------------
- *
- * --------------------------------------------------*/
+
 IMPL_LINK( SwContentOptPage, AnyRulerHdl, CheckBox*, pBox)
 {
     BOOL bChecked = pBox->IsChecked();
@@ -450,8 +405,6 @@ SwAddPrinterTabPage::SwAddPrinterTabPage( Window* pParent,
     aProspectCB_RTL.Show(aCTLOptions.IsCTLFontEnabled());
 }
 
-//------------------------------------------------------------------------
-
 void SwAddPrinterTabPage::SetPreview(BOOL bPrev)
 {
     bPreview = bPrev;
@@ -470,15 +423,11 @@ void SwAddPrinterTabPage::SetPreview(BOOL bPrev)
     }
 }
 
-//------------------------------------------------------------------------
-
 SfxTabPage*	SwAddPrinterTabPage::Create( Window* pParent,
                                        const SfxItemSet& rAttrSet )
 {
     return ( new SwAddPrinterTabPage( pParent, rAttrSet ) );
 }
-//------------------------------------------------------------------------
-
 
 BOOL 	SwAddPrinterTabPage::FillItemSet( SfxItemSet& rCoreSet )
 {
@@ -518,8 +467,6 @@ BOOL 	SwAddPrinterTabPage::FillItemSet( SfxItemSet& rCoreSet )
     }
     return bAttrModified;
 }
-//------------------------------------------------------------------------
-
 
 void 	SwAddPrinterTabPage::Reset( const SfxItemSet&  )
 {
@@ -563,15 +510,11 @@ void 	SwAddPrinterTabPage::Reset( const SfxItemSet&  )
     else
         aProspectCB_RTL.Enable( FALSE );
 }
-//-----------------------------------------------------------------------
-
 
 void 	SwAddPrinterTabPage::Init()
 {
 
 }
-//------------------------------------------------------------------------
-
 
 IMPL_LINK_INLINE_START( SwAddPrinterTabPage, AutoClickHdl, CheckBox *, EMPTYARG )
 {
@@ -588,9 +531,6 @@ IMPL_LINK_INLINE_START( SwAddPrinterTabPage, AutoClickHdl, CheckBox *, EMPTYARG
 }
 IMPL_LINK_INLINE_END( SwAddPrinterTabPage, AutoClickHdl, CheckBox *, EMPTYARG )
 
-//------------------------------------------------------------------------
-
-
 void  SwAddPrinterTabPage::SetFax( const SvStringsDtor& rFaxLst )
 {
     aFaxLB.InsertEntry(sNone);
@@ -599,9 +539,6 @@ void  SwAddPrinterTabPage::SetFax( const SvStringsDtor& rFaxLst )
     aFaxLB.SelectEntryPos(0);
 }
 
-//------------------------------------------------------------------------
-
-
 IMPL_LINK_INLINE_START( SwAddPrinterTabPage, SelectHdl, ListBox *, EMPTYARG )
 {
     bAttrModified=TRUE;
@@ -630,24 +567,12 @@ void SwAddPrinterTabPage::PageCreated (SfxAllItemSet aSet)
             aFaxList.Insert(rpString, 0);
         }
         SetFax( aFaxList );
-/*		SvStringsDtor aFaxList;
-        const List *pList = (pListItem)->GetList();
-        sal_uInt32 nCount = pList->Count();
-        for(sal_uInt32 i = 0; i < nCount ; i++)
-        {
-            String* pString = (String*)(pList->GetObject(i));
-            String* &rpString = pString;
-            aFaxList.Insert(rpString, 0 );
-        }
-        SetFax(aFaxList);
-*/
     }
 }
+
 /*-----------------03.09.96 11.53-------------------
     Tabpage Standardfonts
 --------------------------------------------------*/
-
-
 SwStdFontTabPage::SwStdFontTabPage( Window* pParent,
                                        const SfxItemSet& rSet ) :
     SfxTabPage( pParent, SW_RES( TP_STD_FONT ), rSet),
@@ -728,28 +653,18 @@ SwStdFontTabPage::SwStdFontTabPage( Window* pParent,
     aDocOnlyCB.Check(SW_MOD()->GetModuleConfig()->IsDefaultFontInCurrDocOnly());
 }
 
-/*-----------------03.09.96 11.53-------------------
-
---------------------------------------------------*/
-
 SwStdFontTabPage::~SwStdFontTabPage()
 {
     if(bDeletePrinter)
         delete pPrt;
 }
 
-/*-----------------03.09.96 11.53-------------------
-
---------------------------------------------------*/
 SfxTabPage*	SwStdFontTabPage::Create( Window* pParent,
                                 const SfxItemSet& rAttrSet )
 {
     return new SwStdFontTabPage(pParent, rAttrSet);
 }
 
-/*-----------------03.09.96 11.53-------------------
-
---------------------------------------------------*/
 void lcl_SetColl(SwWrtShell* pWrtShell, USHORT nType,
                     SfxPrinter* pPrt, const String& rStyle,
                     USHORT nFontWhich)
@@ -769,9 +684,7 @@ void lcl_SetColl(SwWrtShell* pWrtShell, USHORT nType,
         delete (SfxFont*) pFnt;
     }
 }
-/*-- 11.10.2005 15:47:52---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void lcl_SetColl(SwWrtShell* pWrtShell, USHORT nType,
                     sal_Int32 nHeight, USHORT nFontHeightWhich)
 {
@@ -780,9 +693,7 @@ void lcl_SetColl(SwWrtShell* pWrtShell, USHORT nType,
     SwTxtFmtColl *pColl = pWrtShell->GetTxtCollFromPool(nType);
     pColl->SetFmtAttr(SvxFontHeightItem(nHeight, 100, nFontHeightWhich));
 }
-/*-----------------03.09.96 11.53-------------------
 
---------------------------------------------------*/
 BOOL SwStdFontTabPage::FillItemSet( SfxItemSet& )
 {
     BOOL bNotDocOnly = !aDocOnlyCB.IsChecked();
@@ -866,7 +777,6 @@ BOOL SwStdFontTabPage::FillItemSet( SfxItemSet& )
                 delete (SfxFont*) pFnt;
                 bDelete = FALSE;
             }
-//          lcl_SetColl(pWrtShell, RES_POOLCOLL_STANDARD, pPrinter, sStandard);
             bMod = TRUE;
         }
         if(bStandardHeightChanged)
@@ -930,9 +840,6 @@ BOOL SwStdFontTabPage::FillItemSet( SfxItemSet& )
     return FALSE;
 }
 
-/*-----------------03.09.96 11.53-------------------
-
---------------------------------------------------*/
 void SwStdFontTabPage::Reset( const SfxItemSet& rSet)
 {
     const SfxPoolItem* pLang;
@@ -1116,11 +1023,6 @@ void SwStdFontTabPage::Reset( const SfxItemSet& rSet)
     aIndexHeightLB.   SaveValue();
 }
 
-/*-----------------07.09.96 12.28-------------------
-
---------------------------------------------------*/
-
-
 IMPL_LINK( SwStdFontTabPage, StandardHdl, PushButton *, EMPTYARG )
 {
     sal_uInt8 nFontOffset = nFontGroup * FONT_PER_GROUP;
@@ -1154,9 +1056,6 @@ IMPL_LINK( SwStdFontTabPage, StandardHdl, PushButton *, EMPTYARG )
 
     return 0;
 }
-/*-----------------17.01.97 15.43-------------------
-
---------------------------------------------------*/
 
 IMPL_LINK( SwStdFontTabPage, ModifyHdl, ComboBox*, pBox )
 {
@@ -1185,9 +1084,6 @@ IMPL_LINK( SwStdFontTabPage, ModifyHdl, ComboBox*, pBox )
     return 0;
 }
 
-/*-- 11.10.2005 15:11:23---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 IMPL_LINK( SwStdFontTabPage, ModifyHeightHdl, FontSizeBox*, pBox )
 {
     if(pBox == &aStandardHeightLB)
@@ -1215,9 +1111,6 @@ IMPL_LINK( SwStdFontTabPage, ModifyHeightHdl, FontSizeBox*, pBox )
     return 0;
 }
 
-/*-- 28.09.2005 13:22:36---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 IMPL_LINK( SwStdFontTabPage, LoseFocusHdl, ComboBox*, pBox )
 {
     FontSizeBox* pHeightLB = 0;
@@ -1255,9 +1148,6 @@ void SwStdFontTabPage::PageCreated (SfxAllItemSet aSet)
     if (pFlagItem)
         SetFontMode(sal::static_int_cast< sal_uInt8, sal_uInt16>( pFlagItem->GetValue()));
 }
-/*-----------------18.01.97 12.14-------------------
-    Optionen Tabelle
---------------------------------------------------*/
 
 SwTableOptionsTabPage::SwTableOptionsTabPage( Window* pParent, const SfxItemSet& rSet ) :
     SfxTabPage(pParent, SW_RES(TP_OPTTABLE_PAGE), rSet),
@@ -1305,28 +1195,16 @@ SwTableOptionsTabPage::SwTableOptionsTabPage( Window* pParent, const SfxItemSet&
     aHeaderCB.SetClickHdl(aLnk);
 }
 
-/*-----------------18.01.97 12.43-------------------
-
---------------------------------------------------*/
-
 SwTableOptionsTabPage::~SwTableOptionsTabPage()
 {
 }
 
-/*-----------------18.01.97 12.43-------------------
-
---------------------------------------------------*/
-
 SfxTabPage*	SwTableOptionsTabPage::Create( Window* pParent,
                                 const SfxItemSet& rAttrSet )
 {
     return new SwTableOptionsTabPage(pParent, rAttrSet );
 }
 
-/*-----------------18.01.97 12.42-------------------
-
---------------------------------------------------*/
-
 BOOL SwTableOptionsTabPage::FillItemSet( SfxItemSet& )
 {
     BOOL bRet = FALSE;
@@ -1413,9 +1291,7 @@ BOOL SwTableOptionsTabPage::FillItemSet( SfxItemSet& )
 
     return bRet;
 }
-/*-----------------18.01.97 12.42-------------------
 
---------------------------------------------------*/
 void SwTableOptionsTabPage::Reset( const SfxItemSet& rSet)
 {
     const SwModuleOptions* pModOpt = SW_MOD()->GetModuleConfig();
@@ -1446,46 +1322,10 @@ void SwTableOptionsTabPage::Reset( const SfxItemSet& rSet)
         bHTMLMode = 0 != (((const SfxUInt16Item*)pItem)->GetValue() & HTMLMODE_ON);
     }
 
-    //bestimmte Controls fuer HTML verstecken
+    // hide certain controls for html
     if(bHTMLMode)
     {
-/*        Point aPos(aCaptionFL.GetPosPixel());
-        long nYDiff = aTableFL.GetPosPixel().Y() - aPos.Y();
-        aTableFL.SetPosPixel(aPos);
 
-        aPos = aHeaderCB.GetPosPixel();
-        aPos.Y() -= nYDiff;
-        aHeaderCB.SetPosPixel(aPos);
-
-        aPos = aRepeatHeaderCB.GetPosPixel();
-        aPos.Y() -= nYDiff;
-        aRepeatHeaderCB.SetPosPixel(aPos);
-
-        aPos = aDontSplitCB.GetPosPixel(); // hier muss eine Luecke geschlossen werden
-        aPos.Y() -= nYDiff;
-        aBorderCB.SetPosPixel(aPos);
-
-        aPos = aTableInsertFL.GetPosPixel();
-        aPos.Y() -= nYDiff;
-        aTableInsertFL.SetPosPixel(aPos);
-
-        aPos = aNumFormattingCB.GetPosPixel();
-        aPos.Y() -= nYDiff;
-        aNumFormattingCB.SetPosPixel(aPos);
-
-        aPos = aNumFmtFormattingCB.GetPosPixel();
-        aPos.Y() -= nYDiff;
-        aNumFmtFormattingCB.SetPosPixel(aPos);
-
-        aPos = aNumAlignmentCB.GetPosPixel();
-        aPos.Y() -= nYDiff;
-        aNumAlignmentCB.SetPosPixel(aPos);
-
-        aCaptionFL.Hide();
-        aCaptionCB.Hide();
-        aCaptionFT.Hide();
-        aCaptionPB.Hide();
-*/
         aDontSplitCB.Hide();
     }
 
@@ -1511,9 +1351,7 @@ void SwTableOptionsTabPage::Reset( const SfxItemSet& rSet)
 
     CheckBoxHdl(0);
 }
-/*-----------------18.01.97 12.42-------------------
 
---------------------------------------------------*/
 IMPL_LINK(SwTableOptionsTabPage, CheckBoxHdl, CheckBox*, EMPTYARG)
 {
     aNumFmtFormattingCB.Enable(aNumFormattingCB.IsChecked());
@@ -1521,17 +1359,13 @@ IMPL_LINK(SwTableOptionsTabPage, CheckBoxHdl, CheckBox*, EMPTYARG)
     aRepeatHeaderCB.Enable(aHeaderCB.IsChecked());
     return 0;
 }
+
 void SwTableOptionsTabPage::PageCreated (SfxAllItemSet aSet)
 {
     SFX_ITEMSET_ARG (&aSet,pWrtSh,SwWrtShellItem,SID_WRT_SHELL,sal_False);
     if (pWrtSh)
         SetWrtShell(pWrtSh->GetValue());
 }
-/*  */
-
-/*-----------------31.10.97 17:55-------------------
- TabPage fuer ShadowCrsr
---------------------------------------------------*/
 
 SwShdwCrsrOptionsTabPage::SwShdwCrsrOptionsTabPage( Window* pParent,
                                                     const SfxItemSet& rSet )
@@ -1605,7 +1439,6 @@ SwShdwCrsrOptionsTabPage::~SwShdwCrsrOptionsTabPage()
 {
 }
 
-
 SfxTabPage*	SwShdwCrsrOptionsTabPage::Create( Window* pParent, const SfxItemSet& rSet )
 {
     return new SwShdwCrsrOptionsTabPage( pParent, rSet );
@@ -1648,7 +1481,7 @@ BOOL SwShdwCrsrOptionsTabPage::FillItemSet( SfxItemSet& rSet )
     SwDocDisplayItem aDisp;
     if(pOldAttr)
         aDisp = *pOldAttr;
-    //
+
     aDisp.bParagraphEnd         = aParaCB       .IsChecked();
     aDisp.bTab                  = aTabCB        .IsChecked();
     aDisp.bSpace                = aSpacesCB     .IsChecked();
@@ -1707,7 +1540,6 @@ void SwShdwCrsrOptionsTabPage::Reset( const SfxItemSet& rSet )
 /*-----------------31.10.97 17:55-------------------
  TabPage fuer Redlining
 --------------------------------------------------*/
-
 struct CharAttr
 {
     USHORT nItemId;
@@ -1744,7 +1576,6 @@ static USHORT aChangedAttrMap[] = { 0, 1, 2, 3, 4, 6, 7, 8, 9, 10 };
 /*-----------------------------------------------------------------------
     Beschreibung: Markierungsvorschau
  -----------------------------------------------------------------------*/
-
 SwMarkPreview::SwMarkPreview( Window *pParent, const ResId& rResID ) :
 
     Window(pParent, rResID),
@@ -1758,7 +1589,7 @@ SwMarkPreview::SwMarkPreview( Window *pParent, const ResId& rResID ) :
 
     const Size aSz(GetOutputSizePixel());
 
-    // Seite
+    // Page
     aPage.SetSize(Size(aSz.Width() - 3, aSz.Height() - 3));
 
     ULONG nOutWPix = aPage.GetWidth();
@@ -1829,23 +1660,23 @@ void SwMarkPreview::Paint(const Rectangle &/*rRect*/)
 
     switch (nMarkPos)
     {
-        case 1:		// Links
+        case 1:		// left
             aRightMark.SetPos(Point(aRightPagePrtArea.Left() - 2 - aRightMark.GetWidth(), aRightMark.Top()));
             break;
 
-        case 2:		// Rechts
+        case 2:		// right
             aLeftMark.SetPos(Point(aLeftPagePrtArea.Right() + 2, aLeftMark.Top()));
             break;
 
-        case 3:		// Aussen
+        case 3:		// outside
             break;
 
-        case 4:		// Innen
+        case 4:		// inside
             aLeftMark.SetPos(Point(aLeftPagePrtArea.Right() + 2, aLeftMark.Top()));
             aRightMark.SetPos(Point(aRightPagePrtArea.Left() - 2 - aRightMark.GetWidth(), aRightMark.Top()));
             break;
 
-        case 0:		// Keine
+        case 0:		// none
         default:
             return;
     }
@@ -2128,12 +1959,12 @@ void SwRedlineOptionsTabPage::Reset( const SfxItemSet&  )
     const AuthorCharAttr &rDeletedAttr = pOpt->GetDeletedAuthorAttr();
     const AuthorCharAttr &rChangedAttr = pOpt->GetFormatAuthorAttr();
 
-    // Preview initialisieren
+    // initialise preview
     InitFontStyle(aInsertedPreviewWN);
     InitFontStyle(aDeletedPreviewWN);
     InitFontStyle(aChangedPreviewWN);
 
-    // Farblistboxen initialisieren
+    // initialisieren colour list box
     String sColor;
     aInsertColorLB.SetUpdateMode(FALSE);
     aDeletedColorLB.SetUpdateMode(FALSE);
@@ -2232,7 +2063,7 @@ void SwRedlineOptionsTabPage::Reset( const SfxItemSet&  )
     }
     aMarkPosLB.SelectEntryPos(nPos);
 
-    // Einstellungen in Preview anzeigen
+    // show settings in preview
     AttribHdl(&aInsertLB);
     ColorHdl(&aInsertColorLB);
     AttribHdl(&aDeletedLB);
@@ -2472,12 +2303,7 @@ void SwRedlineOptionsTabPage::InitFontStyle(SvxFontPrevWindow& rExampleWin)
 }
 
 
-#ifdef DBG_UTIL
-/*******************************************************
- ******************************************************/
-/*----------------- OS 11.01.95  -----------------------
- TabPage Testeinstellungen
--------------------------------------------------------*/
+#if OSL_DEBUG_LEVEL > 1
 
 void lcl_SetPosSize(Window& rWin, Point aPos, Size aSize)
 {
@@ -2541,17 +2367,11 @@ SwTestTabPage::SwTestTabPage( Window* pParent,
 
 }
 
-
-//------------------------------------------------------------------------
-
-
 SfxTabPage*	SwTestTabPage::Create( Window* pParent,
                                        const SfxItemSet& rAttrSet )
 {
     return ( new SwTestTabPage( pParent, rAttrSet ) );
 }
-//------------------------------------------------------------------------
-
 
 BOOL 	SwTestTabPage::FillItemSet( SfxItemSet& rCoreSet )
 {
@@ -2573,8 +2393,6 @@ BOOL 	SwTestTabPage::FillItemSet( SfxItemSet& rCoreSet )
     }
     return bAttrModified;
 }
-//------------------------------------------------------------------------
-
 
 void SwTestTabPage::Reset( const SfxItemSet& )
 {
@@ -2596,8 +2414,6 @@ void SwTestTabPage::Reset( const SfxItemSet& )
         aTest10CBox.Check(pTestAttr->bTest10);
     }
 }
-//------------------------------------------------------------------------
-
 
 void SwTestTabPage::Init()
 {
@@ -2614,8 +2430,6 @@ void SwTestTabPage::Init()
     aTest9CBox.SetClickHdl( aLk );
     aTest10CBox.SetClickHdl( aLk );
 }
-//------------------------------------------------------------------------
-
 
 IMPL_LINK_INLINE_START( SwTestTabPage, AutoClickHdl, CheckBox *, EMPTYARG )
 {
@@ -2627,3 +2441,4 @@ IMPL_LINK_INLINE_END( SwTestTabPage, AutoClickHdl, CheckBox *, EMPTYARG )
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
