@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -30,18 +31,12 @@
 
 
 #include <hintids.hxx>
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
 
 
 #include <svtools/textview.hxx>
-#ifndef _SVX_SVXIDS_HRC
 #include <svx/svxids.hrc>
-#endif
-#ifndef _SCRBAR_HXX //autogen
 #include <vcl/scrbar.hxx>
-#endif
 #include <sfx2/dispatch.hxx>
 #include <sfx2/app.hxx>
 #include <svtools/htmltokn.h>
@@ -53,15 +48,9 @@
 #include <svtools/ctrltool.hxx>
 #include <tools/time.hxx>
 #include <swmodule.hxx>
-#ifndef _DOCSH_HXX
 #include <docsh.hxx>
-#endif
-#ifndef _SRCVIEW_HXX
 #include <srcview.hxx>
-#endif
-#ifndef _HELPID_H
 #include <helpid.h>
-#endif
 
 
 struct SwTextPortion
@@ -180,8 +169,8 @@ static void lcl_Highlight(const String& rSource, SwTextPortions& aPortionList)
                     {
                         //was war das denn?
 #if OSL_DEBUG_LEVEL > 1
-                        DBG_ERROR("Token nicht erkannt!");
-                        DBG_ERROR(ByteString(sToken, gsl_getSystemTextEncoding()).GetBuffer());
+                        OSL_ENSURE(false, "Token not recognised!");
+                        OSL_ENSURE(false, ByteString(sToken, gsl_getSystemTextEncoding()).GetBuffer());
 #endif
                     }
 
@@ -625,7 +614,7 @@ IMPL_LINK(SwSrcEditWindow, ScrollHdl, ScrollBar*, pScroll)
 IMPL_LINK( SwSrcEditWindow, SyntaxTimerHdl, Timer *, pTimer )
 {
     Time aSyntaxCheckStart;
-    DBG_ASSERT( pTextView, "Noch keine View, aber Syntax-Highlight ?!" );
+    OSL_ENSURE( pTextView, "Noch keine View, aber Syntax-Highlight ?!" );
     // pTextEngine->SetUpdateMode( FALSE );
 
     bHighlighting = TRUE;
@@ -774,13 +763,13 @@ void SwSrcEditWindow::ImpDoHighlight( const String& rSource, USHORT nLineOff )
         // optimiert das die TextEngine.
         USHORT nLastEnd = 0;
 
-#ifdef DBG_UTIL
-        USHORT nLine = aPortionList[0].nLine;
-#endif
         for ( USHORT i = 0; i < nCount; i++ )
         {
             SwTextPortion& r = aPortionList[i];
-            DBG_ASSERT( r.nLine == nLine, "doch mehrere Zeilen ?" );
+#if OSL_DEBUG_LEVEL > 1
+            USHORT nLine = aPortionList[0].nLine;
+            OSL_ENSURE( r.nLine == nLine, "doch mehrere Zeilen ?" );
+#endif
             if ( r.nStart > r.nEnd ) 	// Nur bis Bug von MD behoeben
                 continue;
 
@@ -1101,3 +1090,4 @@ void SwSrcEditWindow::SetTextEncoding(rtl_TextEncoding eEncoding)
     SetFont();
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
