@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -256,7 +257,7 @@ static SwWrtShell* lcl_GetShell()
     SwView* pView;
     if ( 0 != (pView = ::GetActiveView()) )
         return pView->GetWrtShellPtr();
-    DBG_ERROR("no current shell found!");
+    OSL_ENSURE(false, "no current shell found!");
     return 0;
 }
 
@@ -290,7 +291,7 @@ BOOL  SwFldMgr::CanInsertRefMark( const String& rStr )
 {
     BOOL bRet = FALSE;
     SwWrtShell *pSh = pWrtShell ? pWrtShell : lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     if(pSh)
     {
         USHORT nCnt = pSh->GetCrsrCnt();
@@ -311,7 +312,7 @@ BOOL  SwFldMgr::CanInsertRefMark( const String& rStr )
 void SwFldMgr::RemoveFldType(USHORT nResId, const String& rName )
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     if( pSh )
         pSh->RemoveFldType(nResId, rName);
 }
@@ -319,7 +320,7 @@ void SwFldMgr::RemoveFldType(USHORT nResId, const String& rName )
 USHORT SwFldMgr::GetFldTypeCount(USHORT nResId) const
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     return pSh ? pSh->GetFldTypeCount(nResId) : 0;
 }
 
@@ -327,7 +328,7 @@ USHORT SwFldMgr::GetFldTypeCount(USHORT nResId) const
 SwFieldType* SwFldMgr::GetFldType(USHORT nResId, USHORT nId) const
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     return pSh ? pSh->GetFldType(nId, nResId) : 0;
 }
 
@@ -335,7 +336,7 @@ SwFieldType* SwFldMgr::GetFldType(USHORT nResId, USHORT nId) const
 SwFieldType* SwFldMgr::GetFldType(USHORT nResId, const String& rName) const
 {
     SwWrtShell * pSh = pWrtShell ? pWrtShell : lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     return pSh ? pSh->GetFldType(nResId, rName) : 0;
 }
 
@@ -453,14 +454,14 @@ USHORT SwFldMgr::GetGroup(BOOL bHtmlMode, USHORT nTypeId, USHORT nSubType) const
 
 USHORT SwFldMgr::GetTypeId(USHORT nPos)
 {
-    ASSERT(nPos < ::GetPackCount(), "unzulaessige Pos");
+    OSL_ENSURE(nPos < ::GetPackCount(), "forbidden Pos");
     return aSwFlds[ nPos ].nTypeId;
 }
 
 
 const String& SwFldMgr::GetTypeStr(USHORT nPos)
 {
-    ASSERT(nPos < ::GetPackCount(), "unzulaessige TypeId");
+    OSL_ENSURE(nPos < ::GetPackCount(), "forbidden TypeId");
 
     USHORT nFldWh = aSwFlds[ nPos ].nTypeId;
 
@@ -509,7 +510,7 @@ BOOL SwFldMgr::GetSubTypes(USHORT nTypeId, SvStringsDtor& rToFill)
 {
     BOOL bRet = FALSE;
     SwWrtShell *pSh = pWrtShell ? pWrtShell : lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     if(pSh)
     {
         const USHORT nPos = GetPos(nTypeId);
@@ -559,10 +560,10 @@ BOOL SwFldMgr::GetSubTypes(USHORT nTypeId, SvStringsDtor& rToFill)
                        (nTypeId == TYP_SEQFLD && nWhich == RES_SETEXPFLD  &&
                        (((SwSetExpFieldType*)pFldType)->GetType() & nsSwGetSetExpType::GSE_SEQ)) ||
 
-                       ((nTypeId == TYP_INPUTFLD  || nTypeId == TYP_FORMELFLD) &&
+                       ((nTypeId == TYP_INPUTFLD || nTypeId == TYP_FORMELFLD) &&
                          (nWhich == RES_USERFLD ||
-                          nWhich == RES_SETEXPFLD &&
-                          !(((SwSetExpFieldType*)pFldType)->GetType() & nsSwGetSetExpType::GSE_SEQ)) ) )
+                          (nWhich == RES_SETEXPFLD &&
+                           !(((SwSetExpFieldType*)pFldType)->GetType() & nsSwGetSetExpType::GSE_SEQ)) )) )
                     {
                         String* pNew = new String(pFldType->GetName());
                         rToFill.Insert(pNew, rToFill.Count());
@@ -618,7 +619,7 @@ BOOL SwFldMgr::GetSubTypes(USHORT nTypeId, SvStringsDtor& rToFill)
 
 USHORT SwFldMgr::GetFormatCount(USHORT nTypeId, BOOL bIsText, BOOL bHtmlMode) const
 {
-    ASSERT(nTypeId < TYP_END, "unzulaessige TypeId");
+    OSL_ENSURE(nTypeId < TYP_END, "forbidden TypeId");
 
     {
         const USHORT nPos = GetPos(nTypeId);
@@ -676,7 +677,7 @@ USHORT SwFldMgr::GetFormatCount(USHORT nTypeId, BOOL bIsText, BOOL bHtmlMode) co
 String SwFldMgr::GetFormatStr(USHORT nTypeId, ULONG nFormatId) const
 {
     String aRet;
-    ASSERT(nTypeId < TYP_END, "unzulaessige TypeId");
+    OSL_ENSURE(nTypeId < TYP_END, "forbidden TypeId");
 
     const USHORT nPos = GetPos(nTypeId);
 
@@ -836,7 +837,7 @@ BOOL SwFldMgr::GoNextPrev( BOOL bNext, SwFieldType* pTyp )
 void SwFldMgr::InsertFldType(SwFieldType& rType)
 {
     SwWrtShell* pSh = pWrtShell ? pWrtShell : ::lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     if(pSh)
         pSh->InsertFldType(rType);
 }
@@ -868,7 +869,7 @@ BOOL SwFldMgr::InsertFld(  const SwInsertFld_Data& rData )
     SwWrtShell* pCurShell = rData.pSh;
     if(!pCurShell)
         pCurShell = pWrtShell ? pWrtShell : ::lcl_GetShell();
-    DBG_ASSERT(pCurShell, "no SwWrtShell found");
+    OSL_ENSURE(pCurShell, "no SwWrtShell found");
     if(!pCurShell)
         return FALSE;
 
@@ -1376,11 +1377,11 @@ BOOL SwFldMgr::InsertFld(  const SwInsertFld_Data& rData )
         }
         break;
         default:
-        {	ASSERT(!this, "Falscher Feldtyp");
+        {	OSL_ENSURE(!this, "wrong field type");
             return FALSE;
         }
     }
-    ASSERT(pFld, "Feld nicht vorhanden");
+    OSL_ENSURE(pFld, "field not available");
 
 
      //the auto language flag has to be set prior to the language!
@@ -1425,7 +1426,7 @@ void SwFldMgr::UpdateCurFld(ULONG nFormat,
                             SwField * _pTmpFld) // #111840#
 {
     // Format aendern
-    ASSERT(pCurFld, "kein Feld an der CursorPos");
+    OSL_ENSURE(pCurFld, "no field at CursorPos");
 
     bool bDelete = false;
     SwField *pTmpFld;		// mb: fixed memory leak
@@ -1443,7 +1444,7 @@ void SwFldMgr::UpdateCurFld(ULONG nFormat,
     const USHORT nTypeId = pTmpFld->GetTypeId();
 
     SwWrtShell* pSh = pWrtShell ? pWrtShell : ::lcl_GetShell();
-    DBG_ASSERT(pSh, "no SwWrtShell found");
+    OSL_ENSURE(pSh, "no SwWrtShell found");
     if(!pSh)
         return;
     pSh->StartAllAction();
@@ -1675,10 +1676,6 @@ void SwFieldType::_GetFldName()
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 BOOL SwFldMgr::ChooseMacro(const String&)
 {
     BOOL bRet = FALSE;
@@ -1709,8 +1706,8 @@ void SwFldMgr::SetMacroPath(const String& rPath)
 
     Reference< uri::XUriReferenceFactory >
         xFactory( xSMgr->createInstance(
-            ::rtl::OUString::createFromAscii(
-                "com.sun.star.uri.UriReferenceFactory" ) ), UNO_QUERY );
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                "com.sun.star.uri.UriReferenceFactory" )) ), UNO_QUERY );
 
     if ( xFactory.is() )
     {
@@ -1724,10 +1721,6 @@ void SwFldMgr::SetMacroPath(const String& rPath)
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 ULONG SwFldMgr::GetDefaultFormat(USHORT nTypeId, BOOL bIsText, SvNumberFormatter* pFormatter, double* pVal)
 {
     double fValue;
@@ -1774,20 +1767,19 @@ ULONG SwFldMgr::GetDefaultFormat(USHORT nTypeId, BOOL bIsText, SvNumberFormatter
     return pFormatter->GetStandardFormat(nDefFormat, GetCurrLanguage());
 }
 
-/* -----------------------------01.03.01 16:46--------------------------------
-
- ---------------------------------------------------------------------------*/
 Reference<XNumberingTypeInfo> SwFldMgr::GetNumberingInfo() const
 {
     if(!xNumberingInfo.is())
     {
         Reference< XMultiServiceFactory > xMSF = ::comphelper::getProcessServiceFactory();
         Reference < XInterface > xI = xMSF->createInstance(
-            ::rtl::OUString::createFromAscii(
-                            "com.sun.star.text.DefaultNumberingProvider" ));
+            ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM(
+                            "com.sun.star.text.DefaultNumberingProvider" )));
         Reference<XDefaultNumberingProvider> xDefNum(xI, UNO_QUERY);
-        DBG_ASSERT(xDefNum.is(), "service missing: \"com.sun.star.text.DefaultNumberingProvider\"");
+        OSL_ENSURE(xDefNum.is(), "service missing: \"com.sun.star.text.DefaultNumberingProvider\"");
         ((SwFldMgr*)this)->xNumberingInfo = Reference<XNumberingTypeInfo>(xDefNum, UNO_QUERY);
     }
     return xNumberingInfo;
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
