@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -38,33 +39,20 @@
 #include <docufld.hxx>
 #include <expfld.hxx>
 #include <ddefld.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <wrtsh.hxx>
 #include <doc.hxx>
 #include <docary.hxx>
 #include <swmodule.hxx>
-#ifndef _FLDVAR_HXX
 #include <fldvar.hxx>
-#endif
 #include <calc.hxx>
 #include <svl/zformat.hxx>
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
-#ifndef _FLDUI_HRC
 #include <fldui.hrc>
-#endif
-#ifndef _FLDTDLG_HRC
 #include <fldtdlg.hrc>
-#endif
 
 #define USER_DATA_VERSION_1 "1"
 #define USER_DATA_VERSION USER_DATA_VERSION_1
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
 
 SwFldVarPage::SwFldVarPage(Window* pParent, const SfxItemSet& rCoreSet ) :
     SwFldPage		( pParent, SW_RES( TP_FLD_VAR ), rCoreSet ),
@@ -109,18 +97,10 @@ SwFldVarPage::SwFldVarPage(Window* pParent, const SfxItemSet& rCoreSet ) :
     aNumFormatLB.SetShowLanguageControl(TRUE);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SwFldVarPage::~SwFldVarPage()
 {
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwFldVarPage::Reset(const SfxItemSet& )
 {
     SavePos(&aTypeLB);
@@ -214,10 +194,6 @@ void SwFldVarPage::Reset(const SfxItemSet& )
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldVarPage, TypeHdl, ListBox *, EMPTYARG )
 {
     // Alte ListBoxPos sichern
@@ -250,10 +226,6 @@ IMPL_LINK( SwFldVarPage, TypeHdl, ListBox *, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldVarPage, SubTypeHdl, ListBox *, pBox )
 {
     USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
@@ -621,7 +593,6 @@ IMPL_LINK( SwFldVarPage, SubTypeHdl, ListBox *, pBox )
 /*--------------------------------------------------------------------
      Beschreibung: Typen in der SelectionBox erneuern
  --------------------------------------------------------------------*/
-
 void SwFldVarPage::UpdateSubType()
 {
     String sOldSel;
@@ -725,10 +696,6 @@ void SwFldVarPage::UpdateSubType()
     aSelectionLB.SetUpdateMode(TRUE);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 USHORT SwFldVarPage::FillFormatLB(USHORT nTypeId)
 {
     String sOldSel, sOldNumSel;
@@ -861,7 +828,6 @@ USHORT SwFldVarPage::FillFormatLB(USHORT nTypeId)
 /*--------------------------------------------------------------------
     Beschreibung: Modify
  --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldVarPage, ModifyHdl, Edit *, EMPTYARG )
 {
     String sValue(aValueED.GetText());
@@ -988,10 +954,6 @@ IMPL_LINK( SwFldVarPage, ModifyHdl, Edit *, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldVarPage, TBClickHdl, ToolBox *, pBox )
 {
     USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
@@ -1140,10 +1102,6 @@ IMPL_LINK( SwFldVarPage, TBClickHdl, ToolBox *, pBox )
     return TRUE;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldVarPage, ChapterHdl, ListBox *, EMPTYARG )
 {
     BOOL bEnable = aChapterLevelLB.GetSelectEntryPos() != 0;
@@ -1155,10 +1113,6 @@ IMPL_LINK( SwFldVarPage, ChapterHdl, ListBox *, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwFldVarPage, SeparatorHdl, Edit *, EMPTYARG )
 {
     BOOL bEnable = aSeparatorED.GetText().Len() != 0 ||
@@ -1168,10 +1122,6 @@ IMPL_LINK( SwFldVarPage, SeparatorHdl, Edit *, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 BOOL SwFldVarPage::FillItemSet(SfxItemSet& )
 {
     USHORT nTypeId = (USHORT)(ULONG)aTypeLB.GetEntryData(GetTypeSel());
@@ -1303,30 +1253,17 @@ BOOL SwFldVarPage::FillItemSet(SfxItemSet& )
     return FALSE;
 }
 
-
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SfxTabPage* SwFldVarPage::Create( 	Window* pParent,
                         const SfxItemSet& rAttrSet )
 {
     return ( new SwFldVarPage( pParent, rAttrSet ) );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 USHORT SwFldVarPage::GetGroup()
 {
     return GRP_VAR;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 SelectionListBox::SelectionListBox( SwFldVarPage* pDialog, const ResId& rResId ) :
     ListBox	(pDialog, rResId),
     pDlg	(pDialog),
@@ -1334,10 +1271,6 @@ SelectionListBox::SelectionListBox( SwFldVarPage* pDialog, const ResId& rResId )
 {
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 long SelectionListBox::PreNotify( NotifyEvent& rNEvt )
 {
     long nHandled = ListBox::PreNotify( rNEvt );
@@ -1365,9 +1298,7 @@ long SelectionListBox::PreNotify( NotifyEvent& rNEvt )
 
     return nHandled;
 }
-/* -----------------12.01.99 11:14-------------------
- *
- * --------------------------------------------------*/
+
 void SwFldVarPage::FillUserData()
 {
     String sData(String::CreateFromAscii(USER_DATA_VERSION));
@@ -1381,3 +1312,4 @@ void SwFldVarPage::FillUserData()
     SetUserData(sData);
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
