@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,9 +34,7 @@
 
 #include "swuiidxmrk.hxx"
 #include <hintids.hxx>
-#ifndef _HELPID_H
 #include <helpid.h>
-#endif
 #define _SVSTDARR_STRINGSSORT
 #include <svl/svstdarr.hxx>
 #include <comphelper/processfactory.hxx>
@@ -46,9 +45,7 @@
 #include <com/sun/star/util/SearchFlags.hpp>
 #include <com/sun/star/i18n/TransliterationModules.hpp>
 #include <svl/stritem.hxx>
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <sfx2/dispatch.hxx>
 #include <svl/eitem.hxx>
 #include <svtools/txtcmp.hxx>
@@ -60,20 +57,12 @@
 #include <idxmrk.hxx>
 #include <txttxmrk.hxx>
 #include <wrtsh.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <multmrk.hxx>
 #include <swundo.hxx>               	// fuer Undo-Ids
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
-#ifndef _INDEX_HRC
 #include <index.hrc>
-#endif
-#ifndef _IDXMRK_HRC
 #include <idxmrk.hrc>
-#endif
 #include <swmodule.hxx>
 #include <fldmgr.hxx>
 #include <fldbas.hxx>
@@ -250,14 +239,12 @@ SwIndexMarkDlg::SwIndexMarkDlg(Window *pParent,
      Beschreibung:	Controls neu initialisieren mit der aktuellen
                     Markierung
  --------------------------------------------------------------------*/
-
-
 void SwIndexMarkDlg::InitControls()
 {
-    DBG_ASSERT(pSh && pTOXMgr, "Shell nicht da?");
+    OSL_ENSURE(pSh && pTOXMgr, "no shell?");
     // Inhalts-Verzeichnis
     const SwTOXType* pType = pTOXMgr->GetTOXType(TOX_CONTENT, 0);
-    ASSERT(pType, "Kein Verzeichnistyp !!");
+    OSL_ENSURE(pType, "Kein Verzeichnistyp !!");
     String sTmpTypeSelection;
     if(aTypeDCB.GetSelectEntryCount())
         sTmpTypeSelection = aTypeDCB.GetSelectEntry();
@@ -266,7 +253,7 @@ void SwIndexMarkDlg::InitControls()
 
     // Stichwort-Verzeichnis
     pType = pTOXMgr->GetTOXType(TOX_INDEX, 0);
-    ASSERT(pType, "Kein Verzeichnistyp !!");
+    OSL_ENSURE(pType, "Kein Verzeichnistyp !!");
     aTypeDCB.InsertEntry(pType->GetTypeName());
 
     // Benutzerverzeichnisse
@@ -381,19 +368,19 @@ void	SwIndexMarkDlg::UpdateLanguageDependenciesForPhoneticReading()
     //get the current language
     if(!bNewMark) //if dialog is opened to iterate existing marks
     {
-        ASSERT(pTOXMgr, "need TOXMgr")
+        OSL_ENSURE(pTOXMgr, "need TOXMgr");
         if(!pTOXMgr)
             return;
         SwTOXMark* pMark = pTOXMgr->GetCurTOXMark();
-        ASSERT(pMark, "need current SwTOXMark");
+        OSL_ENSURE(pMark, "need current SwTOXMark");
         if(!pMark)
             return;
         SwTxtTOXMark* pTxtTOXMark = pMark->GetTxtTOXMark();
-        ASSERT(pTxtTOXMark, "need current SwTxtTOXMark");
+        OSL_ENSURE(pTxtTOXMark, "need current SwTxtTOXMark");
         if(!pTxtTOXMark)
             return;
         const SwTxtNode* pTxtNode = pTxtTOXMark->GetpTxtNd();
-        ASSERT(pTxtNode, "need current SwTxtNode");
+        OSL_ENSURE(pTxtNode, "need current SwTxtNode");
         if(!pTxtNode)
             return;
         xub_StrLen nTextIndex = *pTxtTOXMark->GetStart();
@@ -436,7 +423,6 @@ String	SwIndexMarkDlg::GetDefaultPhoneticReading( const String& rText )
 /* -----------------07.09.99 10:43-------------------
     Change the content of aEntryED if text is selected
  --------------------------------------------------*/
-
 void	SwIndexMarkDlg::Activate()
 {
     // aktuelle Selektion (1.Element) anzeigen  ????
@@ -476,8 +462,6 @@ void SwIndexMarkDlg::Apply()
 /*--------------------------------------------------------------------
     Beschreibung: Aenderungen uebernehmen
  --------------------------------------------------------------------*/
-
-
 void SwIndexMarkDlg::InsertUpdate()
 {
     pSh->StartUndo(bDel ? UNDO_INDEX_ENTRY_DELETE : UNDO_INDEX_ENTRY_INSERT);
@@ -597,8 +581,6 @@ void SwIndexMarkDlg::InsertMark()
 /*--------------------------------------------------------------------
      Beschreibung:	Marke Updaten
  --------------------------------------------------------------------*/
-
-
 void SwIndexMarkDlg::UpdateMark()
 {
     String 	aAltText(aEntryED.GetText());
@@ -641,8 +623,6 @@ void SwIndexMarkDlg::UpdateMark()
 /*--------------------------------------------------------------------
     Beschreibung: Neue Keys eintragen
  --------------------------------------------------------------------*/
-
-
 void SwIndexMarkDlg::UpdateKeyBoxes()
 {
     String aKey(aKeyDCB.GetText());
@@ -661,9 +641,7 @@ void SwIndexMarkDlg::UpdateKeyBoxes()
         aKey2DCB.InsertEntry(aKey);
     }
 }
-/* -----------------13.10.99 15:10-------------------
 
- --------------------------------------------------*/
 class SwNewUserIdxDlg : public ModalDialog
 {
     OKButton 		aOKPB;
@@ -719,9 +697,7 @@ IMPL_LINK( SwIndexMarkDlg, NewUserIdxHdl, Button*, EMPTYARG)
     delete pDlg;
     return 0;
 }
-/* -----------------------------17.01.00 12:18--------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK( SwIndexMarkDlg, SearchTypeHdl, CheckBox*, pBox)
 {
     sal_Bool bEnable = pBox->IsChecked() && pBox->IsEnabled();
@@ -729,9 +705,7 @@ IMPL_LINK( SwIndexMarkDlg, SearchTypeHdl, CheckBox*, pBox)
     aSearchCaseSensitiveCB.Enable(bEnable);
     return 0;
 }
-/* -----------------07.09.99 10:30-------------------
 
- --------------------------------------------------*/
 IMPL_LINK( SwIndexMarkDlg, InsertHdl, Button *, pButton )
 {
     Apply();
@@ -740,9 +714,7 @@ IMPL_LINK( SwIndexMarkDlg, InsertHdl, Button *, pButton )
         CloseHdl(pButton);
     return 0;
 }
-/* -----------------07.09.99 10:29-------------------
 
- --------------------------------------------------*/
 IMPL_LINK( SwIndexMarkDlg, CloseHdl, Button *, EMPTYARG )
 {
     if(bNewMark)
@@ -757,6 +729,7 @@ IMPL_LINK( SwIndexMarkDlg, CloseHdl, Button *, EMPTYARG )
     }
     return 0;
 }
+
 /*--------------------------------------------------------------------
      Beschreibung:	VerzeichnisTyp auswaehlen nur bei Einfuegen
  --------------------------------------------------------------------*/
@@ -835,11 +808,6 @@ IMPL_LINK( SwIndexMarkDlg, ModifyHdl, ListBox *, pBox )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
-
 IMPL_LINK_INLINE_START( SwIndexMarkDlg, NextHdl, Button *, EMPTYARG )
 {
     InsertUpdate();
@@ -849,7 +817,6 @@ IMPL_LINK_INLINE_START( SwIndexMarkDlg, NextHdl, Button *, EMPTYARG )
 }
 IMPL_LINK_INLINE_END( SwIndexMarkDlg, NextHdl, Button *, EMPTYARG )
 
-
 IMPL_LINK_INLINE_START( SwIndexMarkDlg, NextSameHdl, Button *, EMPTYARG )
 {
     InsertUpdate();
@@ -859,7 +826,6 @@ IMPL_LINK_INLINE_START( SwIndexMarkDlg, NextSameHdl, Button *, EMPTYARG )
 }
 IMPL_LINK_INLINE_END( SwIndexMarkDlg, NextSameHdl, Button *, EMPTYARG )
 
-
 IMPL_LINK_INLINE_START( SwIndexMarkDlg, PrevHdl, Button *, EMPTYARG )
 {
     InsertUpdate();
@@ -869,7 +835,6 @@ IMPL_LINK_INLINE_START( SwIndexMarkDlg, PrevHdl, Button *, EMPTYARG )
 }
 IMPL_LINK_INLINE_END( SwIndexMarkDlg, PrevHdl, Button *, EMPTYARG )
 
-
 IMPL_LINK_INLINE_START( SwIndexMarkDlg, PrevSameHdl, Button *, EMPTYARG )
 {
     InsertUpdate();
@@ -880,7 +845,6 @@ IMPL_LINK_INLINE_START( SwIndexMarkDlg, PrevSameHdl, Button *, EMPTYARG )
 }
 IMPL_LINK_INLINE_END( SwIndexMarkDlg, PrevSameHdl, Button *, EMPTYARG )
 
-
 IMPL_LINK( SwIndexMarkDlg, DelHdl, Button *, EMPTYARG )
 {
     bDel = sal_True;
@@ -900,13 +864,11 @@ IMPL_LINK( SwIndexMarkDlg, DelHdl, Button *, EMPTYARG )
 /*--------------------------------------------------------------------
      Beschreibung: Dialoganzeige erneuern
  --------------------------------------------------------------------*/
-
-
 void SwIndexMarkDlg::UpdateDialog()
 {
-    DBG_ASSERT(pSh && pTOXMgr, "Shell nicht da?");
+    OSL_ENSURE(pSh && pTOXMgr, "no shell?");
     SwTOXMark* pMark = pTOXMgr->GetCurTOXMark();
-    ASSERT(pMark, "Keine aktuelle Markierung");
+    OSL_ENSURE(pMark, "no current marker");
     if(!pMark)
         return;
 
@@ -1006,7 +968,6 @@ void SwIndexMarkDlg::UpdateDialog()
 /*--------------------------------------------------------------------
      Remind wether the edit boxes for Phonetic reading are changed manually
  --------------------------------------------------------------------*/
-
 IMPL_LINK( SwIndexMarkDlg, PhoneticEDModifyHdl, Edit *, pEdit )
 {
     if(&aPhoneticED0 == pEdit)
@@ -1027,7 +988,6 @@ IMPL_LINK( SwIndexMarkDlg, PhoneticEDModifyHdl, Edit *, pEdit )
 /*--------------------------------------------------------------------
      Beschreibung: Enable Disable des 2. Schluessels
  --------------------------------------------------------------------*/
-
 IMPL_LINK( SwIndexMarkDlg, KeyDCBModifyHdl, ComboBox *, pBox )
 {
     if(&aKeyDCB == pBox)
@@ -1086,16 +1046,12 @@ IMPL_LINK( SwIndexMarkDlg, KeyDCBModifyHdl, ComboBox *, pBox )
 /*-----------------25.02.94 21:19-------------------
  dtor ueberladen
 --------------------------------------------------*/
-
-
 SwIndexMarkDlg::~SwIndexMarkDlg()
 {
     delete pTOXMgr;
     ViewShell::SetCareWin( 0 );
 }
-/* -----------------07.09.99 08:41-------------------
 
- --------------------------------------------------*/
 void    SwIndexMarkDlg::ReInitDlg(SwWrtShell& rWrtShell, SwTOXMark* pCurTOXMark)
 {
     pSh = &rWrtShell;
@@ -1112,9 +1068,7 @@ void    SwIndexMarkDlg::ReInitDlg(SwWrtShell& rWrtShell, SwTOXMark* pCurTOXMark)
     }
     InitControls();
 }
-/* -----------------06.10.99 10:00-------------------
 
- --------------------------------------------------*/
 SwIndexMarkFloatDlg::SwIndexMarkFloatDlg(SfxBindings* _pBindings,
                                    SfxChildWindow* pChild,
                                    Window *pParent,
@@ -1127,9 +1081,7 @@ SfxModelessDialog(_pBindings, pChild, pParent, SvtCJKOptions().IsCJKFontEnabled(
     aDlg.ReInitDlg(*::GetActiveWrtShell());
     Initialize(pInfo);
 }
-/* -----------------06.10.99 10:27-------------------
 
- --------------------------------------------------*/
 void	SwIndexMarkFloatDlg::Activate()
 {
     SfxModelessDialog::Activate();
@@ -1141,9 +1093,6 @@ void SwIndexMarkFloatDlg::ReInitDlg(SwWrtShell& rWrtShell)
     aDlg.ReInitDlg( rWrtShell );
 }
 
-/* -----------------06.10.99 10:35-------------------
-
- --------------------------------------------------*/
 SwIndexMarkModalDlg::SwIndexMarkModalDlg(Window *pParent, SwWrtShell& rSh, SwTOXMark* pCurTOXMark) :
 SvxStandardDialog(pParent, SvtCJKOptions().IsCJKFontEnabled()?SW_RES(DLG_EDIT_IDXMARK_CJK):SW_RES(DLG_EDIT_IDXMARK)),
     aDlg(this, sal_False, SW_RES(WIN_DLG), SvtCJKOptions().IsCJKFontEnabled()?DLG_EDIT_IDXMARK_CJK:DLG_EDIT_IDXMARK, rSh)
@@ -1151,16 +1100,12 @@ SvxStandardDialog(pParent, SvtCJKOptions().IsCJKFontEnabled()?SW_RES(DLG_EDIT_ID
     FreeResource();
     aDlg.ReInitDlg(rSh, pCurTOXMark);
 }
-/* -----------------06.10.99 10:46-------------------
 
- --------------------------------------------------*/
 void	SwIndexMarkModalDlg::Apply()
 {
     aDlg.Apply();
 }
-/* -----------------16.09.99 14:19-------------------
 
- --------------------------------------------------*/
 class SwCreateAuthEntryDlg_Impl : public ModalDialog
 {
     FixedLine       aEntriesFL;
@@ -1198,14 +1143,13 @@ public:
     void			SetCheckNameHdl(const Link& rLink) {aShortNameCheckLink = rLink;}
 
 };
-/*-- 15.09.99 08:43:24---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 struct TextInfo
 {
     sal_uInt16 nToxField;
     sal_uInt16 nHelpId;
 };
+
 static const TextInfo aTextInfoArr[] =
 {
     {AUTH_FIELD_IDENTIFIER,      HID_AUTH_FIELD_IDENTIFIER      },
@@ -1312,23 +1256,17 @@ SwAuthMarkDlg::SwAuthMarkDlg(  Window *pParent,
         aEntryLB.SetSelectHdl(LINK(this, SwAuthMarkDlg, CompEntryHdl));
     }
 }
-/*-- 15.09.99 08:43:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SwAuthMarkDlg::~SwAuthMarkDlg()
 {
 }
-/*-- 15.09.99 08:43:25---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 void	SwAuthMarkDlg::ReInitDlg(SwWrtShell& rWrtShell)
 {
     pSh = &rWrtShell;
     InitControls();
 }
-/* -----------------15.09.99 08:57-------------------
 
- --------------------------------------------------*/
 IMPL_LINK( SwAuthMarkDlg, CloseHdl, PushButton *, EMPTYARG )
 {
     if(bNewEntry)
@@ -1343,9 +1281,7 @@ IMPL_LINK( SwAuthMarkDlg, CloseHdl, PushButton *, EMPTYARG )
     }
     return 0;
 }
-/* -----------------06.12.99 13:54-------------------
 
- --------------------------------------------------*/
 static String lcl_FindColumnEntry(const beans::PropertyValue* pFields, sal_Int32 nLen, const String& rColumnTitle)
 {
     String sRet;
@@ -1362,9 +1298,7 @@ static String lcl_FindColumnEntry(const beans::PropertyValue* pFields, sal_Int32
     }
     return sRet;
 }
-/* -----------------------------07.12.99 15:39--------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK( SwAuthMarkDlg, CompEntryHdl, ListBox*, pBox)
 {
     String sEntry(pBox->GetSelectEntry());
@@ -1411,17 +1345,14 @@ IMPL_LINK( SwAuthMarkDlg, CompEntryHdl, ListBox*, pBox)
     return 0;
 }
 
-/* -----------------15.09.99 08:57-------------------
-
- --------------------------------------------------*/
 IMPL_LINK( SwAuthMarkDlg, InsertHdl, PushButton *, EMPTYARG )
 {
     //insert or update the SwAuthorityField...
     if(pSh)
     {
         sal_Bool bDifferent = sal_False;
-        DBG_ASSERT(m_sFields[AUTH_FIELD_IDENTIFIER].Len() , "No Id is set!");
-        DBG_ASSERT(m_sFields[AUTH_FIELD_AUTHORITY_TYPE].Len() , "No authority type is set!");
+        OSL_ENSURE(m_sFields[AUTH_FIELD_IDENTIFIER].Len() , "No Id is set!");
+        OSL_ENSURE(m_sFields[AUTH_FIELD_AUTHORITY_TYPE].Len() , "No authority type is set!");
         //check if the entry already exists with different content
         const SwAuthorityFieldType* pFType = (const SwAuthorityFieldType*)
                                         pSh->GetFldType(RES_AUTHORITY, aEmptyStr);
@@ -1468,9 +1399,7 @@ IMPL_LINK( SwAuthMarkDlg, InsertHdl, PushButton *, EMPTYARG )
         CloseHdl(0);
     return 0;
 }
-/* -----------------17.09.99 13:06-------------------
 
- --------------------------------------------------*/
 IMPL_LINK(SwAuthMarkDlg, CreateEntryHdl, PushButton*, pButton)
 {
     sal_Bool bCreate = pButton == &aCreateEntryPB;
@@ -1502,7 +1431,7 @@ IMPL_LINK(SwAuthMarkDlg, CreateEntryHdl, PushButton*, pButton)
         }
         if(bCreate)
         {
-            DBG_ASSERT(LISTBOX_ENTRY_NOTFOUND ==
+            OSL_ENSURE(LISTBOX_ENTRY_NOTFOUND ==
                         aEntryLB.GetEntryPos(m_sFields[AUTH_FIELD_IDENTIFIER]),
                         "entry exists!");
             aEntryLB.InsertEntry(m_sFields[AUTH_FIELD_IDENTIFIER]);
@@ -1515,9 +1444,7 @@ IMPL_LINK(SwAuthMarkDlg, CreateEntryHdl, PushButton*, pButton)
     }
     return 0;
 }
-/* -----------------------------20.12.99 14:26--------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwAuthMarkDlg, ChangeSourceHdl, RadioButton*, pButton)
 {
     sal_Bool bFromComp = (pButton == &aFromComponentRB);
@@ -1581,9 +1508,7 @@ IMPL_LINK(SwAuthMarkDlg, ChangeSourceHdl, RadioButton*, pButton)
     CompEntryHdl(&aEntryLB);
     return 0;
 }
-/* -----------------15.10.2002 13:16-----------------
- *
- * --------------------------------------------------*/
+
 IMPL_LINK(SwAuthMarkDlg, EditModifyHdl, Edit*, pEdit)
 {
     Link aAllowed = LINK(this, SwAuthMarkDlg, IsEntryAllowedHdl);
@@ -1597,9 +1522,7 @@ IMPL_LINK(SwAuthMarkDlg, EditModifyHdl, Edit*, pEdit)
     }
     return 0;
 };
-/* -----------------------------20.12.99 15:11--------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwAuthMarkDlg, IsEntryAllowedHdl, Edit*, pEdit)
 {
     String sEntry = pEdit->GetText();
@@ -1621,14 +1544,12 @@ IMPL_LINK(SwAuthMarkDlg, IsEntryAllowedHdl, Edit*, pEdit)
     }
     return bAllowed;
 }
-/* -----------------21.09.99 14:19-------------------
 
- --------------------------------------------------*/
 void SwAuthMarkDlg::InitControls()
 {
-    DBG_ASSERT(pSh, "Shell nicht da?");
+    OSL_ENSURE(pSh, "no shell?");
     SwField* pField = pSh->GetCurFld();
-    ASSERT(bNewEntry || pField, "Keine aktuelle Markierung");
+    OSL_ENSURE(bNewEntry || pField, "no current marker");
     if(bNewEntry)
     {
         ChangeSourceHdl(aFromComponentRB.IsChecked() ? &aFromComponentRB : &aFromDocContentRB);
@@ -1643,7 +1564,7 @@ void SwAuthMarkDlg::InitControls()
     const SwAuthEntry* pEntry = ((SwAuthorityFieldType*)pField->GetTyp())->
             GetEntryByHandle(((SwAuthorityField*)pField)->GetHandle());
 
-    DBG_ASSERT(pEntry, "No authority entry found");
+    OSL_ENSURE(pEntry, "No authority entry found");
     if(!pEntry)
         return;
     for(sal_uInt16 i = 0; i < AUTH_FIELD_END; i++)
@@ -1653,17 +1574,13 @@ void SwAuthMarkDlg::InitControls()
     aAuthorFI.SetText(pEntry->GetAuthorField(AUTH_FIELD_AUTHOR));
     aTitleFI.SetText(pEntry->GetAuthorField(AUTH_FIELD_TITLE));
 }
-/* -----------------------------05.09.2002 09:44------------------------------
 
- ---------------------------------------------------------------------------*/
 void    SwAuthMarkDlg::Activate()
 {
     aOKBT.Enable(!pSh->HasReadonlySel());
     Window::Activate();
 }
-/* -----------------16.09.99 14:27-------------------
 
- --------------------------------------------------*/
 SwCreateAuthEntryDlg_Impl::SwCreateAuthEntryDlg_Impl(Window* pParent,
         const String pFields[],
         SwWrtShell& rSh,
@@ -1815,9 +1732,7 @@ SwCreateAuthEntryDlg_Impl::SwCreateAuthEntryDlg_Impl(Window* pParent,
     SetSizePixel(aDlgSize);
 
 }
-/* -----------------16.09.99 14:47-------------------
 
- --------------------------------------------------*/
 SwCreateAuthEntryDlg_Impl::~SwCreateAuthEntryDlg_Impl()
 {
     for(sal_uInt16 i = 0; i < AUTH_FIELD_END; i++)
@@ -1828,20 +1743,18 @@ SwCreateAuthEntryDlg_Impl::~SwCreateAuthEntryDlg_Impl()
     delete pTypeListBox;
     delete pIdentifierBox;
 }
-/* -----------------16.09.99 14:27-------------------
 
- --------------------------------------------------*/
 String	SwCreateAuthEntryDlg_Impl::GetEntryText(ToxAuthorityField eField) const
 {
     String sRet;
     if( AUTH_FIELD_AUTHORITY_TYPE == eField )
     {
-        DBG_ASSERT(pTypeListBox, "No ListBox");
+        OSL_ENSURE(pTypeListBox, "No ListBox");
         sRet = String::CreateFromInt32(pTypeListBox->GetSelectEntryPos());
     }
     else if( AUTH_FIELD_IDENTIFIER == eField && !m_bNewEntryMode)
     {
-        DBG_ASSERT(pIdentifierBox, "No ComboBox");
+        OSL_ENSURE(pIdentifierBox, "No ComboBox");
         sRet = pIdentifierBox->GetText();
     }
     else
@@ -1858,9 +1771,7 @@ String	SwCreateAuthEntryDlg_Impl::GetEntryText(ToxAuthorityField eField) const
     }
     return sRet;
 }
-/* -----------------21.09.99 13:54-------------------
 
- --------------------------------------------------*/
 IMPL_LINK(SwCreateAuthEntryDlg_Impl, IdentifierHdl, ComboBox*, pBox)
 {
     const SwAuthorityFieldType* pFType = (const SwAuthorityFieldType*)
@@ -1886,9 +1797,6 @@ IMPL_LINK(SwCreateAuthEntryDlg_Impl, IdentifierHdl, ComboBox*, pBox)
     }
     return 0;
 }
-/* -----------------------------20.12.99 15:07--------------------------------
-
- ---------------------------------------------------------------------------*/
 
 IMPL_LINK(SwCreateAuthEntryDlg_Impl, ShortNameHdl, Edit*, pEdit)
 {
@@ -1900,17 +1808,13 @@ IMPL_LINK(SwCreateAuthEntryDlg_Impl, ShortNameHdl, Edit*, pEdit)
     }
     return 0;
 }
-/* -----------------------------20.12.99 15:54--------------------------------
 
- ---------------------------------------------------------------------------*/
 IMPL_LINK(SwCreateAuthEntryDlg_Impl, EnableHdl, ListBox*, pBox)
 {
     aOKBT.Enable(m_bNameAllowed && pBox->GetSelectEntryCount());
     return 0;
 };
-/* -----------------06.10.99 10:00-------------------
 
- --------------------------------------------------*/
 SwAuthMarkFloatDlg::SwAuthMarkFloatDlg(SfxBindings* _pBindings,
                                    SfxChildWindow* pChild,
                                    Window *pParent,
@@ -1922,12 +1826,10 @@ SwAuthMarkFloatDlg::SwAuthMarkFloatDlg(SfxBindings* _pBindings,
     FreeResource();
     Initialize(pInfo);
     SwWrtShell* pWrtShell = ::GetActiveWrtShell();
-    DBG_ASSERT(pWrtShell, "No shell?");
+    OSL_ENSURE(pWrtShell, "No shell?");
     aDlg.ReInitDlg(*pWrtShell);
 }
-/* -----------------06.10.99 10:27-------------------
 
- --------------------------------------------------*/
 void	SwAuthMarkFloatDlg::Activate()
 {
     SfxModelessDialog::Activate();
@@ -1939,9 +1841,6 @@ void SwAuthMarkFloatDlg::ReInitDlg(SwWrtShell& rWrtShell)
     aDlg.ReInitDlg( rWrtShell );
 }
 
-/* -----------------06.10.99 10:35-------------------
-
- --------------------------------------------------*/
 SwAuthMarkModalDlg::SwAuthMarkModalDlg(Window *pParent, SwWrtShell& rSh) :
     SvxStandardDialog(pParent, SW_RES(DLG_EDIT_AUTHMARK)),
     aDlg(this, SW_RES(WIN_DLG), sal_False)
@@ -1949,11 +1848,10 @@ SwAuthMarkModalDlg::SwAuthMarkModalDlg(Window *pParent, SwWrtShell& rSh) :
     FreeResource();
     aDlg.ReInitDlg(rSh);
 }
-/* -----------------06.10.99 10:46-------------------
 
- --------------------------------------------------*/
 void	SwAuthMarkModalDlg::Apply()
 {
     aDlg.InsertHdl(0);
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
