@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -39,9 +40,7 @@
 #include <vcl/menu.hxx>
 #include <vcl/msgbox.hxx>
 #include <vcl/help.hxx>
-#ifndef _SVSTDARR_HXX
 #include <svl/svstdarr.hxx>
-#endif
 #include <svl/stritem.hxx>
 #include <unotools/pathoptions.hxx>
 #include <unotools/lingucfg.hxx>
@@ -79,15 +78,9 @@
 #include <cmdid.h>
 #include <helpid.h>
 #include <swerror.h>
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
-#ifndef _MISC_HRC
 #include <misc.hrc>
-#endif
-#ifndef _GLOSSARY_HRC
 #include <glossary.hrc>
-#endif
 #include <swmodule.hxx>
 #include <sfx2/filedlghelper.hxx>
 
@@ -127,9 +120,6 @@ String lcl_GetValidShortCut( const String& rName )
     return aBuf;
 }
 
-/* -----------------------------08.02.00 10:28--------------------------------
-
- ---------------------------------------------------------------------------*/
 struct GroupUserData
 {
     String 		sGroupName;
@@ -201,7 +191,6 @@ SwNewGlosNameDlg::SwNewGlosNameDlg(Window* pParent,
 /*------------------------------------------------------------------------
  Beschreibung:	aktuell eingestellte Gruppe erfragen / setzen
 ------------------------------------------------------------------------*/
-
 String SwGlossaryDlg::GetCurrGroup()
 {
     if( ::GetCurrGlosGroup() && ::GetCurrGlosGroup()->Len() )
@@ -209,8 +198,6 @@ String SwGlossaryDlg::GetCurrGroup()
     return SwGlossaries::GetDefName();
 }
 
-
-
 void SwGlossaryDlg::SetActGroup(const String &rGrp)
 {
     if( !::GetCurrGlosGroup() )
@@ -218,8 +205,6 @@ void SwGlossaryDlg::SetActGroup(const String &rGrp)
     *(::GetCurrGlosGroup()) = rGrp;
 }
 
-
-
 SwGlossaryDlg::SwGlossaryDlg(SfxViewFrame* pViewFrame,
                             SwGlossaryHdl * pGlosHdl, SwWrtShell *pWrtShell) :
 
@@ -301,10 +286,6 @@ SwGlossaryDlg::SwGlossaryDlg(SfxViewFrame* pViewFrame,
 
     Init();
 }
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
 
 SwGlossaryDlg::~SwGlossaryDlg()
 {
@@ -316,11 +297,10 @@ SwGlossaryDlg::~SwGlossaryDlg()
     delete pMenu;
     delete pExampleFrame;
 }
+
 /*------------------------------------------------------------------------
  Beschreibung:	Auswahl neue Gruppe
 ------------------------------------------------------------------------*/
-
-
 IMPL_LINK( SwGlossaryDlg, GrpSelect, SvTreeListBox *, pBox )
 {
     SvLBoxEntry* pEntry = pBox->FirstSelected();
@@ -363,10 +343,6 @@ IMPL_LINK( SwGlossaryDlg, GrpSelect, SvTreeListBox *, pBox )
     }
     return 0;
 }
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
 
 void SwGlossaryDlg::Apply()
 {
@@ -384,9 +360,7 @@ void SwGlossaryDlg::Apply()
         aReq.Done();
     }
 }
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
+
 /* inline */ void SwGlossaryDlg::EnableShortName(sal_Bool bOn)
 {
     aShortNameLbl.Enable(bOn);
@@ -419,11 +393,6 @@ SvLBoxEntry* SwGlossaryDlg::DoesBlockExist(const String& rBlock,
     return 0;
 }
 
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
-
 IMPL_LINK( SwGlossaryDlg, NameModify, Edit *, pEdit )
 {
     String aName(aNameED.GetText());
@@ -467,10 +436,6 @@ IMPL_LINK( SwGlossaryDlg, NameModify, Edit *, pEdit )
     }
     return 0;
 }
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
 
 IMPL_LINK_INLINE_START( SwGlossaryDlg, NameDoubleClick, SvTreeListBox*, pBox )
 {
@@ -480,10 +445,6 @@ IMPL_LINK_INLINE_START( SwGlossaryDlg, NameDoubleClick, SvTreeListBox*, pBox )
     return 0;
 }
 IMPL_LINK_INLINE_END( SwGlossaryDlg, NameDoubleClick, SvTreeListBox*, EMPTYARG )
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
 
 IMPL_LINK( SwGlossaryDlg, EnableHdl, Menu *, pMn )
 {
@@ -508,10 +469,6 @@ IMPL_LINK( SwGlossaryDlg, EnableHdl, Menu *, pMn )
     pMn->EnableItem( FN_GL_IMPORT, bEnable );
     return 1;
 }
-/*--------------------------------------------------------------------
-     Beschreibung:
- --------------------------------------------------------------------*/
-
 
 IMPL_LINK( SwGlossaryDlg, MenuHdl, Menu *, pMn )
 {
@@ -607,7 +564,7 @@ IMPL_LINK( SwGlossaryDlg, MenuHdl, Menu *, pMn )
                 if(aTitle.Len() && pGlossaryHdl->DelGlossary(aShortName))
                 {
                     SvLBoxEntry* pChild = DoesBlockExist(aTitle, aShortName);
-                    DBG_ASSERT(pChild, "Eintrag nicht gefunden!");
+                    OSL_ENSURE(pChild, "entry not found!");
                     SvLBoxEntry* pParent = aCategoryBox.GetParent(pChild);
                     aCategoryBox.Select(pParent);
 
@@ -695,11 +652,10 @@ IMPL_LINK( SwGlossaryDlg, MenuHdl, Menu *, pMn )
     }
     return 1;
 }
+
 /*--------------------------------------------------------------------
      Beschreibung:	Dialog Verwaltung Bereiche
  --------------------------------------------------------------------*/
-
-
 IMPL_LINK( SwGlossaryDlg, BibHdl, Button *, EMPTYARG )
 {
     SwGlossaries* pGloss = ::GetGlossaries();
@@ -777,8 +733,6 @@ IMPL_LINK( SwGlossaryDlg, BibHdl, Button *, EMPTYARG )
 /*------------------------------------------------------------------------
  Beschreibung:	Initialisierung; aus Ctor und nach Bearbeiten Bereiche
 ------------------------------------------------------------------------*/
-
-
 void SwGlossaryDlg::Init()
 {
     aCategoryBox.SetUpdateMode( sal_False );
@@ -788,6 +742,9 @@ void SwGlossaryDlg::Init()
     SvLBoxEntry* pSelEntry = 0;
     const String sSelStr(::GetCurrGlosGroup()->GetToken(0, GLOS_DELIM));
     const sal_uInt16 nSelPath = static_cast< sal_uInt16 >(::GetCurrGlosGroup()->GetToken(1, GLOS_DELIM).ToInt32());
+    // #i66304# - "My AutoText" comes from mytexts.bau, but should be translated
+    const String sMyAutoTextEnglish(RTL_CONSTASCII_USTRINGPARAM("My AutoText"));
+    const String sMyAutoTextTranslated(SW_RESSTR(STR_MY_AUTOTEXT));
     for(sal_uInt16 nId = 0; nId < nCnt; ++nId )
     {
         String sTitle;
@@ -796,6 +753,8 @@ void SwGlossaryDlg::Init()
             continue;
         if(!sTitle.Len())
             sTitle = sGroupName.GetToken( 0, GLOS_DELIM );
+        if(sTitle == sMyAutoTextEnglish)
+            sTitle = sMyAutoTextTranslated;
         SvLBoxEntry* pEntry = aCategoryBox.InsertEntry( sTitle );
         sal_uInt16 nPath = static_cast< sal_uInt16 >(sGroupName.GetToken( 1, GLOS_DELIM ).ToInt32());
 
@@ -867,10 +826,6 @@ void SwGlossaryDlg::Init()
     aInsertTipCB.Check( pCfg->IsAutoTextTip() );
     aInsertTipCB.SetClickHdl(LINK(this, SwGlossaryDlg, CheckBoxHdl));
 }
-/*------------------------------------------------------------------------
- Beschreibung:
-------------------------------------------------------------------------*/
-
 
 IMPL_LINK_INLINE_START( SwGlossaryDlg, EditHdl, Button *, EMPTYARG )
 {
@@ -890,7 +845,6 @@ IMPL_LINK_INLINE_END( SwGlossaryDlg, EditHdl, Button *, EMPTYARG )
 /*------------------------------------------------------------------------
  Beschreibung:	KeyInput fuer ShortName - Edits ohne Spaces
 ------------------------------------------------------------------------*/
-
 IMPL_LINK( SwNewGlosNameDlg, Modify, Edit *, pBox )
 {
     String aName(aNewName.GetText());
@@ -905,9 +859,6 @@ IMPL_LINK( SwNewGlosNameDlg, Modify, Edit *, pBox )
     aOk.Enable(bEnable);
     return 0;
 }
-/*------------------------------------------------------------------------
- Beschreibung:
-------------------------------------------------------------------------*/
 
 IMPL_LINK( SwNewGlosNameDlg, Rename, Button *, EMPTYARG )
 {
@@ -925,10 +876,6 @@ IMPL_LINK( SwNewGlosNameDlg, Rename, Button *, EMPTYARG )
     return 0;
 }
 
-/*------------------------------------------------------------------------
- Beschreibung:
-------------------------------------------------------------------------*/
-
 IMPL_LINK( SwGlossaryDlg, CheckBoxHdl, CheckBox *, pBox )
 {
     SvxAutoCorrCfg* pCfg = SvxAutoCorrCfg::Get();
@@ -953,9 +900,7 @@ SwGlTreeListBox::SwGlTreeListBox(Window* pParent, const ResId& rResId) :
     FreeResource();
     SetDragDropMode( SV_DRAGDROP_CTRL_MOVE|SV_DRAGDROP_CTRL_COPY );
 }
-/* -----------------30.11.98 10:49-------------------
- *
- * --------------------------------------------------*/
+
 void SwGlTreeListBox::Clear()
 {
     SvLBoxEntry* pEntry = First();
@@ -970,9 +915,6 @@ void SwGlTreeListBox::Clear()
     SvTreeListBox::Clear();
 }
 
-/*-----------------10.06.97 14.52-------------------
-
---------------------------------------------------*/
 void SwGlTreeListBox::RequestHelp( const HelpEvent& rHEvt )
 {
     Point aPos( ScreenToOutputPixel( rHEvt.GetMousePosPixel() ));
@@ -1024,9 +966,7 @@ void SwGlTreeListBox::RequestHelp( const HelpEvent& rHEvt )
         }
     }
 }
-/* -----------------26.11.98 14:42-------------------
- *
- * --------------------------------------------------*/
+
 DragDropMode SwGlTreeListBox::NotifyStartDrag(
                     TransferDataContainer& /*rContainer*/,
                     SvLBoxEntry* pEntry )
@@ -1055,9 +995,7 @@ DragDropMode SwGlTreeListBox::NotifyStartDrag(
     }
     return eRet;
 }
-/* -----------------27.11.98 09:35-------------------
- *
- * --------------------------------------------------*/
+
 sal_Bool    SwGlTreeListBox::NotifyAcceptDrop( SvLBoxEntry* pEntry)
 {
     // TODO: Readonly - Ueberpruefung fehlt noch!
@@ -1067,9 +1005,7 @@ sal_Bool    SwGlTreeListBox::NotifyAcceptDrop( SvLBoxEntry* pEntry)
     return pDestParent != pSrcParent;
 
 }
-/* -----------------26.11.98 14:42-------------------
- *
- * --------------------------------------------------*/
+
 sal_Bool  SwGlTreeListBox::NotifyMoving(   SvLBoxEntry*  pTarget,
                                     SvLBoxEntry*  pEntry,
                                     SvLBoxEntry*& /*rpNewParent*/,
@@ -1115,9 +1051,7 @@ sal_Bool  SwGlTreeListBox::NotifyMoving(   SvLBoxEntry*  pTarget,
     }
     return sal_False; //sonst wird der Eintrag automatisch vorgenommen
 }
-/* -----------------26.11.98 14:42-------------------
- *
- * --------------------------------------------------*/
+
 sal_Bool  SwGlTreeListBox::NotifyCopying(   SvLBoxEntry*  pTarget,
                                     SvLBoxEntry*  pEntry,
                                     SvLBoxEntry*& /*rpNewParent*/,
@@ -1165,10 +1099,6 @@ sal_Bool  SwGlTreeListBox::NotifyCopying(   SvLBoxEntry*  pTarget,
     return sal_False; //sonst wird der Eintrag automatisch vorgenommen
 }
 
-
-/*-----------------10.06.97 15.18-------------------
-
---------------------------------------------------*/
 String SwGlossaryDlg::GetCurrGrpName() const
 {
     SvLBoxEntry* pEntry = aCategoryBox.FirstSelected();
@@ -1185,16 +1115,13 @@ String SwGlossaryDlg::GetCurrGrpName() const
     return sRet;
 }
 
-/*-----------------11.06.97 08.17-------------------
-
---------------------------------------------------*/
 IMPL_LINK( SwGlossaryDlg, PathHdl, Button *, pBtn )
 {
     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
     if(pFact)
     {
         AbstractSvxMultiPathDialog* pDlg = pFact->CreateSvxMultiPathDialog( pBtn );
-        DBG_ASSERT(pDlg, "Dialogdiet fail!");
+        OSL_ENSURE(pDlg, "Dialogdiet fail!");
         SvtPathOptions aPathOpt;
         String sGlosPath( aPathOpt.GetAutoTextPath() );
         pDlg->SetPath(sGlosPath);
@@ -1212,9 +1139,7 @@ IMPL_LINK( SwGlossaryDlg, PathHdl, Button *, pBtn )
     }
     return 0;
 }
-/* -----------------28.07.99 13:48-------------------
 
- --------------------------------------------------*/
 IMPL_LINK( SwGlossaryDlg, ShowPreviewHdl, CheckBox *, pBox )
 {
     sal_Bool bCreated = sal_False;
@@ -1238,9 +1163,7 @@ IMPL_LINK( SwGlossaryDlg, ShowPreviewHdl, CheckBox *, pBox )
 
     return 0;
 };
-/* -----------------18.11.99 17:09-------------------
 
- --------------------------------------------------*/
 IMPL_LINK( SwGlossaryDlg, PreviewLoadedHdl,  void *, EMPTYARG )
 {
     BOOL bShow = aShowExampleCB.IsChecked();
@@ -1250,9 +1173,6 @@ IMPL_LINK( SwGlossaryDlg, PreviewLoadedHdl,  void *, EMPTYARG )
     return 0;
 }
 
-/* -----------------28.07.99 16:28-------------------
-
- --------------------------------------------------*/
 void SwGlossaryDlg::ShowAutoText(const String& rGroup, const String& rShortName)
 {
     if(aExampleWIN.IsVisible())
@@ -1262,9 +1182,7 @@ void SwGlossaryDlg::ShowAutoText(const String& rGroup, const String& rShortName)
         pExampleFrame->ClearDocument( TRUE );
     }
 }
-/* -----------------------------21.12.00 11:33--------------------------------
 
- ---------------------------------------------------------------------------*/
 void	SwGlossaryDlg::ResumeShowAutoText()
 {
     String sGroup, sShortName;
@@ -1302,4 +1220,4 @@ void	SwGlossaryDlg::ResumeShowAutoText()
     ResetResumeData();
 }
 
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
