@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -37,9 +38,7 @@
 #include <redline.hxx>
 #include <tools/datetime.hxx>
 #include <vcl/msgbox.hxx>
-#ifndef _SVSTDARR_HXX
 #include <svl/svstdarr.hxx>
-#endif
 #include <svl/eitem.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/dispatch.hxx>
@@ -47,9 +46,7 @@
 #include <svx/postattr.hxx>
 #include <swtypes.hxx>
 #include <wrtsh.hxx>
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <swmodule.hxx>
 #ifndef _REDLNDLG_HXX
 #define _REDLNACCEPTDLG
@@ -58,21 +55,11 @@
 #include <swwait.hxx>
 #include <uitool.hxx>
 
-#ifndef _HELPID_H
 #include <helpid.h>
-#endif
-#ifndef _CMDID_H
 #include <cmdid.h>
-#endif
-#ifndef _MISC_HRC
 #include <misc.hrc>
-#endif
-#ifndef _REDLNDLG_HRC
 #include <redlndlg.hrc>
-#endif
-#ifndef _SHELLS_HRC
 #include <shells.hrc>
-#endif
 
 // -> #111827#
 #include <comcore.hrc>
@@ -91,10 +78,6 @@
 
 #include <IDocumentRedlineAccess.hxx>
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 SFX_IMPL_MODELESSDIALOG( SwRedlineAcceptChild, FN_REDLINE_ACCEPT )
 
 SV_IMPL_PTRARR(SwRedlineDataParentArr, SwRedlineDataParentPtr)
@@ -105,10 +88,6 @@ SV_IMPL_PTRARR(SvLBoxEntryArr, SvLBoxEntryPtr)
 static USHORT nSortMode = 0xffff;
 static BOOL   bSortDir = TRUE;
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 SwRedlineAcceptChild::SwRedlineAcceptChild( Window* _pParent,
                                             USHORT nId,
                                             SfxBindings* pBindings,
@@ -123,7 +102,6 @@ SwRedlineAcceptChild::SwRedlineAcceptChild( Window* _pParent,
 /*--------------------------------------------------------------------
     Beschreibung: Nach Dok-Wechsel Dialog neu initialisieren
  --------------------------------------------------------------------*/
-
 BOOL SwRedlineAcceptChild::ReInitDlg(SwDocShell *pDocSh)
 {
     BOOL bRet;
@@ -134,10 +112,6 @@ BOOL SwRedlineAcceptChild::ReInitDlg(SwDocShell *pDocSh)
     return bRet;
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 SwModelessRedlineAcceptDlg::SwModelessRedlineAcceptDlg( SfxBindings* _pBindings,
                                                         SwChildWinWrapper* pChild,
                                                         Window *_pParent) :
@@ -149,10 +123,6 @@ SwModelessRedlineAcceptDlg::SwModelessRedlineAcceptDlg( SfxBindings* _pBindings,
     FreeResource();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwModelessRedlineAcceptDlg::Activate()
 {
     SwView *pView = ::GetActiveView();
@@ -183,10 +153,6 @@ void SwModelessRedlineAcceptDlg::Activate()
     pImplDlg->Activate();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwModelessRedlineAcceptDlg::Initialize(SfxChildWinInfo *pInfo)
 {
     String aStr;
@@ -196,39 +162,23 @@ void SwModelessRedlineAcceptDlg::Initialize(SfxChildWinInfo *pInfo)
     SfxModelessDialog::Initialize(pInfo);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwModelessRedlineAcceptDlg::FillInfo(SfxChildWinInfo& rInfo) const
 {
     SfxModelessDialog::FillInfo(rInfo);
     pImplDlg->FillInfo(rInfo.aExtraString);
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 void SwModelessRedlineAcceptDlg::Resize()
 {
     pImplDlg->Resize();
     SfxModelessDialog::Resize();
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 SwModelessRedlineAcceptDlg::~SwModelessRedlineAcceptDlg()
 {
     delete pImplDlg;
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 SwRedlineAcceptDlg::SwRedlineAcceptDlg(Dialog *pParent, BOOL bAutoFmt) :
     pParentDlg		(pParent),
     aTabPagesCTRL   (pParent, SW_RES(CTRL_TABPAGES)),
@@ -315,18 +265,10 @@ SwRedlineAcceptDlg::SwRedlineAcceptDlg(Dialog *pParent, BOOL bAutoFmt) :
     aSelectTimer.SetTimeoutHdl(LINK(this, SwRedlineAcceptDlg, GotoHdl));
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 SwRedlineAcceptDlg::~SwRedlineAcceptDlg()
 {
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 void SwRedlineAcceptDlg::Init(USHORT nStart)
 {
     SwWait aWait( *::GetActiveView()->GetDocShell(), FALSE );
@@ -353,10 +295,6 @@ void SwRedlineAcceptDlg::Init(USHORT nStart)
         pTable->MakeVisible( pSelEntry, sal_True ); //#i70937#, force the scroll
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 void SwRedlineAcceptDlg::InitAuthors()
 {
     SwWrtShell* pSh = ::GetActiveView()->GetWrtShellPtr();
@@ -426,10 +364,6 @@ void SwRedlineAcceptDlg::InitAuthors()
                                 !bOnlyFormatedRedlines );
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 String SwRedlineAcceptDlg::GetRedlineText( const SwRedline& rRedln,
                                         DateTime &rDateTime, USHORT nStack)
 {
@@ -449,10 +383,6 @@ String SwRedlineAcceptDlg::GetRedlineText( const SwRedline& rRedln,
     return sEntry;
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 const String &SwRedlineAcceptDlg::GetActionText(const SwRedline& rRedln, USHORT nStack)
 {
     switch( rRedln.GetType(nStack) )
@@ -468,10 +398,6 @@ const String &SwRedlineAcceptDlg::GetActionText(const SwRedline& rRedln, USHORT
     return aEmptyStr;
 }
 
-/*------------------------------------------------------------------------
-    Beschreibung:
-------------------------------------------------------------------------*/
-
 void SwRedlineAcceptDlg::Resize()
 {
     Size aSz(pParentDlg->GetOutputSizePixel());
@@ -487,7 +413,6 @@ void SwRedlineAcceptDlg::Resize()
 /*--------------------------------------------------------------------
     Beschreibung: Nach Aktivierung neu initialisieren
  --------------------------------------------------------------------*/
-
 void SwRedlineAcceptDlg::Activate()
 {
     // prevent update if flag is set (#102547#)
@@ -593,10 +518,6 @@ void SwRedlineAcceptDlg::Activate()
     InitAuthors();
 }
 
-/* -----------------05.06.98 13:06-------------------
- *
- * --------------------------------------------------*/
-
 USHORT SwRedlineAcceptDlg::CalcDiff(USHORT nStart, BOOL bChild)
 {
     if (!nStart)
@@ -670,10 +591,6 @@ USHORT SwRedlineAcceptDlg::CalcDiff(USHORT nStart, BOOL bChild)
     return USHRT_MAX;
 }
 
-/* -----------------05.06.98 13:57-------------------
- *
- * --------------------------------------------------*/
-
 void SwRedlineAcceptDlg::InsertChilds(SwRedlineDataParent *pParent, const SwRedline& rRedln, const USHORT nAutoFmt)
 {
     String sChild;
@@ -753,10 +670,6 @@ void SwRedlineAcceptDlg::InsertChilds(SwRedlineDataParent *pParent, const SwRedl
     }
 }
 
-/* -----------------05.06.98 15:20-------------------
- *
- * --------------------------------------------------*/
-
 void SwRedlineAcceptDlg::RemoveParents(USHORT nStart, USHORT nEnd)
 {
     SwWrtShell* pSh = ::GetActiveView()->GetWrtShellPtr();
@@ -831,10 +744,6 @@ void SwRedlineAcceptDlg::RemoveParents(USHORT nStart, USHORT nEnd)
     aRedlineParents.DeleteAndDestroy( nStart, nEnd - nStart + 1);
 }
 
-/* -----------------05.06.98 15:20-------------------
- *
- * --------------------------------------------------*/
-
 void SwRedlineAcceptDlg::InsertParents(USHORT nStart, USHORT nEnd)
 {
     SwView *pView	= ::GetActiveView();
@@ -898,10 +807,6 @@ void SwRedlineAcceptDlg::InsertParents(USHORT nStart, USHORT nEnd)
     }
 }
 
-/* -----------------05.06.98 13:06-------------------
- *
- * --------------------------------------------------*/
-
 void SwRedlineAcceptDlg::CallAcceptReject( BOOL bSelect, BOOL bAccept )
 {
     SwWrtShell* pSh = ::GetActiveView()->GetWrtShellPtr();
@@ -912,7 +817,7 @@ void SwRedlineAcceptDlg::CallAcceptReject( BOOL bSelect, BOOL bAccept )
     ListBoxEntries_t aRedlines;
 
     // don't activate
-    DBG_ASSERT( bInhibitActivate == false,
+    OSL_ENSURE( bInhibitActivate == false,
                 "recursive call of CallAcceptReject?");
     bInhibitActivate = true;
 
@@ -999,10 +904,6 @@ void SwRedlineAcceptDlg::CallAcceptReject( BOOL bSelect, BOOL bAccept )
     pTPView->EnableUndo();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 USHORT SwRedlineAcceptDlg::GetRedlinePos( const SvLBoxEntry& rEntry ) const
 {
     SwWrtShell* pSh = ::GetActiveView()->GetWrtShellPtr();
@@ -1010,50 +911,30 @@ USHORT SwRedlineAcceptDlg::GetRedlinePos( const SvLBoxEntry& rEntry ) const
                                     rEntry.GetUserData())->pData)->pData );
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, AcceptHdl, void*, EMPTYARG)
 {
     CallAcceptReject( TRUE, TRUE );
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, AcceptAllHdl, void*, EMPTYARG )
 {
     CallAcceptReject( FALSE, TRUE );
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, RejectHdl, void*, EMPTYARG )
 {
     CallAcceptReject( TRUE, FALSE );
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, RejectAllHdl, void*, EMPTYARG )
 {
     CallAcceptReject( FALSE, FALSE );
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, UndoHdl, void*, EMPTYARG )
 {
     SwView * pView = ::GetActiveView();
@@ -1066,10 +947,6 @@ IMPL_LINK( SwRedlineAcceptDlg, UndoHdl, void*, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, FilterChangedHdl, void*, EMPTYARG )
 {
     SvxTPFilter *pFilterTP = aTabPagesCTRL.GetFilterPage();
@@ -1084,10 +961,6 @@ IMPL_LINK( SwRedlineAcceptDlg, FilterChangedHdl, void*, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, DeselectHdl, void*, EMPTYARG )
 {
     // Flackern der Buttons vermeiden:
@@ -1096,10 +969,6 @@ IMPL_LINK( SwRedlineAcceptDlg, DeselectHdl, void*, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, SelectHdl, void*, EMPTYARG )
 {
     aDeselectTimer.Stop();
@@ -1108,10 +977,6 @@ IMPL_LINK( SwRedlineAcceptDlg, SelectHdl, void*, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, GotoHdl, void*, EMPTYARG )
 {
     SwWrtShell* pSh = ::GetActiveView()->GetWrtShellPtr();
@@ -1186,10 +1051,6 @@ IMPL_LINK( SwRedlineAcceptDlg, GotoHdl, void*, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 IMPL_LINK( SwRedlineAcceptDlg, CommandHdl, void*, EMPTYARG )
 {
     const CommandEvent aCEvt(pTable->GetCommandEvent());
@@ -1259,16 +1120,16 @@ IMPL_LINK( SwRedlineAcceptDlg, CommandHdl, void*, EMPTYARG )
 
                         /* enable again once we have redline comments in the margin
                         sComment = rRedline.GetComment();
-                        if ( sComment == String(::rtl::OUString::createFromAscii("")) )
+                        if ( !sComment.Len() )
                             GetActiveView()->GetDocShell()->Broadcast(SwRedlineHint(&rRedline,SWREDLINE_INSERTED));
                         const_cast<SwRedline&>(rRedline).Broadcast(SwRedlineHint(&rRedline,SWREDLINE_FOCUS));
                         */
 
                         sComment = rRedline.GetComment();
                         SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-                        DBG_ASSERT(pFact, "Dialogdiet fail!");
+                        OSL_ENSURE(pFact, "Dialogdiet fail!");
                         ::DialogGetRanges fnGetRange = pFact->GetDialogGetRangesFunc( RID_SVXDLG_POSTIT );
-                        DBG_ASSERT(fnGetRange, "Dialogdiet fail! GetRanges()");
+                        OSL_ENSURE(fnGetRange, "Dialogdiet fail! GetRanges()");
                         SfxItemSet aSet( pSh->GetAttrPool(), fnGetRange() );
 
                         aSet.Put(SvxPostItTextItem(sComment.ConvertLineEnd(), SID_ATTR_POSTIT_TEXT));
@@ -1279,7 +1140,7 @@ IMPL_LINK( SwRedlineAcceptDlg, CommandHdl, void*, EMPTYARG )
                                     SID_ATTR_POSTIT_DATE ));
 
                         AbstractSvxPostItDialog* pDlg = pFact->CreateSvxPostItDialog( pParentDlg, aSet, FALSE );
-                        DBG_ASSERT(pDlg, "Dialogdiet fail!");
+                        OSL_ENSURE(pDlg, "Dialogdiet fail!");
 
                         pDlg->HideAuthor();
 
@@ -1356,10 +1217,6 @@ IMPL_LINK( SwRedlineAcceptDlg, CommandHdl, void*, EMPTYARG )
     return 0;
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwRedlineAcceptDlg::Initialize(const String& rExtraData)
 {
     if (rExtraData.Len())
@@ -1397,10 +1254,6 @@ void SwRedlineAcceptDlg::Initialize(const String& rExtraData)
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
 void SwRedlineAcceptDlg::FillInfo(String &rExtraData) const
 {
     rExtraData.AppendAscii("AcceptChgDat:(");
@@ -1416,3 +1269,5 @@ void SwRedlineAcceptDlg::FillInfo(String &rExtraData) const
     }
     rExtraData += ')';
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
