@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -67,19 +68,13 @@
 
 #include <cmdid.h>
 #include <helpid.h>
-#ifndef _GLOBALS_HRC
 #include <globals.hrc>
-#endif
-#ifndef _SHELLS_HRC
 #include <shells.hrc>
-#endif
 
 #define SwDrawTextShell
 #include <sfx2/msg.hxx>
 #include <swslots.hxx>
-#ifndef _POPUP_HRC
 #include <popup.hrc>
-#endif
 #include <uitool.hxx>
 #include <wview.hxx>
 #include <swmodule.hxx>
@@ -93,7 +88,7 @@
 
 #include <cppuhelper/bootstrap.hxx>
 
-#include "swabstdlg.hxx" //CHINA001
+#include "swabstdlg.hxx"
 #include "misc.hrc"
 
 using namespace ::com::sun::star;
@@ -101,8 +96,6 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::i18n;
 
-
-
 SFX_IMPL_INTERFACE(SwDrawTextShell, SfxShell, SW_RES(STR_SHELLNAME_DRAW_TEXT))
 {
     SFX_POPUPMENU_REGISTRATION(SW_RES(MN_DRWTXT_POPUPMENU));
@@ -112,12 +105,6 @@ SFX_IMPL_INTERFACE(SwDrawTextShell, SfxShell, SW_RES(STR_SHELLNAME_DRAW_TEXT))
 
 TYPEINIT1(SwDrawTextShell,SfxShell)
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
-
 void SwDrawTextShell::Init()
 {
     SwWrtShell &rSh = GetShell();
@@ -146,11 +133,6 @@ void SwDrawTextShell::Init()
     pOLV->ShowCursor();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
 SwDrawTextShell::SwDrawTextShell(SwView &rV) :
     SfxShell(&rV),
     rView(rV)
@@ -165,12 +147,6 @@ SwDrawTextShell::SwDrawTextShell(SwView &rV) :
     SetHelpId(SW_DRWTXTSHELL);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
-
 __EXPORT SwDrawTextShell::~SwDrawTextShell()
 {
     if ( GetView().GetCurShell() == this )
@@ -182,7 +158,7 @@ __EXPORT SwDrawTextShell::~SwDrawTextShell()
     //Dann wird vor dem Flush wieder ein DrawTextShell gepusht und der Mode ist
     //eingeschaltet. In diesem Moment wird der Dispatcher geflusht und die alte
     //DrawTextShell zerstoert.
-//	ASSERT( !pSdrView->IsTextEdit(), "TextEdit in DTor DrwTxtSh?" );
+// OSL_ENSURE( !pSdrView->IsTextEdit(), "TextEdit in DTor DrwTxtSh?" );
 //    if (pSdrView->IsTextEdit())
 //		GetShell().EndTextEdit();	// Danebengeklickt, Ende mit Edit
 
@@ -194,11 +170,9 @@ SwWrtShell& SwDrawTextShell::GetShell()
     return rView.GetWrtShell();
 }
 
-
 /*--------------------------------------------------------------------
     Beschreibung:	Slots mit dieser Statusmethode disablen
  --------------------------------------------------------------------*/
-
 void SwDrawTextShell::StateDisableItems( SfxItemSet &rSet )
 {
     SfxWhichIter aIter(rSet);
@@ -211,15 +185,11 @@ void SwDrawTextShell::StateDisableItems( SfxItemSet &rSet )
     }
 }
 
-
 /*************************************************************************
 |*
 |* Attribute setzen
 |*
 \************************************************************************/
-
-
-
 void SwDrawTextShell::SetAttrToMarked(const SfxItemSet& rAttr)
 {
     Rectangle aNullRect;
@@ -233,23 +203,11 @@ void SwDrawTextShell::SetAttrToMarked(const SfxItemSet& rAttr)
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
-
 BOOL SwDrawTextShell::IsTextEdit()
 {
     return pSdrView->IsTextEdit();
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
-
 void SwDrawTextShell::ExecFontWork(SfxRequest& rReq)
 {
     SwWrtShell &rSh = GetShell();
@@ -268,12 +226,6 @@ void SwDrawTextShell::ExecFontWork(SfxRequest& rReq)
     pVFrame->GetBindings().Invalidate(SID_FONTWORK);
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
-
 void SwDrawTextShell::StateFontWork(SfxItemSet& rSet)
 {
     const USHORT nId = SvxFontWorkChildWindow::GetChildWindowId();
@@ -285,9 +237,6 @@ void SwDrawTextShell::StateFontWork(SfxItemSet& rSet)
 |* SfxRequests fuer FontWork bearbeiten
 |*
 \************************************************************************/
-
-
-
 void SwDrawTextShell::ExecFormText(SfxRequest& rReq)
 {
     SwWrtShell &rSh = GetShell();
@@ -337,9 +286,6 @@ void SwDrawTextShell::ExecFormText(SfxRequest& rReq)
 |* Statuswerte fuer FontWork zurueckgeben
 |*
 \************************************************************************/
-
-
-
 void SwDrawTextShell::GetFormTextState(SfxItemSet& rSet)
 {
     SwWrtShell &rSh = GetShell();
@@ -379,12 +325,6 @@ void SwDrawTextShell::GetFormTextState(SfxItemSet& rSet)
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
-
-
-
 void SwDrawTextShell::ExecDrawLingu(SfxRequest &rReq)
 {
     SwWrtShell &rSh = GetShell();
@@ -414,7 +354,7 @@ void SwDrawTextShell::ExecDrawLingu(SfxRequest &rReq)
                     {
                         Reference< ui::dialogs::XExecutableDialog > xDialog(
                                 xMCF->createInstanceWithContext(
-                                    rtl::OUString::createFromAscii("com.sun.star.linguistic2.ChineseTranslationDialog")
+                                    rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.linguistic2.ChineseTranslationDialog"))
                                     , xContext), UNO_QUERY);
                         Reference< lang::XInitialization > xInit( xDialog, UNO_QUERY );
                         if( xInit.is() )
@@ -424,7 +364,7 @@ void SwDrawTextShell::ExecDrawLingu(SfxRequest &rReq)
                             Sequence<Any> aSeq(1);
                             Any* pArray = aSeq.getArray();
                             PropertyValue aParam;
-                            aParam.Name = rtl::OUString::createFromAscii("ParentWindow");
+                            aParam.Name = rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("ParentWindow"));
                             aParam.Value <<= makeAny(xDialogParentWindow);
                             pArray[0] <<= makeAny(aParam);
                             xInit->initialize( aSeq );
@@ -473,14 +413,11 @@ void SwDrawTextShell::ExecDrawLingu(SfxRequest &rReq)
             break;
 
         default:
-            ASSERT(!this, "unexpected slot-id");
+            OSL_ENSURE(!this, "unexpected slot-id");
         }
     }
 }
 
-/*--------------------------------------------------------------------
-    Beschreibung:
- --------------------------------------------------------------------*/
 void SwDrawTextShell::ExecDraw(SfxRequest &rReq)
 {
     SwWrtShell &rSh = GetShell();
@@ -589,7 +526,7 @@ void SwDrawTextShell::ExecDraw(SfxRequest &rReq)
             break;
 
         default:
-            ASSERT(!this, "unexpected slot-id");
+            OSL_ENSURE(!this, "unexpected slot-id");
             return;
     }
 
@@ -602,9 +539,6 @@ void SwDrawTextShell::ExecDraw(SfxRequest &rReq)
 /*--------------------------------------------------------------------
     Beschreibung:	Undo ausfuehren
  --------------------------------------------------------------------*/
-
-
-
 void SwDrawTextShell::ExecUndo(SfxRequest &rReq)
 {
     if( IsTextEdit() )
@@ -650,9 +584,6 @@ void SwDrawTextShell::ExecUndo(SfxRequest &rReq)
 /*--------------------------------------------------------------------
     Beschreibung:	Zustand Undo
  --------------------------------------------------------------------*/
-
-
-
 void SwDrawTextShell::StateUndo(SfxItemSet &rSet)
 {
     if ( !IsTextEdit() )
@@ -749,7 +680,7 @@ void SwDrawTextShell::ExecTransliteration( SfxRequest & rReq )
             break;
 
         default:
-            ASSERT(!this, "falscher Dispatcher");
+            OSL_ENSURE(!this, "wrong dispatcher");
         }
 
         if( nMode )
@@ -763,7 +694,6 @@ void SwDrawTextShell::ExecTransliteration( SfxRequest & rReq )
 /*--------------------------------------------------------------------
     Beschreibung:	Sonderzeichen einfuegen (siehe SDraw: FUBULLET.CXX)
  --------------------------------------------------------------------*/
-
 void SwDrawTextShell::InsertSymbol(SfxRequest& rReq)
 {
     OutlinerView* pOLV = pSdrView->GetTextEditOutlinerView();
@@ -896,9 +826,7 @@ void SwDrawTextShell::InsertSymbol(SfxRequest& rReq)
         rReq.Done();
     }
 }
-/*-- 22.10.2003 14:26:32---------------------------------------------------
 
-  -----------------------------------------------------------------------*/
 SfxUndoManager* SwDrawTextShell::GetUndoManager()
 {
     SwWrtShell &rSh = GetShell();
@@ -908,5 +836,4 @@ SfxUndoManager* SwDrawTextShell::GetUndoManager()
     return &pOutliner->GetUndoManager();
 }
 
-
-
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
