@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -35,12 +36,8 @@
 
 
 
-#ifndef _EDIT_HXX //autogen
 #include <vcl/edit.hxx>
-#endif
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <vcl/svapp.hxx>
 #include <svl/zforlist.hxx>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
@@ -51,18 +48,12 @@
 #include <svx/framelinkarray.hxx>
 #include "swmodule.hxx"
 #include "swtypes.hxx"
-#ifndef _VIEW_HXX
 #include "view.hxx"
-#endif
 #include "wrtsh.hxx"
 #include "tblafmt.hxx"
-#ifndef _TAUTOFMT_HXX
 #include "tautofmt.hxx"
-#endif
 #include "shellres.hxx"
-#ifndef _TAUTOFMT_HRC
 #include "tautofmt.hrc"
-#endif
 
 using namespace com::sun::star;
 
@@ -608,12 +599,12 @@ AutoFmtPreview::AutoFmtPreview( Window* pParent, const ResId& rRes, SwWrtShell*
     else
         mbRTL = pWrtShell->IsTableRightToLeft();
     
-    DBG_ASSERT( m_xMSF.is(), "AutoFmtPreview: no MultiServiceFactory");
+    OSL_ENSURE( m_xMSF.is(), "AutoFmtPreview: no MultiServiceFactory");
     if ( m_xMSF.is() )
     {
         m_xBreak = uno::Reference< i18n::XBreakIterator >(
             m_xMSF->createInstance (
-                rtl::OUString::createFromAscii( "com.sun.star.i18n.BreakIterator" ) ),
+            rtl::OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.i18n.BreakIterator")) ),
             uno::UNO_QUERY);
     }
     pNumFmt	= new SvNumberFormatter( m_xMSF, LANGUAGE_SYSTEM );
@@ -1055,3 +1046,5 @@ void __EXPORT AutoFmtPreview::Paint( const Rectangle& rRect )
 {
     DoPaint( rRect );
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
